@@ -2,6 +2,7 @@
 #include <sstream>
 #include <iomanip>
 #include <algorithm>
+#include <cstring>
 #include "../drw_base.h"
 #include "drw_cptables.h"
 #include "drw_cptable932.h"
@@ -9,113 +10,143 @@
 #include "drw_cptable949.h"
 #include "drw_cptable950.h"
 
-DRW_TextCodec::DRW_TextCodec() {
-    version = DRW::AC1021;
-    conv = new DRW_Converter(NULL, 0);
+DRW_TextCodec::DRW_TextCodec()
+    : version{DRW::AC1021}
+    , conv( new DRW_Converter(nullptr, 0) )
+{
 }
 
-DRW_TextCodec::~DRW_TextCodec() {
-    delete conv;
-}
+DRW_TextCodec::~DRW_TextCodec() = default;
 
-void DRW_TextCodec::setVersion(int v, bool dxfFormat){
-    if (v == DRW::AC1009 || v == DRW::AC1006) {
-        version = DRW::AC1009;
-        cp = "ANSI_1252";
-        setCodePage(&cp, dxfFormat);
-    } else if (v == DRW::AC1012 || v == DRW::AC1014
-             || v == DRW::AC1015 || v == DRW::AC1018) {
-        version = DRW::AC1015;
-//        if (cp.empty()) { //codepage not set, initialize
+void DRW_TextCodec::setVersion(DRW::Version v, bool dxfFormat){
+    switch (v)
+    {
+        case DRW::UNKNOWNV:
+        case DRW::MC00:
+        case DRW::AC12:
+        case DRW::AC14:
+        case DRW::AC150:
+        case DRW::AC210:
+        case DRW::AC1002:
+        case DRW::AC1003:
+        case DRW::AC1004:
+            // unhandled?
+            break;
+
+        case DRW::AC1006:
+        case DRW::AC1009:
+        {
+            version = DRW::AC1009;
             cp = "ANSI_1252";
-            setCodePage(&cp, dxfFormat);
-//        }
-    } else {
-        version = DRW::AC1021;
-        if (dxfFormat)
-            cp = "UTF-8";//RLZ: can be UCS2 or UTF-16 16bits per char
-        else
-            cp = "UTF-16";//RLZ: can be UCS2 or UTF-16 16bits per char
-        setCodePage(&cp, dxfFormat);
+            setCodePage( cp, dxfFormat);
+            break;
+        }
+
+        case DRW::AC1012:
+        case DRW::AC1014:
+        case DRW::AC1015:
+        case DRW::AC1018:
+        {
+            version = DRW::AC1015;
+//            if (cp.empty()) { //codepage not set, initialize ??
+                cp = "ANSI_1252";
+                setCodePage( cp, dxfFormat);
+//          }
+            break;
+        }
+
+        case DRW::AC1021:
+        case DRW::AC1024:
+        case DRW::AC1027:
+        case DRW::AC1032:
+        {
+            version = DRW::AC1021;
+            if (dxfFormat)
+                cp = "UTF-8";//RLZ: can be UCS2 or UTF-16 16bits per char
+            else
+                cp = "UTF-16";//RLZ: can be UCS2 or UTF-16 16bits per char
+            setCodePage( cp, dxfFormat);
+            break;
+        }
     }
 }
 
-void DRW_TextCodec::setVersion(std::string *v, bool dxfFormat){
-    std::string versionStr = *v;
-    if (versionStr == "AC1009" || versionStr == "AC1006") {
-        setVersion(DRW::AC1009, dxfFormat);
-    } else if (versionStr == "AC1012" || versionStr == "AC1014"
-             || versionStr == "AC1015" || versionStr == "AC1018") {
-        setVersion(DRW::AC1015, dxfFormat);
+void DRW_TextCodec::setVersion(const std::string &v, bool dxfFormat){
+    version = DRW::UNKNOWNV;
+    for ( auto it = DRW::dwgVersionStrings.begin(); it != DRW::dwgVersionStrings.end(); ++it )
+    {
+        if ( std::strcmp( v.c_str(), it->first ) == 0 ) {
+            version = it->second;
+            setVersion( it->second, dxfFormat);
+            break;
+        }
     }
-    setVersion(DRW::AC1021, dxfFormat);
 }
 
-void DRW_TextCodec::setCodePage(std::string *c, bool dxfFormat){
-    cp = correctCodePage(*c);
-    delete conv;
+void DRW_TextCodec::setCodePage(const std::string &c, bool dxfFormat){
+    cp = correctCodePage(c);
+    conv.reset();
     if (version == DRW::AC1009 || version == DRW::AC1015) {
         if (cp == "ANSI_874")
-            conv = new DRW_ConvTable(DRW_Table874, CPLENGHTCOMMON);
+            conv.reset( new DRW_ConvTable(DRW_Table874, CPLENGTHCOMMON) );
         else if (cp == "ANSI_932")
-            conv = new DRW_Conv932Table(DRW_Table932, DRW_LeadTable932,
-                                         DRW_DoubleTable932, CPLENGHT932);
+            conv.reset( new DRW_Conv932Table() );
         else if (cp == "ANSI_936")
-            conv = new DRW_ConvDBCSTable(DRW_Table936, DRW_LeadTable936,
-                                         DRW_DoubleTable936, CPLENGHT936);
+            conv.reset( new DRW_ConvDBCSTable(DRW_Table936, DRW_LeadTable936,
+                                         DRW_DoubleTable936, CPLENGTH936) );
         else if (cp == "ANSI_949")
-            conv = new DRW_ConvDBCSTable(DRW_Table949, DRW_LeadTable949,
-                                         DRW_DoubleTable949, CPLENGHT949);
+            conv.reset( new DRW_ConvDBCSTable(DRW_Table949, DRW_LeadTable949,
+                                         DRW_DoubleTable949, CPLENGTH949) );
         else if (cp == "ANSI_950")
-            conv = new DRW_ConvDBCSTable(DRW_Table950, DRW_LeadTable950,
-                                         DRW_DoubleTable950, CPLENGHT950);
+            conv.reset( new DRW_ConvDBCSTable(DRW_Table950, DRW_LeadTable950,
+                                         DRW_DoubleTable950, CPLENGTH950) );
         else if (cp == "ANSI_1250")
-            conv = new DRW_ConvTable(DRW_Table1250, CPLENGHTCOMMON);
+            conv.reset( new DRW_ConvTable(DRW_Table1250, CPLENGTHCOMMON) );
         else if (cp == "ANSI_1251")
-            conv = new DRW_ConvTable(DRW_Table1251, CPLENGHTCOMMON);
+            conv.reset( new DRW_ConvTable(DRW_Table1251, CPLENGTHCOMMON) );
         else if (cp == "ANSI_1253")
-            conv = new DRW_ConvTable(DRW_Table1253, CPLENGHTCOMMON);
+            conv.reset( new DRW_ConvTable(DRW_Table1253, CPLENGTHCOMMON) );
         else if (cp == "ANSI_1254")
-            conv = new DRW_ConvTable(DRW_Table1254, CPLENGHTCOMMON);
+            conv.reset( new DRW_ConvTable(DRW_Table1254, CPLENGTHCOMMON) );
         else if (cp == "ANSI_1255")
-            conv = new DRW_ConvTable(DRW_Table1255, CPLENGHTCOMMON);
+            conv.reset( new DRW_ConvTable(DRW_Table1255, CPLENGTHCOMMON) );
         else if (cp == "ANSI_1256")
-            conv = new DRW_ConvTable(DRW_Table1256, CPLENGHTCOMMON);
+            conv.reset( new DRW_ConvTable(DRW_Table1256, CPLENGTHCOMMON) );
         else if (cp == "ANSI_1257")
-            conv = new DRW_ConvTable(DRW_Table1257, CPLENGHTCOMMON);
+            conv.reset( new DRW_ConvTable(DRW_Table1257, CPLENGTHCOMMON) );
         else if (cp == "ANSI_1258")
-            conv = new DRW_ConvTable(DRW_Table1258, CPLENGHTCOMMON);
+            conv.reset( new DRW_ConvTable(DRW_Table1258, CPLENGTHCOMMON) );
         else if (cp == "UTF-8") { //DXF older than 2007 are write in win codepages
             cp = "ANSI_1252";
-            conv = new DRW_Converter(NULL, 0);
+            conv.reset( new DRW_Converter(nullptr, 0) );
         } else
-            conv = new DRW_ConvTable(DRW_Table1252, CPLENGHTCOMMON);
+            conv.reset( new DRW_ConvTable(DRW_Table1252, CPLENGTHCOMMON) );
     } else {
         if (dxfFormat)
-            conv = new DRW_Converter(NULL, 0);//utf16 to utf8
+            conv.reset( new DRW_Converter(nullptr, 0) );//utf16 to utf8
         else
-            conv = new DRW_ConvUTF16();//utf16 to utf8
+            conv.reset( new DRW_ConvUTF16() );//utf16 to utf8
     }
 }
 
-std::string DRW_TextCodec::toUtf8(std::string s) {
-    return conv->toUtf8(&s);
+std::string DRW_TextCodec::toUtf8(const std::string &s) {
+    return conv->toUtf8(s);
 }
 
-std::string DRW_TextCodec::fromUtf8(std::string s) {
-    return conv->fromUtf8(&s);
+std::string DRW_TextCodec::fromUtf8(const std::string &s) {
+    return conv->fromUtf8(s);
 }
 
-std::string DRW_Converter::toUtf8(std::string *s) {
+std::string DRW_Converter::toUtf8(const std::string &s) {
     std::string result;
     int j = 0;
     unsigned int i= 0;
-    for (i=0; i < s->length(); i++) {
-        unsigned char c = s->at(i);
+    for (i=0; i < s.length(); i++) {
+        unsigned char c = s.at(i);
         if (c < 0x80) { //ascii check for /U+????
-            if (c == '\\' && i+6 < s->length() && s->at(i+1) == 'U' && s->at(i+2) == '+') {
-                result += s->substr(j,i-j);
-                result += encodeText(s->substr(i,7));
+            if (c == '\\' && i+6 < s.length() && s.at(i+1) == 'U' && s.at(i+2) == '+') {
+                result += s.substr(j,i-j);
+                result += encodeText(s.substr(i,7));
                 i +=6;
                 j = i+1;
             }
@@ -127,28 +158,28 @@ std::string DRW_Converter::toUtf8(std::string *s) {
             i +=3;
         }
     }
-    result += s->substr(j);
+    result += s.substr(j);
 
     return result;
 }
 
-std::string DRW_ConvTable::fromUtf8(std::string *s) {
+std::string DRW_ConvTable::fromUtf8(const std::string &s) {
     std::string result;
     bool notFound;
     int code;
 
     int j = 0;
-    for (unsigned int i=0; i < s->length(); i++) {
-        unsigned char c = s->at(i);
+    for (unsigned int i=0; i < s.length(); i++) {
+        unsigned char c = s.at(i);
         if (c > 0x7F) { //need to decode
-            result += s->substr(j,i-j);
-            std::string part1 = s->substr(i,4);
+            result += s.substr(j,i-j);
+            std::string part1 = s.substr(i,4);
             int l;
             code = decodeNum(part1, &l);
             j = i+l;
             i = j - 1;
             notFound = true;
-            for (int k=0; k<cpLenght; k++){
+            for (int k=0; k<cpLength; k++){
                 if(table[k] == code) {
                     result += CPOFFSET + k; //translate from table
                     notFound = false;
@@ -159,20 +190,19 @@ std::string DRW_ConvTable::fromUtf8(std::string *s) {
                 result += decodeText(code);
         }
     }
-    result += s->substr(j);
+    result += s.substr(j);
 
     return result;
 }
 
-std::string DRW_ConvTable::toUtf8(std::string *s) {
+std::string DRW_ConvTable::toUtf8(const std::string &s) {
     std::string res;
-    std::string::iterator it;
-    for ( it=s->begin() ; it < s->end(); ++it ) {
+    for ( auto it=s.begin() ; it < s.end(); ++it ) {
         unsigned char c = *it;
         if (c < 0x80) {
             //check for \U+ encoded text
             if (c == '\\') {
-                if (it+6 < s->end() && *(it+1) == 'U' && *(it+2) == '+')  {
+                if (s.end()-it > 6 && *(it+1) == 'U' && *(it+2) == '+')  {
                     res += encodeText(std::string(it, it+7));
                     it +=6;
                 } else {
@@ -188,7 +218,7 @@ std::string DRW_ConvTable::toUtf8(std::string *s) {
     return res;
 }
 
-std::string DRW_Converter::encodeText(std::string stmp){
+std::string DRW_Converter::encodeText(const std::string &stmp){
     int code;
 #if defined(__APPLE__)
     int Succeeded = sscanf (&( stmp.substr(3,4)[0]), "%x", &code );
@@ -238,13 +268,13 @@ std::string DRW_Converter::encodeNum(int c){
         ret[3] = 0x80 | (c & 0x3f);
         ret[4] = 0;
     }
-    return std::string((char*)ret);
+    return std::string(reinterpret_cast<char*>(ret));
 }
 
-/** 's' is a string with at least 4 bytes lenght
-** returned 'b' is byte lenght of encoded char: 2,3 or 4
+/** 's' is a string with at least 4 bytes length
+** returned 'b' is byte length of encoded char: 2,3 or 4
 **/
-int DRW_Converter::decodeNum(std::string s, int *b){
+int DRW_Converter::decodeNum(const std::string &s, int *b){
     int code= 0;
     unsigned char c = s.at(0);
     if ( (c& 0xE0)  == 0xC0) { //2 bytes
@@ -268,23 +298,23 @@ int DRW_Converter::decodeNum(std::string s, int *b){
 }
 
 
-std::string DRW_ConvDBCSTable::fromUtf8(std::string *s) {
+std::string DRW_ConvDBCSTable::fromUtf8(const std::string &s) {
     std::string result;
     bool notFound;
     int code;
 
     int j = 0;
-    for (unsigned int i=0; i < s->length(); i++) {
-        unsigned char c = s->at(i);
+    for (unsigned int i=0; i < s.length(); i++) {
+        unsigned char c = s.at(i);
         if (c > 0x7F) { //need to decode
-            result += s->substr(j,i-j);
-            std::string part1 = s->substr(i,4);
+            result += s.substr(j,i-j);
+            std::string part1 = s.substr(i,4);
             int l;
             code = decodeNum(part1, &l);
             j = i+l;
             i = j - 1;
             notFound = true;
-                for (int k=0; k<cpLenght; k++){
+                for (int k=0; k<cpLength; k++){
                     if(doubleTable[k][1] == code) {
                         int data = doubleTable[k][0];
                         char d[3];
@@ -300,22 +330,21 @@ std::string DRW_ConvDBCSTable::fromUtf8(std::string *s) {
                 result += decodeText(code);
         } //direct conversion
     }
-    result += s->substr(j);
+    result += s.substr(j);
 
     return result;
 }
 
-std::string DRW_ConvDBCSTable::toUtf8(std::string *s) {
+std::string DRW_ConvDBCSTable::toUtf8(const std::string &s) {
     std::string res;
-    std::string::iterator it;
-    for ( it=s->begin() ; it < s->end(); ++it ) {
+    for (auto it=s.begin() ; it < s.end(); ++it ) {
         bool notFound = true;
         unsigned char c = *it;
         if (c < 0x80) {
             notFound = false;
             //check for \U+ encoded text
             if (c == '\\') {
-                if (it+6 < s->end() && *(it+1) == 'U' && *(it+2) == '+')  {
+                if (s.end()-it > 6 && *(it+1) == 'U' && *(it+2) == '+')  {
                     res += encodeText(std::string(it, it+7));
                     it +=6;
                 } else {
@@ -328,7 +357,7 @@ std::string DRW_ConvDBCSTable::toUtf8(std::string *s) {
             res += encodeNum(0x20AC);//euro sign
         } else {//2 bytes
             ++it;
-            int code = (c << 8) | (unsigned char )(*it);
+            int code = (c << 8) | static_cast<unsigned char >(*it);
             int sta = leadTable[c-0x81];
             int end = leadTable[c-0x80];
             for (int k=sta; k<end; k++){
@@ -346,17 +375,21 @@ std::string DRW_ConvDBCSTable::toUtf8(std::string *s) {
     return res;
 }
 
-std::string DRW_Conv932Table::fromUtf8(std::string *s) {
+DRW_Conv932Table::DRW_Conv932Table()
+    :DRW_Converter(DRW_Table932, CPLENGTH932) {
+}
+
+std::string DRW_Conv932Table::fromUtf8(const std::string &s) {
     std::string result;
     bool notFound;
     int code;
 
     int j = 0;
-    for (unsigned int i=0; i < s->length(); i++) {
-        unsigned char c = s->at(i);
+    for (unsigned int i=0; i < s.length(); i++) {
+        unsigned char c = s.at(i);
         if (c > 0x7F) { //need to decode
-            result += s->substr(j,i-j);
-            std::string part1 = s->substr(i,4);
+            result += s.substr(j,i-j);
+            std::string part1 = s.substr(i,4);
             int l;
             code = decodeNum(part1, &l);
             j = i+l;
@@ -369,9 +402,9 @@ std::string DRW_Conv932Table::fromUtf8(std::string *s) {
             }
             if (notFound && ( code<0xF8 || (code>0x390 && code<0x542) ||
                     (code>0x200F && code<0x9FA1) || code>0xF928 )) {
-                for (int k=0; k<cpLenght; k++){
-                    if(doubleTable[k][1] == code) {
-                        int data = doubleTable[k][0];
+                for (int k=0; k<cpLength; k++){
+                    if(DRW_DoubleTable932[k][1] == code) {
+                        int data = DRW_DoubleTable932[k][0];
                         char d[3];
                         d[0] = data >> 8;
                         d[1] = data & 0xFF;
@@ -386,22 +419,21 @@ std::string DRW_Conv932Table::fromUtf8(std::string *s) {
                 result += decodeText(code);
         } //direct conversion
     }
-    result += s->substr(j);
+    result += s.substr(j);
 
     return result;
 }
 
-std::string DRW_Conv932Table::toUtf8(std::string *s) {
+std::string DRW_Conv932Table::toUtf8(const std::string &s) {
     std::string res;
-    std::string::iterator it;
-    for ( it=s->begin() ; it < s->end(); ++it ) {
+    for (auto it=s.begin() ; it < s.end(); ++it ) {
         bool notFound = true;
         unsigned char c = *it;
         if (c < 0x80) {
             notFound = false;
             //check for \U+ encoded text
             if (c == '\\') {
-                if (it+6 < s->end() && *(it+1) == 'U' && *(it+2) == '+')  {
+                if (s.end()-it > 6 && *(it+1) == 'U' && *(it+2) == '+')  {
                     res += encodeText(std::string(it, it+7));
                     it +=6;
                 } else {
@@ -414,8 +446,8 @@ std::string DRW_Conv932Table::toUtf8(std::string *s) {
             res += encodeNum(c + CPOFFSET932); //translate from table
         } else {//2 bytes
             ++it;
-            int code = (c << 8) | (unsigned char )(*it);
-            int sta;
+            int code = (c << 8) | static_cast<unsigned char>(*it);
+            int sta=0;
             int end=0;
             if (c > 0x80 && c < 0xA0) {
                 sta = DRW_LeadTable932[c-0x81];
@@ -441,16 +473,15 @@ std::string DRW_Conv932Table::toUtf8(std::string *s) {
     return res;
 }
 
-std::string DRW_ConvUTF16::fromUtf8(std::string *s){
+std::string DRW_ConvUTF16::fromUtf8(const std::string &s){
     DRW_UNUSED(s);
-    //RLZ: to be writen (only needed for write dwg 2007+)
+    //RLZ: to be written (only needed for write dwg 2007+)
     return std::string();
 }
 
-std::string DRW_ConvUTF16::toUtf8(std::string *s){//RLZ: pending to write
+std::string DRW_ConvUTF16::toUtf8(const std::string &s){//RLZ: pending to write
     std::string res;
-    std::string::iterator it;
-    for ( it=s->begin() ; it < s->end(); ++it ) {
+    for ( auto it=s.begin() ; it < s.end(); ++it ) {
         unsigned char c1 = *it;
         unsigned char c2 = *(++it);
         duint16 ch = (c2 <<8) | c1;
@@ -480,13 +511,13 @@ std::string DRW_TextCodec::correctCodePage(const std::string& s) {
                cp=="ISO8859-1" || cp=="ISO8859-15" || cp=="ISO-IR-100" || cp=="L1" || cp=="IBM 850") {
         return "ANSI_1252";
         //Greek
-    } else if (cp=="ANSI_1253" || cp=="CP1253" || cp=="iso8859-7") {
+    } else if (cp=="ANSI_1253" || cp=="CP1253" || cp=="ISO8859-7") {
         return "ANSI_1253";
         //Turkish
-    } else if (cp=="ANSI_1254" || cp=="CP1254" || cp=="iso8859-9" || cp=="iso8859-3") {
+    } else if (cp=="ANSI_1254" || cp=="CP1254" || cp=="ISO8859-9" || cp=="ISO8859-3") {
         return "ANSI_1254";
         //Hebrew
-    } else if (cp=="ANSI_1255" || cp=="CP1255" || cp=="iso8859-8") {
+    } else if (cp=="ANSI_1255" || cp=="CP1255" || cp=="ISO8859-8") {
         return "ANSI_1255";
         //Arabic
     } else if (cp=="ANSI_1256" || cp=="CP1256" || cp=="ISO8859-6") {
