@@ -16,8 +16,6 @@
 #include <string>
 #include <sstream>
 #include <vector>
-#include <map>
-#include <list>
 #include "drw_dbg.h"
 #include "dwgreader15.h"
 #include "drw_textcodec.h"
@@ -27,7 +25,7 @@ bool dwgReader15::readMetaData() {
     version = parent->getVersion();
     decoder.setVersion(version, false);
     DRW_DBG("dwgReader15::readMetaData\n");
-	if (!fileBuf->setPosition(13))
+    if (! fileBuf->setPosition(13))
         return false;
     previewImagePos = fileBuf->getRawLong32();
     DRW_DBG("previewImagePos (seekerImageData) = "); DRW_DBG(previewImagePos);
@@ -109,7 +107,7 @@ bool dwgReader15::readFileHeader() {
     DRW_DBG("\nfile header crc8 xor result= "); DRW_DBG(ckcrc);
     DRW_DBG("\nfile header CRC= "); DRW_DBG(fileBuf->getRawShort16());
     DRW_DBG("\nfile header sentinel= ");
-	checkSentinel(fileBuf.get(), secEnum::FILEHEADER, false);
+    checkSentinel(fileBuf.get(), secEnum::FILEHEADER, false);
 
     DRW_DBG("\nposition after read file header sentinel= "); DRW_DBG(fileBuf->getPosition());
     DRW_DBG(", bit are= "); DRW_DBG(fileBuf->getBitPos());
@@ -124,13 +122,13 @@ bool dwgReader15::readDwgHeader(DRW_Header& hdr){
     if (si.Id<0)//not found, ends
         return false;
     if (!fileBuf->setPosition(si.address))
-		return false;
-	std::vector<duint8> tmpByteStr(si.size);
-	fileBuf->getBytes(tmpByteStr.data(), si.size);
-	dwgBuffer buff(tmpByteStr.data(), si.size, &decoder);
+        return false;
+    std::vector<duint8> tmpByteStr(si.size);
+    fileBuf->getBytes(tmpByteStr.data(), si.size);
+    dwgBuffer buff(tmpByteStr.data(), si.size, &decoder);
     DRW_DBG("Header section sentinel= ");
     checkSentinel(&buff, secEnum::HEADER, true);
-	bool ret = dwgReader::readDwgHeader(hdr, &buff, &buff);
+    bool ret = dwgReader::readDwgHeader(hdr, &buff, &buff);
     return ret;
 }
 
@@ -144,17 +142,16 @@ bool dwgReader15::readDwgClasses(){
         return false;
 
     DRW_DBG("classes section sentinel= ");
-	checkSentinel(fileBuf.get(), secEnum::CLASSES, true);
+    checkSentinel(fileBuf.get(), secEnum::CLASSES, true);
 
     duint32 size = fileBuf->getRawLong32();
     if (size != (si.size - 38)) {
         DRW_DBG("\nWARNING dwgReader15::readDwgClasses size are "); DRW_DBG(size);
         DRW_DBG(" and secSize - 38 are "); DRW_DBG(si.size - 38); DRW_DBG("\n");
-	}
-	std::vector<duint8> tmpByteStr(size);
-
-	fileBuf->getBytes(tmpByteStr.data(), size);
-	dwgBuffer buff(tmpByteStr.data(), size, &decoder);
+    }
+    std::vector<duint8> tmpByteStr(size);
+    fileBuf->getBytes(tmpByteStr.data(), size);
+    dwgBuffer buff(tmpByteStr.data(), size, &decoder);
     size--; //reduce 1 byte instead of check pos + bitPos
     while (size > buff.getPosition()) {
         DRW_Class *cl = new DRW_Class();
@@ -163,8 +160,8 @@ bool dwgReader15::readDwgClasses(){
     }
      DRW_DBG("\nCRC: "); DRW_DBGH(fileBuf->getRawShort16());
      DRW_DBG("\nclasses section end sentinel= ");
-	 checkSentinel(fileBuf.get(), secEnum::CLASSES, false);
-	 bool ret = buff.isGood();
+     checkSentinel(fileBuf.get(), secEnum::CLASSES, false);
+     bool ret = buff.isGood();
      return ret;
 }
 
@@ -174,7 +171,7 @@ bool dwgReader15::readDwgHandles() {
     if (si.Id<0)//not found, ends
         return false;
 
-	bool ret = dwgReader::readDwgHandles(fileBuf.get(), si.address, si.size);
+    bool ret = dwgReader::readDwgHandles(fileBuf.get(), si.address, si.size);
     return ret;
 }
 
@@ -184,7 +181,7 @@ bool dwgReader15::readDwgHandles() {
  * (using their object file offsets)
  */
 bool dwgReader15::readDwgTables(DRW_Header& hdr) {
-	bool ret = dwgReader::readDwgTables(hdr, fileBuf.get());
+    bool ret = dwgReader::readDwgTables(hdr, fileBuf.get());
 
     return ret;
 }
@@ -195,7 +192,7 @@ bool dwgReader15::readDwgTables(DRW_Header& hdr) {
  */
 bool dwgReader15::readDwgBlocks(DRW_Interface& intfa) {
     bool ret = true;
-	ret = dwgReader::readDwgBlocks(intfa, fileBuf.get());
+    ret = dwgReader::readDwgBlocks(intfa, fileBuf.get());
     return ret;
 }
 
