@@ -16,8 +16,6 @@
 #include <string>
 #include <sstream>
 #include <vector>
-#include <map>
-#include <list>
 #include "drw_dbg.h"
 #include "dwgreader18.h"
 #include "dwgutil.h"
@@ -25,9 +23,9 @@
 #include "../libdwgr.h"
 
 void dwgReader18::genMagicNumber(){
-	int size =0x114;
-	std::vector<duint8> tmpMagicStr(size);
-	duint8 *p = tmpMagicStr.data();
+    int size =0x114;
+    std::vector<duint8> tmpMagicStr(size);
+    duint8 *p = tmpMagicStr.data();
     int rSeed =1;
     while (size--) {
         rSeed *= 0x343fd;
@@ -45,18 +43,18 @@ void dwgReader18::genMagicNumber(){
             DRW_DBG(", ");
             j++;
         }
-	}
+    }
 }
 
-duint32 dwgReader18::checksum(duint32 seed, duint8* data, duint32 sz){
-    duint32 size = sz;
+duint32 dwgReader18::checksum(duint32 seed, duint8* data, duint64 sz){
+    duint64 size = sz;
     duint32 sum1 = seed & 0xffff;
     duint32 sum2 = seed >> 0x10;
     while (size != 0) {
 //        duint32 chunkSize = min(0x15b0, size);
-        duint32 chunkSize = 0x15b0 < size? 0x15b0:size;
+        duint64 chunkSize = 0x15b0 < size? 0x15b0:size;
         size -= chunkSize;
-        for (duint32 i = 0; i < chunkSize; i++) {
+        for (duint64 i = 0; i < chunkSize; i++) {
             sum1 += *data++;
             sum2 += sum1;
         }
@@ -66,8 +64,8 @@ duint32 dwgReader18::checksum(duint32 seed, duint8* data, duint32 sz){
     return (sum2 << 0x10) | (sum1 & 0xffff);
 }
 
- //called: Section page map: 0x41630e3b
-void dwgReader18::parseSysPage(duint8 *decompSec, duint32 decompSize){
+//called: Section page map: 0x41630e3b
+bool dwgReader18::parseSysPage(duint8 *decompSec, duint32 decompSize){
     DRW_DBG("\nparseSysPage:\n ");
     duint32 compSize = fileBuf->getRawLong32();
     DRW_DBG("Compressed size= "); DRW_DBG(compSize); DRW_DBG(", "); DRW_DBGH(compSize);
@@ -81,9 +79,9 @@ void dwgReader18::parseSysPage(duint8 *decompSec, duint32 decompSize){
         hdrData[i]=0;
     duint32 calcsH = checksum(0, hdrData, 20);
     DRW_DBG("Calc hdr checksum= "); DRW_DBGH(calcsH);
-	std::vector<duint8> tmpCompSec(compSize);
-	fileBuf->getBytes(tmpCompSec.data(), compSize);
-	duint32 calcsD = checksum(calcsH, tmpCompSec.data(), compSize);
+    std::vector<duint8> tmpCompSec(compSize);
+    fileBuf->getBytes(tmpCompSec.data(), compSize);
+    duint32 calcsD = checksum(calcsH, tmpCompSec.data(), compSize);
     DRW_DBG("\nCalc data checksum= "); DRW_DBGH(calcsD); DRW_DBG("\n");
 
 #ifdef DRW_DBG_DUMP
@@ -93,9 +91,12 @@ void dwgReader18::parseSysPage(duint8 *decompSec, duint32 decompSize){
         } else { DRW_DBG(", "); j++; }
     } DRW_DBG("\n");
 #endif
-    DRW_DBG("decompresing "); DRW_DBG(compSize); DRW_DBG(" bytes in "); DRW_DBG(decompSize); DRW_DBG(" bytes\n");
+    DRW_DBG("decompressing "); DRW_DBG(compSize); DRW_DBG(" bytes in "); DRW_DBG(decompSize); DRW_DBG(" bytes\n");
     dwgCompressor comp;
-	comp.decompress18(tmpCompSec.data(), decompSec, compSize, decompSize);
+    if (!comp.decompress18(tmpCompSec.data(), decompSec, compSize, decompSize)) {
+        return false;
+    }
+
 #ifdef DRW_DBG_DUMP
     for (unsigned int i=0, j=0; i< decompSize;i++) {
         DRW_DBGH( decompSec[i]);
@@ -103,14 +104,16 @@ void dwgReader18::parseSysPage(duint8 *decompSec, duint32 decompSize){
         } else { DRW_DBG(", "); j++; }
     } DRW_DBG("\n");
 #endif
+
+    return true;
 }
 
  //called ???: Section map: 0x4163003b
-bool dwgReader18::parseDataPage(dwgSectionInfo si/*, duint8 *dData*/){
+bool dwgReader18::parseDataPage(const dwgSectionInfo &si/*, duint8 *dData*/){
     DRW_DBG("\nparseDataPage\n ");
-	objData.resize(si.pageCount * si.maxSize);
+    objData.reset( new duint8 [si.pageCount * si.maxSize] );
 
-    for (std::map<duint32, dwgPageInfo>::iterator it=si.pages.begin(); it!=si.pages.end(); ++it){
+    for (auto it=si.pages.begin(); it!=si.pages.end(); ++it){
         dwgPageInfo pi = it->second;
         if (!fileBuf->setPosition(pi.address))
             return false;
@@ -120,7 +123,7 @@ bool dwgReader18::parseDataPage(dwgSectionInfo si/*, duint8 *dData*/){
         dwgCompressor::decrypt18Hdr(hdrData, 32, pi.address);
         DRW_DBG("Section  "); DRW_DBG(si.name); DRW_DBG(" page header=\n");
         for (unsigned int i=0, j=0; i< 32;i++) {
-            DRW_DBGH( (unsigned char)hdrData[i]);
+            DRW_DBGH( static_cast<unsigned char>(hdrData[i]));
             if (j == 7) {
                 DRW_DBG("\n");
                 j = 0;
@@ -147,25 +150,28 @@ bool dwgReader18::parseDataPage(dwgSectionInfo si/*, duint8 *dData*/){
         DRW_DBG("\n      header checksum= "); DRW_DBGH(bufHdr.getRawLong32());
         DRW_DBG("\n      data checksum= "); DRW_DBGH(bufHdr.getRawLong32()); DRW_DBG("\n");
 
-        //get compresed data
-		std::vector<duint8> cData(pi.cSize);
-        if (!fileBuf->setPosition(pi.address+32))
+        //get compressed data
+        std::vector<duint8> cData(pi.cSize);
+        if (!fileBuf->setPosition(pi.address + 32)) {
             return false;
-		fileBuf->getBytes(cData.data(), pi.cSize);
+        }
+        fileBuf->getBytes(cData.data(), pi.cSize);
 
         //calculate checksum
-		duint32 calcsD = checksum(0, cData.data(), pi.cSize);
+        duint32 calcsD = checksum(0, cData.data(), pi.cSize);
         for (duint8 i= 24; i<28; ++i)
             hdrData[i]=0;
         duint32 calcsH = checksum(calcsD, hdrData, 32);
         DRW_DBG("Calc header checksum= "); DRW_DBGH(calcsH);
         DRW_DBG("\nCalc data checksum= "); DRW_DBGH(calcsD); DRW_DBG("\n");
 
-		duint8* oData = &objData[pi.startOffset];
+        duint8* oData = objData.get() + pi.startOffset;
         pi.uSize = si.maxSize;
-        DRW_DBG("decompresing "); DRW_DBG(pi.cSize); DRW_DBG(" bytes in "); DRW_DBG(pi.uSize); DRW_DBG(" bytes\n");
+        DRW_DBG("decompressing "); DRW_DBG(pi.cSize); DRW_DBG(" bytes in "); DRW_DBG(pi.uSize); DRW_DBG(" bytes\n");
         dwgCompressor comp;
-		comp.decompress18(cData.data(), oData, pi.cSize, pi.uSize);
+        if (!comp.decompress18(cData.data(), oData, pi.cSize, pi.uSize)) {
+            return false;
+        }
     }
     return true;
 }
@@ -177,7 +183,7 @@ bool dwgReader18::readMetaData() {
     if (! fileBuf->setPosition(11))
         return false;
     maintenanceVersion = fileBuf->getRawChar8();
-    DRW_DBG("maintenance verion= "); DRW_DBGH(maintenanceVersion);
+    DRW_DBG("maintenance version= "); DRW_DBGH(maintenanceVersion);
     DRW_DBG("\nbyte at 0x0C= "); DRW_DBGH(fileBuf->getRawChar8());
     previewImagePos = fileBuf->getRawLong32(); //+ page header size (0x20).
     DRW_DBG("\npreviewImagePos (seekerImageData) = "); DRW_DBG(previewImagePos);
@@ -209,7 +215,7 @@ bool dwgReader18::readFileHeader() {
         return false;
 
 //    genMagicNumber(); DBG("\n"); DBG("\n");
-    DRW_DBG("Encripted Header Data=\n");
+    DRW_DBG("Encrypted Header Data=\n");
     duint8 byteStr[0x6C];
     int size =0x6C;
     for (int i=0, j=0; i< 0x6C;i++) {
@@ -227,9 +233,9 @@ bool dwgReader18::readFileHeader() {
     DRW_DBG("\n");
 
 //    size =0x6C;
-    DRW_DBG("Decripted Header Data=\n");
+    DRW_DBG("Decrypted Header Data=\n");
     for (int i=0, j = 0; i< size;i++) {
-        DRW_DBGH( (unsigned char)byteStr[i]);
+        DRW_DBGH( static_cast<unsigned char>(byteStr[i]));
         if (j == 15) {
             DRW_DBG("\n");
             j = 0;
@@ -277,8 +283,8 @@ bool dwgReader18::readFileHeader() {
 
     DRW_DBG("\nEnd Encrypted Data. Reads 0x14 bytes, equal to magic number:\n");
     for (int i=0, j=0; i< 0x14;i++) {
-        DRW_DBG("magic num: "); DRW_DBGH( (unsigned char)DRW_magicNumEnd18[i]);
-        DRW_DBG(",read "); DRW_DBGH( (unsigned char)fileBuf->getRawChar8());
+        DRW_DBG("magic num: "); DRW_DBGH( static_cast<unsigned char>(DRW_magicNumEnd18[i]));
+        DRW_DBG(",read "); DRW_DBGH( static_cast<unsigned char>(fileBuf->getRawChar8()));
         if (j == 3) {
             DRW_DBG("\n");
             j = 0;
@@ -301,14 +307,16 @@ bool dwgReader18::readFileHeader() {
         DRW_DBG("Warning, bad page type, was expected 0x41630e3b instead of");  DRW_DBGH(pageType); DRW_DBG("\n");
         return false;
     }
-	std::vector<duint8> tmpDecompSec(decompSize);
-	parseSysPage(tmpDecompSec.data(), decompSize);
+    std::vector<duint8> tmpDecompSec(decompSize);
+    if (!parseSysPage(tmpDecompSec.data(), decompSize)) {
+        return false;
+    }
 
-//parses "Section page map" decompresed data
-	dwgBuffer buff2(tmpDecompSec.data(), decompSize, &decoder);
+//parses "Section page map" decompressed data
+    dwgBuffer buff2(tmpDecompSec.data(), decompSize, &decoder);
     duint32 address = 0x100;
-    //stores temporaly info of all pages:
-    std::map<duint32, dwgPageInfo >sectionPageMapTmp;
+    //stores temporarily info of all pages:
+    std::unordered_map<duint64, dwgPageInfo >sectionPageMapTmp;
 
     for (unsigned int i = 0; i < decompSize;) {
         dint32 id = buff2.getRawLong32();//RLZ bad can be +/-
@@ -343,12 +351,14 @@ bool dwgReader18::readFileHeader() {
         DRW_DBG("Warning, bad page type, was expected 0x4163003b instead of");  DRW_DBGH(pageType); DRW_DBG("\n");
         return false;
     }
-	tmpDecompSec.resize(decompSize);
-	parseSysPage(tmpDecompSec.data(), decompSize);
+    tmpDecompSec.resize(decompSize);
+    if (!parseSysPage(tmpDecompSec.data(), decompSize)) {
+        return false;
+    }
 
 //reads sections:
     DRW_DBG("\n*** dwgReader18: reads sections:");
-	dwgBuffer buff3(tmpDecompSec.data(), decompSize, &decoder);
+    dwgBuffer buff3(tmpDecompSec.data(), decompSize, &decoder);
     duint32 numDescriptions = buff3.getRawLong32();
     DRW_DBG("\nnumDescriptions (sections)= "); DRW_DBG(numDescriptions);
     DRW_DBG("\n0x02 long= "); DRW_DBGH(buff3.getRawLong32());
@@ -365,8 +375,8 @@ bool dwgReader18::readFileHeader() {
         secInfo.maxSize = buff3.getRawLong32();
         DRW_DBG("\nMax Decompressed Size= "); DRW_DBGH(secInfo.maxSize);
         DRW_DBG("\nunknown long= "); DRW_DBGH(buff3.getRawLong32());
-        secInfo.compresed = buff3.getRawLong32();
-        DRW_DBG("\nis Compressed? 1:no, 2:yes= "); DRW_DBGH(secInfo.compresed);
+        secInfo.compressed = buff3.getRawLong32();
+        DRW_DBG("\nis Compressed? 1:no, 2:yes= "); DRW_DBGH(secInfo.compressed);
         secInfo.Id = buff3.getRawLong32();
         DRW_DBG("\nSection Id= "); DRW_DBGH(secInfo.Id);
         secInfo.encrypted = buff3.getRawLong32();
@@ -394,7 +404,7 @@ bool dwgReader18::readFileHeader() {
             DRW_DBG("Saved section Name= "); DRW_DBG( secInfo.name.c_str() ); DRW_DBG("\n");
             sections[secEnum::getEnum(secInfo.name)] = secInfo;
         }
-	}
+    }
 
     if (! fileBuf->isGood())
         return false;
@@ -411,18 +421,18 @@ bool dwgReader18::readDwgHeader(DRW_Header& hdr){
     //global store for uncompressed data of all pages
     uncompSize=si.size;
     if (ret) {
-		dwgBuffer dataBuf(objData.data(), si.size, &decoder);
+        dwgBuffer dataBuf(objData.get(), si.size, &decoder);
         DRW_DBG("Header section sentinel= ");
         checkSentinel(&dataBuf, secEnum::HEADER, true);
         if (version == DRW::AC1018){
             ret = dwgReader::readDwgHeader(hdr, &dataBuf, &dataBuf);
         } else {
-			dwgBuffer handleBuf(objData.data(), si.size, &decoder);
+            dwgBuffer handleBuf(objData.get(), si.size, &decoder);
             ret = dwgReader::readDwgHeader(hdr, &dataBuf, &handleBuf);
         }
     }
     //Cleanup: global store for uncompressed data of all pages
-	objData.clear();
+    objData.reset();
     return ret;
 }
 
@@ -430,38 +440,45 @@ bool dwgReader18::readDwgHeader(DRW_Header& hdr){
 bool dwgReader18::readDwgClasses(){
     DRW_DBG("\ndwgReader18::readDwgClasses\n");
     dwgSectionInfo si = sections[secEnum::CLASSES];
-    if (si.Id<0)//not found, ends
+    if (si.Id < 0) //not found, ends
         return false;
-    bool ret = parseDataPage(si/*, objData*/);
+    if (!parseDataPage(si/*, objData*/)) {
+        return false;
+    }
+
     //global store for uncompressed data of all pages
     uncompSize=si.size;
-    if (ret) {
-
-	dwgBuffer dataBuf(objData.data(), uncompSize, &decoder);
+    dwgBuffer dataBuf(objData.get(), uncompSize, &decoder);
 
     DRW_DBG("classes section sentinel= ");
     checkSentinel(&dataBuf, secEnum::CLASSES, true);
 
     duint32 size = dataBuf.getRawLong32();
     DRW_DBG("\ndata size in bytes "); DRW_DBG(size);
-    if (version > DRW::AC1021 && maintenanceVersion > 3) { //2010+
+    if ((DRW::AC1024 <= version && 3 < maintenanceVersion)
+        || DRW::AC1032 <= version) { //2010+
         duint32 hSize = dataBuf.getRawLong32();
-        DRW_DBG("\n2010+ & MV> 3, higth 32b: "); DRW_DBG(hSize);
+        DRW_DBG("\n2010+ & MV> 3, height 32b: "); DRW_DBG(hSize);
     }
     duint32 bitSize = 0;
     if (version > DRW::AC1021) {//2007+
-    bitSize = dataBuf.getRawLong32();
-    DRW_DBG("\ntotal size in bits "); DRW_DBG(bitSize);
-}
+        bitSize = dataBuf.getRawLong32();
+        DRW_DBG("\ntotal size in bits "); DRW_DBG(bitSize);
+    }
     duint32 maxClassNum = dataBuf.getBitShort();
     DRW_DBG("\nMaximum class number "); DRW_DBG(maxClassNum);
     DRW_DBG("\nRc 1 "); DRW_DBG(dataBuf.getRawChar8());
     DRW_DBG("\nRc 2 "); DRW_DBG(dataBuf.getRawChar8());
     DRW_DBG("\nBit "); DRW_DBG(dataBuf.getBit());
+    if (499 >= maxClassNum) {
+        // maxClassNum is later reduced by 499, so smaller values seem to be invalid
+        // no documentation about the value of 499 found yet
+        return false;
+    }
 
     /*******************************/
     dwgBuffer *strBuf = &dataBuf;
-	dwgBuffer strBuff(objData.data(), uncompSize, &decoder);
+    dwgBuffer strBuff(objData.get(), uncompSize, &decoder);
     //prepare string stream for 2007+
     if (version > DRW::AC1021) {//2007+
         strBuf = &strBuff;
@@ -521,11 +538,10 @@ bool dwgReader18::readDwgClasses(){
     DRW_DBG("\nclasses section end sentinel= ");
     checkSentinel(strBuf, secEnum::CLASSES, false);
 
-    ret = strBuf->isGood();
-    }
     //Cleanup: global store for uncompressed data of all pages
-	objData.clear();
-    return ret;
+    objData.reset();
+
+    return strBuf->isGood();
 }
 
 
@@ -541,16 +557,23 @@ bool dwgReader18::readDwgHandles() {
     dwgSectionInfo si = sections[secEnum::HANDLES];
     if (si.Id<0)//not found, ends
         return false;
-    bool ret = parseDataPage(si);
+
+    if (!parseDataPage(si)) {
+        return false;
+    }
+
     //global store for uncompressed data of all pages
     uncompSize=si.size;
-    if (ret) {
-		dwgBuffer dataBuf(objData.data(), uncompSize, &decoder);
+    dwgBuffer dataBuf(objData.get(), uncompSize, &decoder);
+
+    bool ret {dwgReader::readDwgHandles(&dataBuf, 0, si.size)};
 
-        ret = dwgReader::readDwgHandles(&dataBuf, 0, si.size);
-    }
     //Cleanup: global store for uncompressed data of all pages
-	objData.clear();
+    if (objData){
+        objData.reset();
+        uncompSize = 0;
+    }
+
     return ret;
 }
 
@@ -564,20 +587,16 @@ bool dwgReader18::readDwgTables(DRW_Header& hdr) {
     DRW_DBG("\ndwgReader18::readDwgTables\n");
     dwgSectionInfo si = sections[secEnum::OBJECTS];
 
-    if (si.Id<0)//not found, ends
+    if (si.Id < 0   //not found, ends
+        || !parseDataPage( si/*, objData*/)) {
         return false;
-    bool ret = parseDataPage(si/*, objData*/);
+    }
+
     //global store for uncompressed data of all pages
     uncompSize=si.size;
-    if (ret) {
+    dwgBuffer dataBuf(objData.get(), uncompSize, &decoder);
 
-		dwgBuffer dataBuf(objData.data(), uncompSize, &decoder);
-
-        ret = dwgReader::readDwgTables(hdr, &dataBuf);
-
-    }
     //Do not delete objData in this point, needed in the remaining code
-    return ret;
+
+    return dwgReader::readDwgTables(hdr, &dataBuf);
 }
-
-
