@@ -13,8 +13,6 @@
 #ifndef DWGREADER27_H
 #define DWGREADER27_H
 
-#include <map>
-#include <list>
 #include "drw_textcodec.h"
 #include "dwgbuffer.h"
 #include "dwgreader18.h"
@@ -22,26 +20,26 @@
 class dwgReader27 : public dwgReader18 {
 public:
     dwgReader27(std::ifstream *stream, dwgR *p):dwgReader18(stream, p){ }
-	bool readFileHeader() override;
-	bool readDwgHeader(DRW_Header& hdr) override;
-	bool readDwgClasses() override;
+    bool readFileHeader() override;
+    bool readDwgHeader(DRW_Header& hdr) override;
+    bool readDwgClasses() override;
 //    bool readDwgHandles(){return false;}
 //    bool readDwgTables(){return false;}
-	bool readDwgBlocks(DRW_Interface& intfa) override{
+    bool readDwgBlocks(DRW_Interface& intfa) override {
         bool ret = true;
-		dwgBuffer dataBuf(objData.data(), uncompSize, &decoder);
+        dwgBuffer dataBuf(objData.get(), uncompSize, &decoder);
         ret = dwgReader::readDwgBlocks(intfa, &dataBuf);
         return ret;
     }
-	virtual bool readDwgEntities(DRW_Interface& intfa) override{
+    bool readDwgEntities(DRW_Interface& intfa) override {
         bool ret = true;
-		dwgBuffer dataBuf(objData.data(), uncompSize, &decoder);
+        dwgBuffer dataBuf(objData.get(), uncompSize, &decoder);
         ret = dwgReader::readDwgEntities(intfa, &dataBuf);
         return ret;
     }
-	virtual bool readDwgObjects(DRW_Interface& intfa) override{
+    bool readDwgObjects(DRW_Interface& intfa) override {
         bool ret = true;
-		dwgBuffer dataBuf(objData.data(), uncompSize, &decoder);
+        dwgBuffer dataBuf(objData.get(), uncompSize, &decoder);
         ret = dwgReader::readDwgObjects(intfa, &dataBuf);
         return ret;
     }
@@ -51,4 +49,4 @@ public:
 //        return false;}
 };
 
-#endif // DWGREADER21_H
+#endif // DWGREADER27_H
