@@ -43,15 +43,16 @@ public:
     unsigned long long int getInt64() {return int64;}
     bool getBool() { return (intData==0) ? false : true;}
     int getVersion(){return decoder.getVersion();}
-    void setVersion(std::string *v, bool dxfFormat){decoder.setVersion(v, dxfFormat);}
-    void setCodePage(std::string *c){decoder.setCodePage(c, true);}
+    void setVersion(const std::string &v, bool dxfFormat){decoder.setVersion(v, dxfFormat);}
+    void setCodePage(const std::string &c){decoder.setCodePage(c, true);}
     std::string getCodePage(){ return decoder.getCodePage();}
-    void setIgnoreComments( const bool bValue) { m_bIgnoreComments = bValue;};
+    void setIgnoreComments(const bool bValue) {m_bIgnoreComments = bValue;}
 
 protected:
-    virtual bool readCode(int *code) = 0; //return true if sucesful (not EOF)
+    virtual bool readCode(int *code) = 0; //return true if successful (not EOF)
     virtual bool readString(std::string *text) = 0;
     virtual bool readString() = 0;
+    virtual bool readBinary() = 0;
     virtual bool readInt16() = 0;
     virtual bool readInt32() = 0;
     virtual bool readInt64() = 0;
@@ -77,6 +78,7 @@ public:
     virtual bool readCode(int *code);
     virtual bool readString(std::string *text);
     virtual bool readString();
+    virtual bool readBinary();
     virtual bool readInt16();
     virtual bool readInt32();
     virtual bool readInt64();
@@ -91,6 +93,7 @@ public:
     virtual bool readCode(int *code);
     virtual bool readString(std::string *text);
     virtual bool readString();
+    virtual bool readBinary();
     virtual bool readInt16();
     virtual bool readDouble();
     virtual bool readInt32();
