@@ -30,12 +30,9 @@ class LC_ActionFileExportMakerCam : public RS_ActionInterface {
     Q_OBJECT
 public:
 	LC_ActionFileExportMakerCam(RS_EntityContainer& container, RS_GraphicView& graphicView);
-	~LC_ActionFileExportMakerCam() = default;
 
-	static QAction* createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/);
-
-    virtual void init(int status=0);
-    virtual void trigger();
+	void init(int status=0) override;
+	void trigger() override;
 
 };
 
