@@ -51,6 +51,8 @@ public:
 protected:
     RS_Layer* a_layer;
 
+private:
+    void deselectEntities(RS_Layer* layer);
 };
 
 #endif
