@@ -28,6 +28,8 @@
 
 #include "rs_dialogfactory.h"
 #include "rs_graphicview.h"
+#include "rs_line.h"
+#include "rs_coordinateevent.h"
 #include "rs_commandevent.h"
 #include "rs_modification.h"
 #include "rs_selection.h"
@@ -35,6 +37,8 @@
 #include "rs_preview.h"
 #include "rs_debug.h"
 
+#include <cmath>
+
 struct RS_ActionDefault::Points {
 	RS_Vector v1;
 	RS_Vector v2;
@@ -66,7 +70,7 @@ void RS_ActionDefault::init(int status) {
         deleteSnapper();
     }
     RS_PreviewActionInterface::init(status);
-	pPoints->v1 = pPoints->v2 = {};
+    pPoints->v1 = pPoints->v2 = {};
     //    snapMode.clear();
     //    snapMode.restriction = RS2::RestrictNothing;
     //    restrBak = RS2::RestrictNothing;
@@ -82,7 +86,7 @@ void RS_ActionDefault::keyPressEvent(QKeyEvent* e) {
         restrBak = snapMode.restriction;
         setSnapRestriction(RS2::RestrictOrthogonal);
         e->accept();
-		break; //avoid clearing command line at shift key
+        break; //avoid clearing command line at shift key
         //cleanup default action, issue#285
     case Qt::Key_Escape:
         //        std::cout<<"RS_ActionDefault::keyPressEvent(): Qt::Key_Escape"<<std::endl;
@@ -90,6 +94,7 @@ void RS_ActionDefault::keyPressEvent(QKeyEvent* e) {
         deleteSnapper();
         setStatus(Neutral);
         e->accept();
+        break;
     default:
         e->ignore();
     }
@@ -155,10 +160,21 @@ void RS_ActionDefault::mouseMoveEvent(QMouseEvent* e) {
 		pPoints->v2 = snapPoint(e);
 		RS_DIALOGFACTORY->updateCoordinateWidget(pPoints->v2, pPoints->v2 - graphicView->getRelativeZero());
 
+        if (e->modifiers() & Qt::ShiftModifier) {
+            mouse = snapToAngle(mouse, pPoints->v1, 15.);
+            pPoints->v2 = mouse;
+        }
 
         deletePreview();
         preview->addSelectionFrom(*container);
 		preview->moveRef(pPoints->v1, pPoints->v2 - pPoints->v1);
+
+        if (e->modifiers() & Qt::ShiftModifier) {
+            RS_Line *line = new RS_Line(pPoints->v1, mouse);
+            preview->addEntity(line);
+            line->setSelected(true);
+        }
+
         drawPreview();
         break;
 
@@ -166,9 +182,21 @@ void RS_ActionDefault::mouseMoveEvent(QMouseEvent* e) {
 		pPoints->v2 = snapPoint(e);
 		RS_DIALOGFACTORY->updateCoordinateWidget(pPoints->v2, pPoints->v2 - graphicView->getRelativeZero());
 
+        if (e->modifiers() & Qt::ShiftModifier) {
+            mouse = snapToAngle(mouse, pPoints->v1, 15.);
+            pPoints->v2 = mouse;
+        }
+
         deletePreview();
         preview->addSelectionFrom(*container);
 		preview->move(pPoints->v2 - pPoints->v1);
+
+        if (e->modifiers() & Qt::ShiftModifier) {
+            RS_Line *line = new RS_Line(pPoints->v1, mouse);
+            preview->addEntity(line);
+            line->setSelected(true);
+        }
+
         drawPreview();
         break;
 
@@ -221,6 +249,9 @@ void RS_ActionDefault::mousePressEvent(QMouseEvent* e) {
 
         case Moving: {
 			pPoints->v2 = snapPoint(e);
+            if (e->modifiers() & Qt::ShiftModifier) {
+                pPoints->v2 = snapToAngle(pPoints->v2, pPoints->v1, 15.);
+            }
             deletePreview();
             RS_Modification m(*container, graphicView);
             RS_MoveData data;
@@ -238,6 +269,9 @@ void RS_ActionDefault::mousePressEvent(QMouseEvent* e) {
 
         case MovingRef: {
 			pPoints->v2 = snapPoint(e);
+            if (e->modifiers() & Qt::ShiftModifier) {
+                pPoints->v2 = snapToAngle(pPoints->v2, pPoints->v1, 15.);
+            }
             deletePreview();
             RS_Modification m(*container, graphicView);
             RS_MoveRefData data;
