@@ -55,31 +55,29 @@ public:
 public:
     RS_ActionDefault(RS_EntityContainer& container,
                      RS_GraphicView& graphicView);
-	virtual ~RS_ActionDefault() = default;
+	~RS_ActionDefault() override;
 
-    static QAction* createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/);
+	void finish(bool /*updateTB*/ = true ) override{}
 
-	virtual void finish(bool /*updateTB*/ = true ){}
+	void init(int status=0) override;
 
-    virtual void init(int status=0);
+	void keyPressEvent(QKeyEvent* e) override;
+	void keyReleaseEvent(QKeyEvent* e) override;
 
-    virtual void keyPressEvent(QKeyEvent* e);
-    virtual void keyReleaseEvent(QKeyEvent* e);
+	void mouseMoveEvent(QMouseEvent* e) override;
+	void mousePressEvent(QMouseEvent* e) override;
+	void mouseReleaseEvent(QMouseEvent* e) override;
 
-    virtual void mouseMoveEvent(QMouseEvent* e);
-    virtual void mousePressEvent(QMouseEvent* e);
-    virtual void mouseReleaseEvent(QMouseEvent* e);
+	void commandEvent(RS_CommandEvent* e) override;
+	QStringList getAvailableCommands() override;
 
-    virtual void commandEvent(RS_CommandEvent* e);
-    virtual QStringList getAvailableCommands();
-
-    virtual void updateMouseButtonHints();
-    virtual void updateMouseCursor();
-//    virtual void resume();
+	void updateMouseButtonHints() override;
+	void updateMouseCursor() override;
+//    void resume() override;
 
 protected:
-    RS_Vector v1;
-    RS_Vector v2;
+	struct Points;
+	std::unique_ptr<Points> pPoints;
     RS2::SnapRestriction restrBak;
 
 };
