@@ -48,32 +48,30 @@ private:
 public:
     RS_ActionDimDiametric(RS_EntityContainer& container,
                               RS_GraphicView& graphicView);
-	~RS_ActionDimDiametric();
+	~RS_ActionDimDiametric() override;
 
-	static QAction* createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/);
-
-	virtual void reset();
+	void reset() override;
 	
-    virtual void trigger();
+	void trigger() override;
 	void preparePreview();
 	
-    virtual void mouseMoveEvent(QMouseEvent* e);
-    virtual void mouseReleaseEvent(QMouseEvent* e);
+	void mouseMoveEvent(QMouseEvent* e) override;
+	void mouseReleaseEvent(QMouseEvent* e) override;
 	
-	virtual void coordinateEvent(RS_CoordinateEvent* e);
-    virtual void commandEvent(RS_CommandEvent* e);
-        virtual QStringList getAvailableCommands();
+	void coordinateEvent(RS_CoordinateEvent* e) override;
+	void commandEvent(RS_CommandEvent* e) override;
+		QStringList getAvailableCommands() override;
 
-    virtual void hideOptions();
-    virtual void showOptions();
+	void hideOptions() override;
+	void showOptions() override;
 	
-    virtual void updateMouseButtonHints();
+	void updateMouseButtonHints() override;
 
 private:
     /** Chosen entity (arc / circle) */
     RS_Entity* entity;
 	/** Chosen position */
-	RS_Vector pos;
+	std::unique_ptr<RS_Vector> pos;
     /** Data of new dimension */
 	std::unique_ptr<RS_DimDiametricData> edata;
 	/** Last status before entering text. */
