@@ -77,6 +77,9 @@ protected:
 private:
 	struct Points;
 	std::unique_ptr<Points> pPoints;
+
+    //list of entity types supported by current action
+    const EntityTypeList enTypeList = EntityTypeList{RS2::EntityLine, RS2::EntityArc, RS2::EntityCircle};
 };
 
 #endif
