@@ -20,8 +20,8 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **********************************************************************/
 
-#ifndef RS_ACTIONDRAWCIRCLETAN1_2P_H
-#define RS_ACTIONDRAWCIRCLETAN1_2P_H
+#ifndef RS_ACTIONDRAWCIRCLETAN2_1P_H
+#define RS_ACTIONDRAWCIRCLETAN2_1P_H
 
 #include "rs_previewactioninterface.h"
 
@@ -29,26 +29,27 @@ class RS_AtomicEntity;
 struct RS_CircleData;
 
 /**
- * Draw tangential circle passing 2 points
+ * Given two circles and a point, draw a common tangent circle passing the point
  *
  * @author Dongxu Li
  */
-class RS_ActionDrawCircleTan1_2P : public RS_PreviewActionInterface {
+class RS_ActionDrawCircleTan2_1P : public RS_PreviewActionInterface {
         Q_OBJECT
+public:
     /**
      * Action States.
      */
     enum Status {
-        SetCircle1=0,   //  Setting the First Circle.  */
-        SetPoint1=1,   //  Setting the First Point.  */
-        SetPoint2=2,   //  Setting the Second Point.  */
-        SetCenter   //  Setting the internal or external tangent circle's center.  */
+        SetCircle1=0,   //  Setting the first circle.  */
+        SetCircle2=1,   //  Setting the second circle.  */
+        SetPoint=2,   //  Setting point on the desired circle.  */
+        SetCenter
     };
 
 public:
-    RS_ActionDrawCircleTan1_2P(RS_EntityContainer& container,
+    RS_ActionDrawCircleTan2_1P(RS_EntityContainer& container,
                                  RS_GraphicView& graphicView);
-	~RS_ActionDrawCircleTan1_2P() override;
+	~RS_ActionDrawCircleTan2_1P() override;
 
 	void init(int status=0) override;
 
@@ -59,26 +60,22 @@ public:
 	void mouseMoveEvent(QMouseEvent* e) override;
 	void mouseReleaseEvent(QMouseEvent* e) override;
 
-			void coordinateEvent(RS_CoordinateEvent* e) override;
+	void coordinateEvent(RS_CoordinateEvent* e) override;
 //        void commandEvent(RS_CommandEvent* e) override;
 	QStringList getAvailableCommands() override;
 	void finish(bool updateTB=true) override;
 	void updateMouseButtonHints() override;
 	void updateMouseCursor() override;
 
-//    void showOptions() override;
-//    void hideOptions() override;
-//    void setRadius(const double& r);
-	double getRadius() const;
-
 
 protected:
     RS_Entity* catchCircle(QMouseEvent* e);
-	RS_AtomicEntity* circle;
-
 private:
 	struct Points;
 	std::unique_ptr<Points> pPoints;
+
+    //list of entity types supported by current action
+    const EntityTypeList enTypeList = EntityTypeList {RS2::EntityLine, RS2::EntityArc, RS2::EntityCircle};
 };
 
 #endif
