@@ -66,6 +66,12 @@ private:
 	std::unique_ptr<RS_Vector> point;
     /** Chosen entity */
     RS_Entity* circle;
+
+    //list of entity types supported by current action
+    const EntityTypeList circleType = EntityTypeList{ RS2::EntityArc,
+                RS2::EntityCircle,
+                RS2::EntityEllipse,
+                RS2::EntitySplinePoints };
 };
 
 #endif
