@@ -68,6 +68,9 @@ private:
     /** 2nd chosen entity */
     RS_Entity* circle2;
     bool valid;
+
+    //list of entity types supported by current action
+    const EntityTypeList circleType = EntityTypeList{RS2::EntityArc, RS2::EntityCircle, RS2::EntityEllipse};
 };
 
 #endif
