@@ -39,41 +39,32 @@ RS_ActionModifyCut::RS_ActionModifyCut(RS_EntityContainer& container,
         :RS_ActionInterface("Cut Entity",
 					container, graphicView)
 ,cutEntity(nullptr)
-,cutCoord(false)
+,cutCoord(new RS_Vector{})
 {
 	actionType=RS2::ActionModifyCut;
 }
 
-QAction* RS_ActionModifyCut::createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/) {
-        // tr("Divide")
-        QAction *action = new QAction(tr("&Divide"), NULL);
-        action->setIcon(QIcon(":/extui/modifycut.png"));
-        //action->zetStatusTip(tr("Cut Entities"));
-    return action;
-}
-
+RS_ActionModifyCut::~RS_ActionModifyCut() = default;
 
 void RS_ActionModifyCut::init(int status) {
     RS_ActionInterface::init(status);
 }
 
-
-
 void RS_ActionModifyCut::trigger() {
 
     RS_DEBUG->print("RS_ActionModifyCut::trigger()");
 
-    if (cutEntity && cutEntity->isAtomic() && cutCoord.valid &&
-            cutEntity->isPointOnEntity(cutCoord)) {
+	if (cutEntity && cutEntity->isAtomic() && cutCoord->valid &&
+			cutEntity->isPointOnEntity(*cutCoord)) {
 
         cutEntity->setHighlighted(false);
         graphicView->drawEntity(cutEntity);
 
         RS_Modification m(*container, graphicView);
-        m.cut(cutCoord, (RS_AtomicEntity*)cutEntity);
+		m.cut(*cutCoord, (RS_AtomicEntity*)cutEntity);
 
-        cutEntity = NULL;
-        cutCoord = RS_Vector(false);
+		cutEntity = nullptr;
+		*cutCoord = RS_Vector(false);
         setStatus(ChooseCutEntity);
 
         RS_DIALOGFACTORY->updateSelectionWidget(container->countSelected(),container->totalSelectedLength());
@@ -107,7 +98,7 @@ void RS_ActionModifyCut::mouseReleaseEvent(QMouseEvent* e) {
         switch (getStatus()) {
         case ChooseCutEntity:
             cutEntity = catchEntity(e);
-            if (cutEntity==NULL) {
+			if (cutEntity==nullptr) {
                 RS_DIALOGFACTORY->commandMessage(tr("No Entity found."));
             } else if(cutEntity->trimmable()){
                 cutEntity->setHighlighted(true);
@@ -119,12 +110,12 @@ void RS_ActionModifyCut::mouseReleaseEvent(QMouseEvent* e) {
             break;
 
         case SetCutCoord:
-            cutCoord = snapPoint(e);
-            if (cutEntity==NULL) {
+			*cutCoord = snapPoint(e);
+			if (cutEntity==nullptr) {
                 RS_DIALOGFACTORY->commandMessage(tr("No Entity found."));
-            } else if (!cutCoord.valid) {
+			} else if (!cutCoord->valid) {
                 RS_DIALOGFACTORY->commandMessage(tr("Cutting point is invalid."));
-            } else if (!cutEntity->isPointOnEntity(cutCoord)) {
+			} else if (!cutEntity->isPointOnEntity(*cutCoord)) {
                 RS_DIALOGFACTORY->commandMessage(
                     tr("Cutting point is not on entity."));
             } else {
@@ -165,8 +156,18 @@ void RS_ActionModifyCut::updateMouseButtonHints() {
 
 
 
-void RS_ActionModifyCut::updateMouseCursor() {
-    graphicView->setMouseCursor(RS2::CadCursor);
+void RS_ActionModifyCut::updateMouseCursor()
+{
+    switch (getStatus()) {
+    case ChooseCutEntity:
+        graphicView->setMouseCursor(RS2::SelectCursor);
+        break;
+    case SetCutCoord:
+        graphicView->setMouseCursor(RS2::CadCursor);
+        break;
+    default:
+        break;
+    }
 }
 
 // EOF
