@@ -26,15 +26,19 @@
 
 #include "rs_actionmodifymove.h"
 
-#include <QAction>
-#include <QMouseEvent>
 #include "rs_dialogfactory.h"
 #include "rs_graphicview.h"
+#include "rs_line.h"
 #include "rs_coordinateevent.h"
 #include "rs_modification.h"
 #include "rs_preview.h"
 #include "rs_debug.h"
 
+#include <QAction>
+#include <QMouseEvent>
+
+#include <cmath>
+
 struct RS_ActionModifyMove::Points {
 	RS_MoveData data;
 	RS_Vector referencePoint;
@@ -64,13 +68,10 @@ void RS_ActionModifyMove::trigger() {
 }
 
 
-
 void RS_ActionModifyMove::mouseMoveEvent(QMouseEvent* e) {
     RS_DEBUG->print("RS_ActionModifyMove::mouseMoveEvent begin");
 
-    if (getStatus()==SetReferencePoint ||
-            getStatus()==SetTargetPoint) {
-
+    if (getStatus()==SetReferencePoint || getStatus()==SetTargetPoint) {
         RS_Vector mouse = snapPoint(e);
         switch (getStatus()) {
         case SetReferencePoint:
@@ -78,12 +79,24 @@ void RS_ActionModifyMove::mouseMoveEvent(QMouseEvent* e) {
             break;
 
         case SetTargetPoint:
-			if (pPoints->referencePoint.valid) {
+            if (pPoints->referencePoint.valid) {
+                if (e->modifiers() & Qt::ShiftModifier) {
+                    mouse = snapToAngle(mouse, pPoints->referencePoint, 15.);
+                }
+
 				pPoints->targetPoint = mouse;
 
                 deletePreview();
                 preview->addSelectionFrom(*container);
 				preview->move(pPoints->targetPoint-pPoints->referencePoint);
+
+                if (e->modifiers() & Qt::ShiftModifier) {
+                    RS_Line *line = new RS_Line(pPoints->referencePoint, mouse);
+                    preview->addEntity(line);
+                    line->setSelected(true);
+                    line->setLayerToActive();
+                    line->setPenToActive();
+                }
                 drawPreview();
             }
             break;
@@ -97,10 +110,13 @@ void RS_ActionModifyMove::mouseMoveEvent(QMouseEvent* e) {
 }
 
 
-
 void RS_ActionModifyMove::mouseReleaseEvent(QMouseEvent* e) {
     if (e->button()==Qt::LeftButton) {
-        RS_CoordinateEvent ce(snapPoint(e));
+        RS_Vector snapped = snapPoint(e);
+        if((e->modifiers() & Qt::ShiftModifier) && getStatus() == SetTargetPoint )
+            snapped = snapToAngle(snapped, pPoints->referencePoint, 15.);
+
+        RS_CoordinateEvent ce(snapped);
         coordinateEvent(&ce);
     } else if (e->button()==Qt::RightButton) {
         deletePreview();
@@ -108,6 +124,7 @@ void RS_ActionModifyMove::mouseReleaseEvent(QMouseEvent* e) {
     }
 }
 
+
 void RS_ActionModifyMove::coordinateEvent(RS_CoordinateEvent* e) {
 
     if (e==NULL) {
@@ -164,7 +181,6 @@ void RS_ActionModifyMove::updateMouseButtonHints() {
 }
 
 
-
 void RS_ActionModifyMove::updateMouseCursor() {
         if(graphicView != NULL){
     graphicView->setMouseCursor(RS2::CadCursor);
