@@ -31,6 +31,7 @@
 #include "rs_dialogfactory.h"
 #include "rs_graphicview.h"
 #include "rs_modification.h"
+#include "rs_preview.h"
 #include "rs_debug.h"
 
 RS_ActionModifyOffset::RS_ActionModifyOffset(RS_EntityContainer& container,
@@ -49,11 +50,6 @@ RS_ActionModifyOffset::RS_ActionModifyOffset(RS_EntityContainer& container,
 
 RS_ActionModifyOffset::~RS_ActionModifyOffset() = default;
 
-QAction* RS_ActionModifyOffset::createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/) {
-	QAction* action = new QAction(QIcon(":/extui/arcspara.png"), tr("&Offset"),nullptr);
-    return action;
-}
-
 void RS_ActionModifyOffset::init(int status) {
     RS_ActionInterface::init(status);
     //finish, if nothing selected
@@ -64,12 +60,9 @@ void RS_ActionModifyOffset::init(int status) {
 void RS_ActionModifyOffset::trigger() {
     RS_Modification m(*container, graphicView);
 	m.offset(*data);
-    if (RS_DIALOGFACTORY) {
-        RS_DIALOGFACTORY->requestToolBar(RS2::ToolBarModify);
-		RS_DIALOGFACTORY->updateSelectionWidget(container->countSelected(),
-												container->totalSelectedLength());
-    }
-    finish(false);
+	RS_DIALOGFACTORY->updateSelectionWidget(container->countSelected(),
+											container->totalSelectedLength());
+	finish(false);
 }
 
 
@@ -103,32 +96,26 @@ void RS_ActionModifyOffset::mouseReleaseEvent(QMouseEvent* e) {
 }
 
 void RS_ActionModifyOffset::updateMouseButtonHints() {
-    if (RS_DIALOGFACTORY) {
-        switch (getStatus()) {
-        case SetPosition:
-            RS_DIALOGFACTORY->updateMouseWidget(tr("Specify direction of offset"), tr("Back"));
-            break;
+	switch (getStatus()) {
+	case SetPosition:
+		RS_DIALOGFACTORY->updateMouseWidget(tr("Specify direction of offset"), tr("Back"));
+		break;
 
-        default:
-			RS_DIALOGFACTORY->updateMouseWidget();
-            break;
-        }
-    }
+	default:
+		RS_DIALOGFACTORY->updateMouseWidget();
+		break;
+	}
 }
 
 void RS_ActionModifyOffset::showOptions() {
     RS_ActionInterface::showOptions();
-    if (RS_DIALOGFACTORY) {
-		RS_DIALOGFACTORY->requestModifyOffsetOptions(data->distance, true);
-    }
+	RS_DIALOGFACTORY->requestModifyOffsetOptions(data->distance, true);
 }
 
 void RS_ActionModifyOffset::hideOptions() {
     RS_ActionInterface::hideOptions();
 
-    if (RS_DIALOGFACTORY) {
-		RS_DIALOGFACTORY->requestModifyOffsetOptions(data->distance, false);
-    }
+	RS_DIALOGFACTORY->requestModifyOffsetOptions(data->distance, false);
 }
 
 void RS_ActionModifyOffset::updateMouseCursor() {
