@@ -46,22 +46,20 @@ public:
 public:
 	RS_ActionPolylineEquidistant(RS_EntityContainer& container,
 						RS_GraphicView& graphicView);
-	~RS_ActionPolylineEquidistant()=default;
+	~RS_ActionPolylineEquidistant() override;
 
-	static QAction* createGUIAction(RS2::ActionType /*type*/, QObject* /*parent*/);
-
-	virtual void init(int status=0);
+	void init(int status=0) override;
 	
-	virtual void trigger();
+	void trigger() override;
 
-//        virtual void mouseMoveEvent(QMouseEvent* e);
-        virtual void mouseReleaseEvent(QMouseEvent* e);
+//        void mouseMoveEvent(QMouseEvent* e) override;
+		void mouseReleaseEvent(QMouseEvent* e) override;
 	
-	virtual void updateMouseButtonHints();
-	virtual void updateMouseCursor();
-//	virtual void updateToolBar();
-	virtual void showOptions();
-	virtual void hideOptions();
+	void updateMouseButtonHints() override;
+	void updateMouseCursor() override;
+//	void updateToolBar() override;
+	void showOptions() override;
+	void hideOptions() override;
 
     void setDist(const double& d) {
 		dist = d;
@@ -87,7 +85,7 @@ private:
 
 private:
 	RS_Entity* originalEntity;
-	RS_Vector targetPoint;
+	std::unique_ptr<RS_Vector> targetPoint;
 	double dist;
 	int number;
 	bool bRightSide;
