@@ -62,7 +62,12 @@ void RS_ActionZoomPan::trigger() {
         x1 = x2;
         y1 = y2;
     }
-    if(getStatus()==SetPanEnd) finish(false);
+    if(getStatus()==SetPanEnd)
+    {
+        finish(false);
+        graphicView->setPanning(false);
+        graphicView->redraw();
+    }
 }
 
 
@@ -81,24 +86,28 @@ void RS_ActionZoomPan::mouseMoveEvent(QMouseEvent* e) {
 
 
 void RS_ActionZoomPan::mousePressEvent(QMouseEvent* e) {
-#if QT_VERSION < 0x040700
-    if (e->button()==Qt::MidButton ||
-#else
     if (e->button()==Qt::MiddleButton ||
-#endif
             e->button()==Qt::LeftButton) {
         //v1 = snapPoint(e);
         x1 = e->x();
         y1 = e->y();
         setStatus(SetPanning);
+        graphicView->setPanning(true);
     }
 }
 
 
 
-void RS_ActionZoomPan::mouseReleaseEvent(QMouseEvent* /*e*/) {
-        setStatus(SetPanEnd);
-        trigger();
+void RS_ActionZoomPan::mouseReleaseEvent(QMouseEvent* e) {
+	switch (e->button()) {
+	case Qt::MiddleButton:
+	case Qt::RightButton:
+		setStatus(SetPanEnd);
+		break;
+	default:
+		setStatus(SetPanStart);
+	}
+	trigger();
     //RS_DEBUG->print("RS_ActionZoomPan::mousePressEvent(): %f %f", v1.x, v1.y);
 }
 
