@@ -590,8 +590,8 @@ RS_Commands::RS_Commands() {
         {"columnspacing",QObject::tr("columnspacing")},
         {"factor",QObject::tr("factor")},
         {"length",QObject::tr("length")},
-        {"length1",QObject::tr("length1", "bevel/fillet lenght1")},
-        {"length2",QObject::tr("length2", "bevel/fillet lenght2")},
+        {"length1",QObject::tr("length1", "bevel/fillet length1")},
+        {"length2",QObject::tr("length2", "bevel/fillet length2")},
         {"number",QObject::tr("number")},
         {"radius",QObject::tr("radius")},
         {"rows",QObject::tr("rows")},
@@ -697,7 +697,7 @@ void RS_Commands::updateAlias(){
     if (aliasName.isEmpty())
         return;
     aliasName += "/librecad.alias";
-//    qDebug()<<"alisa file:\t"<<aliasName;
+//    qDebug()<<"alias file:\t"<<aliasName;
     QFile f(aliasName);
     QString line;
     std::map<QString, QString> aliasList;
@@ -746,7 +746,7 @@ void RS_Commands::updateAlias(){
 
     }
     //update alias file with non present commands
-//RLZ: to be writen
+//RLZ: to be written
 
     //add alias to shortCommands
     for(auto const& p: aliasList){
@@ -851,7 +851,7 @@ RS2::ActionType RS_Commands::keycodeToAction(const QString& code) {
         //not found, searching for main commands
         it = mainCommands.find(c);
         if( it == mainCommands.end() ){
-			RS_DIALOGFACTORY->commandMessage(QObject::tr("Command not found: %1").arg(c));
+//			RS_DIALOGFACTORY->commandMessage(QObject::tr("Command not found: %1").arg(c));
             return RS2::ActionNone;
         }
     }
