@@ -44,10 +44,7 @@
 #include "rs_solid.h"
 #include "rs_information.h"
 #include "rs_graphicview.h"
-
-#if QT_VERSION < 0x040400
-#include "emu_qt44.h"
-#endif
+#include "rs_constructionline.h"
 
 bool RS_EntityContainer::autoUpdateBorders = true;
 
@@ -85,7 +82,11 @@ RS_EntityContainer::RS_EntityContainer(const RS_EntityContainer& ec)
  * Destructor.
  */
 RS_EntityContainer::~RS_EntityContainer() {
-    clear();
+    if (autoDelete) {
+        while (!entities.isEmpty())
+            delete entities.takeFirst();
+    } else
+        entities.clear();
 }
 
 
@@ -151,19 +152,6 @@ void RS_EntityContainer::reparent(RS_EntityContainer* parent) {
 
 
 
-/**
- * Called when the undo state changed. Forwards the event to all sub-entities.
- *
- * @param undone true: entity has become invisible.
- *               false: entity has become visible.
- */
-//void RS_EntityContainer::undoStateChanged(bool undone) {
-
-//    RS_Entity::undoStateChanged(undone);
-//}
-
-
-
 void RS_EntityContainer::setVisible(bool v) {
     //    RS_DEBUG->print("RS_EntityContainer::setVisible: %d", v);
     RS_Entity::setVisible(v);
@@ -441,11 +429,7 @@ bool RS_EntityContainer::removeEntity(RS_Entity* entity) {
     //    and sets 'entIdx' in next() or last() if 'entity' is the last item in the list.
 	//    in LibreCAD is never called with nullptr
     bool ret;
-#if QT_VERSION < 0x040400
-    ret = emu_qt44_removeOne(entities, entity);
-#else
     ret = entities.removeOne(entity);
-#endif
 
     if (autoDelete && ret) {
         delete entity;
@@ -587,7 +571,7 @@ void RS_EntityContainer::calculateBorders() {
         maxV.y = 0.0;
     }
 
-    RS_DEBUG->print("RS_EntityCotnainer::calculateBorders: size: %f,%f",
+    RS_DEBUG->print("RS_EntityContainer::calculateBorders: size: %f,%f",
                     getSize().x, getSize().y);
 
     //RS_DEBUG->print("  borders: %f/%f %f/%f", minV.x, minV.y, maxV.x, maxV.y);
@@ -681,18 +665,25 @@ void RS_EntityContainer::updateDimensions(bool autoText) {
  */
 void RS_EntityContainer::updateInserts() {
 
-    RS_DEBUG->print("RS_EntityContainer::updateInserts()");
+    RS_DEBUG->print("RS_EntityContainer::updateInserts() ID/type: %d/%d", getId(), rtti());
 
-	for (RS_Entity* e: entities){
+    for (RS_Entity* e: entities){
         //// Only update our own inserts and not inserts of inserts
         if (e->rtti()==RS2::EntityInsert  /*&& e->getParent()==this*/) {
             ((RS_Insert*)e)->update();
-        } else if (e->isContainer() && e->rtti()!=RS2::EntityHatch) {
-            ((RS_EntityContainer*)e)->updateInserts();
+            RS_DEBUG->print("RS_EntityContainer::updateInserts: updated ID/type: %d/%d", e->getId(), e->rtti());
+        } else if (e->isContainer()) {
+            if (e->rtti()==RS2::EntityHatch) {
+                RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_EntityContainer::updateInserts: skip hatch ID/type: %d/%d", e->getId(), e->rtti());
+            } else {
+                RS_DEBUG->print("RS_EntityContainer::updateInserts: update container ID/type: %d/%d", e->getId(), e->rtti());
+                ((RS_EntityContainer*)e)->updateInserts();
+            }
+        } else {
+            RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_EntityContainer::updateInserts: skip entity ID/type: %d/%d", e->getId(), e->rtti());
         }
     }
-
-    RS_DEBUG->print("RS_EntityContainer::updateInserts() OK");
+    RS_DEBUG->print("RS_EntityContainer::updateInserts() ID/type: %d/%d OK", getId(), rtti());
 }
 
 
@@ -715,7 +706,8 @@ void RS_EntityContainer::renameInserts(const QString& oldName,
             if (i->getName()==oldName) {
                 i->setName(newName);
             }
-        } else if (e->isContainer()) {
+        }
+        if (e->isContainer()) {
             ((RS_EntityContainer*)e)->renameInserts(oldName, newName);
         }
     }
@@ -785,7 +777,7 @@ RS_Entity* RS_EntityContainer::firstEntity(RS2::ResolveLevel level) {
 		if (e && e->isContainer() && e->rtti()!=RS2::EntityInsert) {
             subContainer = (RS_EntityContainer*)e;
             e = ((RS_EntityContainer*)e)->firstEntity(level);
-            // emtpy container:
+            // empty container:
 			if (!e) {
 				subContainer = nullptr;
                 e = nextEntity(level);
@@ -805,7 +797,7 @@ RS_Entity* RS_EntityContainer::firstEntity(RS2::ResolveLevel level) {
 		if (e && e->isContainer() && e->rtti()!=RS2::EntityText && e->rtti()!=RS2::EntityMText) {
             subContainer = (RS_EntityContainer*)e;
             e = ((RS_EntityContainer*)e)->firstEntity(level);
-            // emtpy container:
+            // empty container:
 			if (!e) {
 				subContainer = nullptr;
                 e = nextEntity(level);
@@ -824,7 +816,7 @@ RS_Entity* RS_EntityContainer::firstEntity(RS2::ResolveLevel level) {
 		if (e && e->isContainer()) {
             subContainer = (RS_EntityContainer*)e;
             e = ((RS_EntityContainer*)e)->firstEntity(level);
-            // emtpy container:
+            // empty container:
 			if (!e) {
 				subContainer = nullptr;
                 e = nextEntity(level);
@@ -930,7 +922,7 @@ RS_Entity* RS_EntityContainer::nextEntity(RS2::ResolveLevel level) {
 		if (e && e->isContainer() && e->rtti()!=RS2::EntityInsert) {
             subContainer = (RS_EntityContainer*)e;
             e = ((RS_EntityContainer*)e)->firstEntity(level);
-            // emtpy container:
+            // empty container:
 			if (!e) {
 				subContainer = nullptr;
                 e = nextEntity(level);
@@ -959,7 +951,7 @@ RS_Entity* RS_EntityContainer::nextEntity(RS2::ResolveLevel level) {
 		if (e && e->isContainer() && e->rtti()!=RS2::EntityText && e->rtti()!=RS2::EntityMText ) {
             subContainer = (RS_EntityContainer*)e;
             e = ((RS_EntityContainer*)e)->firstEntity(level);
-            // emtpy container:
+            // empty container:
 			if (!e) {
 				subContainer = nullptr;
                 e = nextEntity(level);
@@ -987,7 +979,7 @@ RS_Entity* RS_EntityContainer::nextEntity(RS2::ResolveLevel level) {
 		if (e && e->isContainer()) {
             subContainer = (RS_EntityContainer*)e;
             e = ((RS_EntityContainer*)e)->firstEntity(level);
-            // emtpy container:
+            // empty container:
 			if (!e) {
 				subContainer = nullptr;
                 e = nextEntity(level);
@@ -1033,7 +1025,7 @@ RS_Entity* RS_EntityContainer::prevEntity(RS2::ResolveLevel level) {
 		if (e && e->isContainer() && e->rtti()!=RS2::EntityInsert) {
             subContainer = (RS_EntityContainer*)e;
             e = ((RS_EntityContainer*)e)->lastEntity(level);
-            // emtpy container:
+            // empty container:
 			if (!e) {
 				subContainer = nullptr;
                 e = prevEntity(level);
@@ -1060,7 +1052,7 @@ RS_Entity* RS_EntityContainer::prevEntity(RS2::ResolveLevel level) {
 		if (e && e->isContainer() && e->rtti()!=RS2::EntityText && e->rtti()!=RS2::EntityMText) {
             subContainer = (RS_EntityContainer*)e;
             e = ((RS_EntityContainer*)e)->lastEntity(level);
-            // emtpy container:
+            // empty container:
 			if (!e) {
 				subContainer = nullptr;
                 e = prevEntity(level);
@@ -1087,7 +1079,7 @@ RS_Entity* RS_EntityContainer::prevEntity(RS2::ResolveLevel level) {
 		if (e && e->isContainer()) {
             subContainer = (RS_EntityContainer*)e;
             e = ((RS_EntityContainer*)e)->lastEntity(level);
-            // emtpy container:
+            // empty container:
 			if (!e) {
 				subContainer = nullptr;
                 e = prevEntity(level);
@@ -1137,7 +1129,7 @@ int RS_EntityContainer::findEntity(RS_Entity const* const entity) {
 
 /**
  * @return The point which is closest to 'coord'
- * (one of the vertexes)
+ * (one of the vertices)
  */
 RS_Vector RS_EntityContainer::getNearestEndpoint(const RS_Vector& coord,
                                                  double* dist  )const {
@@ -1170,7 +1162,7 @@ RS_Vector RS_EntityContainer::getNearestEndpoint(const RS_Vector& coord,
 
 /**
  * @return The point which is closest to 'coord'
- * (one of the vertexes)
+ * (one of the vertices)
  */
 RS_Vector RS_EntityContainer::getNearestEndpoint(const RS_Vector& coord,
                                                  double* dist,  RS_Entity** pEntity)const {
@@ -1352,6 +1344,42 @@ RS_Vector RS_EntityContainer::getNearestIntersection(const RS_Vector& coord,
     return closestPoint;
 }
 
+RS_Vector RS_EntityContainer::getNearestVirtualIntersection(const RS_Vector& coord,
+                                                            const double& angle,
+                                                            double* dist)
+{
+
+    RS_Vector point;                // endpoint found
+    RS_VectorSolutions sol;
+    RS_Entity* closestEntity;
+    RS_Vector second_coord;
+
+    second_coord.set(angle);
+    closestEntity = getNearestEntity(coord, nullptr, RS2::ResolveAllButTextImage);
+
+    if (closestEntity)
+    {
+            RS_ConstructionLineData data(coord,coord + second_coord);
+            auto line = new RS_ConstructionLine(this,data);
+
+            sol = RS_Information::getIntersection(closestEntity,line,true);
+            if (sol.getVector().empty())
+            {
+                return coord;
+            }
+            else
+            {
+                point=sol.getClosest(coord,dist,nullptr);
+                return point;
+            }
+    }
+    else
+    {
+        return coord;
+    }
+
+
+}
 
 
 RS_Vector RS_EntityContainer::getNearestRef(const RS_Vector& coord,
@@ -1529,10 +1557,12 @@ bool RS_EntityContainer::optimizeContours() {
         case RS2::EntityEllipse:
 			if(static_cast<RS_Ellipse*>(e1)->isEllipticArc())
                 continue;
+            // fall-through
         case RS2::EntityCircle:
             //directly detect circles, bug#3443277
             tmp.addEntity(e1->clone());
             enList<<e1;
+            // fall-through
         default:
             continue;
         }
@@ -1567,24 +1597,34 @@ bool RS_EntityContainer::optimizeContours() {
     /** connect entities **/
     const QString errMsg=QObject::tr("Hatch failed due to a gap=%1 between (%2, %3) and (%4, %5)");
 
-    while(count()>0){
+    while(count()>0) {
         double dist(0.);
         RS_Vector&& vpTmp=getNearestEndpoint(vpEnd,&dist,&next);
         if(dist>1e-8) {
-            if(vpEnd.squaredTo(vpStart)<1e-8){
+            if(vpEnd.squaredTo(vpStart) < 1e-8) {
                 RS_Entity* e2=entityAt(0);
                 tmp.addEntity(e2->clone());
                 vpStart=e2->getStartpoint();
                 vpEnd=e2->getEndpoint();
                 removeEntity(e2);
                 continue;
-			}
-			QG_DIALOGFACTORY->commandMessage(
-						errMsg.arg(dist).arg(vpTmp.x).arg(vpTmp.y).arg(vpEnd.x).arg(vpEnd.y)
-						);
-            closed=false;
+            }
+            else {
+                QG_DIALOGFACTORY->commandMessage(
+                            errMsg.arg(dist).arg(vpTmp.x).arg(vpTmp.y).arg(vpEnd.x).arg(vpEnd.y)
+                            );
+                RS_DEBUG->print(RS_Debug::D_ERROR, "RS_EntityContainer::optimizeContours: hatch failed due to a gap");
+                closed=false;
+                break;
+            }
         }
-		if(next && closed){ 			//workaround if next is nullptr
+        if(!next) { 	    //workaround if next is nullptr
+//      	    std::cout<<"RS_EntityContainer::optimizeContours: next is nullptr" <<std::endl;
+            RS_DEBUG->print("RS_EntityContainer::optimizeContours: next is nullptr");
+//			closed=false;	//workaround if next is nullptr
+            break;			//workaround if next is nullptr
+        } 					//workaround if next is nullptr
+        if(closed) {
             next->setProcessed(true);
             RS_Entity* eTmp = next->clone();
             if(vpEnd.squaredTo(eTmp->getStartpoint())>vpEnd.squaredTo(eTmp->getEndpoint()))
@@ -1592,20 +1632,15 @@ bool RS_EntityContainer::optimizeContours() {
             vpEnd=eTmp->getEndpoint();
             tmp.addEntity(eTmp);
         	removeEntity(next);
-		} else { 			//workaround if next is nullptr
-//      	    std::cout<<"RS_EntityContainer::optimizeContours: next is nullptr" <<std::endl;
-
-			closed=false;	//workaround if next is nullptr
-			break;			//workaround if next is nullptr
-		} 					//workaround if next is nullptr
+        }
     }
 //    DEBUG_HEADER
-    if(vpEnd.valid && vpEnd.squaredTo(vpStart)>1e-8) {
-		if(closed)
-			QG_DIALOGFACTORY->commandMessage(errMsg.arg(vpEnd.distanceTo(vpStart))
-											 .arg(vpStart.x).arg(vpStart.y).arg(vpEnd.x).arg(vpEnd.y));
-        closed=false;
-    }
+//    if(vpEnd.valid && vpEnd.squaredTo(vpStart) > 1e-8) {
+//		QG_DIALOGFACTORY->commandMessage(errMsg.arg(vpEnd.distanceTo(vpStart))
+//											 .arg(vpStart.x).arg(vpStart.y).arg(vpEnd.x).arg(vpEnd.y));
+//        RS_DEBUG->print("RS_EntityContainer::optimizeContours: hatch failed due to a gap");
+//        closed=false;
+//    }
 //    std::cout<<"RS_EntityContainer::optimizeContours: 5"<<std::endl;
 
 
@@ -1616,7 +1651,12 @@ bool RS_EntityContainer::optimizeContours() {
     }
 //    std::cout<<"RS_EntityContainer::optimizeContours: 6"<<std::endl;
 
-    RS_DEBUG->print("RS_EntityContainer::optimizeContours: OK");
+    if(closed) {
+        RS_DEBUG->print("RS_EntityContainer::optimizeContours: OK");
+    }
+    else {
+        RS_DEBUG->print("RS_EntityContainer::optimizeContours: bad");
+    }
 //    std::cout<<"RS_EntityContainer::optimizeContours: end: count()="<<count()<<std::endl;
 //    std::cout<<"RS_EntityContainer::optimizeContours: closed="<<closed<<std::endl;
     return closed;
@@ -1764,9 +1804,8 @@ void RS_EntityContainer::draw(RS_Painter* painter, RS_GraphicView* view,
         return;
     }
 
-
-    foreach (auto e, entities){
-
+    foreach (auto e, entities)
+    {
         view->drawEntity(painter, e);
     }
 }
@@ -1931,7 +1970,7 @@ RS_Entity* RS_EntityContainer::last() const
 	return entities.last();
 }
 
-QList<RS_Entity*> RS_EntityContainer::getEntityList()
+const QList<RS_Entity*>& RS_EntityContainer::getEntityList()
 {
     return entities;
 }
