@@ -74,7 +74,6 @@ public:
 
 	double getLength() const override;
 
-//	void undoStateChanged(bool undone) override;
 	void setVisible(bool v) override;
 
 	bool setSelected(bool select=true) override;
@@ -165,6 +164,9 @@ public:
 									 double* dist = nullptr) const override;
 	RS_Vector getNearestIntersection(const RS_Vector& coord,
 			double* dist = nullptr);
+    RS_Vector getNearestVirtualIntersection(const RS_Vector& coord,
+                                            const double& angle,
+                                            double* dist);
 	RS_Vector getNearestRef(const RS_Vector& coord,
 									 double* dist = nullptr) const override;
 	RS_Vector getNearestSelectedRef(const RS_Vector& coord,
@@ -228,14 +230,14 @@ public:
 	RS_Entity* first() const;
 	//! \}
 
-    QList<RS_Entity*> getEntityList();
+    const QList<RS_Entity*>& getEntityList();
 
 protected:
 
     /** entities in the container */
     QList<RS_Entity *> entities;
 
-    /** sub container used only temporarly for iteration. */
+    /** sub container used only temporarily for iteration. */
     RS_EntityContainer* subContainer;
 
     /**
