@@ -47,10 +47,6 @@
 #include "rs_debug.h"
 
 
-#if QT_VERSION < 0x040400
-#include "emu_qt44.h"
-#endif
-
 RS_HatchData::RS_HatchData(bool _solid,
 						   double _scale,
 						   double _angle,
@@ -106,11 +102,14 @@ bool RS_Hatch::validate() {
 
 
 RS_Entity* RS_Hatch::clone() const{
+    RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::clone()");
     RS_Hatch* t = new RS_Hatch(*this);
     t->setOwner(isOwner());
     t->initId();
     t->detach();
-		t->hatch = nullptr;
+    t->update();
+//    t->hatch = nullptr;
+    RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::clone(): OK");
     return t;
 }
 
@@ -151,28 +150,37 @@ void RS_Hatch::calculateBorders() {
 /**
  * Updates the Hatch. Called when the
  * hatch or it's data, position, alignment, .. changes.
+ *
+ * Refill hatch with pattern. Move, scale, rotate, trim, etc.
  */
 void RS_Hatch::update() {
-        RS_DEBUG->print("RS_Hatch::update");
-        RS_DEBUG->print("RS_Hatch::update: contour has %d loops", count());
+
+    RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update");
 
     updateError = HATCH_OK;
     if (updateRunning) {
+        RS_DEBUG->print(RS_Debug::D_NOTICE, "RS_Hatch::update: skip hatch in updating process");
         return;
     }
 
     if (updateEnabled==false) {
+        RS_DEBUG->print(RS_Debug::D_NOTICE, "RS_Hatch::update: skip hatch forbidden to update");
         return;
     }
 
     if (data.solid==true) {
+        RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update: processing solid hatch");
         calculateBorders();
         return;
     }
 
-    RS_DEBUG->print("RS_Hatch::update");
+    RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update: contour has %d loops", count());
     updateRunning = true;
 
+    // save attributes for the current hatch
+    RS_Layer* hatch_layer = this->getLayer();
+    RS_Pen hatch_pen = this->getPen();
+
     // delete old hatch:
     if (hatch) {
         removeEntity(hatch);
@@ -180,39 +188,45 @@ void RS_Hatch::update() {
     }
 
     if (isUndone()) {
+        RS_DEBUG->print(RS_Debug::D_NOTICE, "RS_Hatch::update: skip undone hatch");
         updateRunning = false;
         return;
     }
 
     if (!validate()) {
-        RS_DEBUG->print(RS_Debug::D_WARNING,
-                        "RS_Hatch::update: invalid contour in hatch found");
+        RS_DEBUG->print(RS_Debug::D_ERROR, "RS_Hatch::update: invalid contour in hatch found");
         updateRunning = false;
         updateError = HATCH_INVALID_CONTOUR;
         return;
     }
 
-    // search pattern:
-    RS_DEBUG->print("RS_Hatch::update: requesting pattern");
+    // search for pattern
+    RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update: requesting pattern");
     RS_Pattern* pat = RS_PATTERNLIST->requestPattern(data.pattern);
 	if (!pat) {
         updateRunning = false;
-        RS_DEBUG->print("RS_Hatch::update: requesting pattern: not found");
+        RS_DEBUG->print(RS_Debug::D_ERROR, "RS_Hatch::update: requesting pattern: not found");
         updateError = HATCH_PATTERN_NOT_FOUND;
         return;
+    } else {
+        RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update: requesting pattern: OK");
+        // make a working copy of hatch pattern
+        RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update: cloning pattern");
+        pat = (RS_Pattern*)pat->clone();
+        if (pat) {
+            RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update: cloning pattern: OK");
+        } else {
+            RS_DEBUG->print(RS_Debug::D_ERROR, "RS_Hatch::update: error while cloning hatch pattern");
+            return;
+        }
     }
-    RS_DEBUG->print("RS_Hatch::update: requesting pattern: OK");
-
-    RS_DEBUG->print("RS_Hatch::update: cloning pattern");
-    pat = (RS_Pattern*)pat->clone();
-    RS_DEBUG->print("RS_Hatch::update: cloning pattern: OK");
 
     // scale pattern
-    RS_DEBUG->print("RS_Hatch::update: scaling pattern");
+    RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update: scaling pattern");
     pat->scale(RS_Vector(0.0,0.0), RS_Vector(data.scale, data.scale));
     pat->calculateBorders();
     forcedCalculateBorders();
-    RS_DEBUG->print("RS_Hatch::update: scaling pattern: OK");
+    RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update: scaling pattern: OK");
 
     // find out how many pattern-instances we need in x/y:
     int px1, py1, px2, py2;
@@ -227,10 +241,10 @@ void RS_Hatch::update() {
 //    RS_Vector cPos = getMin();
     RS_Vector cSize = getSize();
 
+    RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update: pattern size: %f/%f", pSize.x, pSize.y);
+    RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update: contour size: %f/%f", cSize.x, cSize.y);
 
-    RS_DEBUG->print("RS_Hatch::update: pattern size: %f/%f", pSize.x, pSize.y);
-    RS_DEBUG->print("RS_Hatch::update: contour size: %f/%f", cSize.x, cSize.y);
-
+    // check pattern sizes for sanity
     if (cSize.x<1.0e-6 || cSize.y<1.0e-6 ||
             pSize.x<1.0e-6 || pSize.y<1.0e-6 ||
             cSize.x>RS_MAXDOUBLE-1 || cSize.y>RS_MAXDOUBLE-1 ||
@@ -238,20 +252,20 @@ void RS_Hatch::update() {
         delete pat;
         delete copy;
         updateRunning = false;
-        RS_DEBUG->print("RS_Hatch::update: contour size or pattern size too small");
+        RS_DEBUG->print(RS_Debug::D_ERROR, "RS_Hatch::update: contour size or pattern size too small");
         updateError = HATCH_TOO_SMALL;
         return;
     }
-
     // avoid huge memory consumption:
     else if ( cSize.x* cSize.y/(pSize.x*pSize.y)>1e4) {
-        RS_DEBUG->print("RS_Hatch::update: contour size too large or pattern size too small");
+        RS_DEBUG->print(RS_Debug::D_ERROR, "RS_Hatch::update: contour size too large or pattern size too small");
         delete pat;
         delete copy;
         updateError = HATCH_AREA_TOO_BIG;
         return;
     }
 
+    // calculate pattern pieces quantity
     f = copy->getMin().x/pSize.x;
     px1 = (int)floor(f);
     f = copy->getMin().y/pSize.y;
@@ -265,12 +279,10 @@ void RS_Hatch::update() {
     pat->rotate(rot_center, data.angle);
     pat->move(-rot_center);
 
-
     RS_EntityContainer tmp;   // container for untrimmed lines
 
     // adding array of patterns to tmp:
-    RS_DEBUG->print("RS_Hatch::update: creating pattern carpet");
-
+    RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update: creating pattern carpet");
     for (int px=px1; px<px2; px++) {
 		for (int py=py1; py<py2; py++) {
 			for(auto e: *pat){
@@ -281,21 +293,27 @@ void RS_Hatch::update() {
         }
     }
 
+    // clean memory
     delete pat;
     pat = nullptr;
     delete copy;
     copy = nullptr;
-    RS_DEBUG->print("RS_Hatch::update: creating pattern carpet: OK");
+    RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update: creating pattern carpet: OK");
 
-
-    RS_DEBUG->print("RS_Hatch::update: cutting pattern carpet");
-    // cut pattern to contour shape:
+    // cut pattern to contour shape
+    RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update: cutting pattern carpet");
     RS_EntityContainer tmp2;   // container for small cut lines
 	RS_Line* line = nullptr;
 	RS_Arc* arc = nullptr;
 	RS_Circle* circle = nullptr;
 	RS_Ellipse* ellipse = nullptr;
-	for(auto e: tmp){
+
+    for(auto e: tmp) {
+
+        if (!e) {
+            RS_DEBUG->print(RS_Debug::D_WARNING, "RS_Hatch::update: nullptr entity found");
+            continue;
+        }
 
 		line = nullptr;
 		arc = nullptr;
@@ -307,35 +325,35 @@ void RS_Hatch::update() {
         RS_Vector center = RS_Vector(false);
         bool reversed=false;
 
-        switch(e->rtti()){
-        case RS2::EntityLine:
-            line=static_cast<RS_Line*>(e);
-            startPoint = line->getStartpoint();
-            endPoint = line->getEndpoint();
-            break;
-        case RS2::EntityArc:
-            arc=static_cast<RS_Arc*>(e);
-            startPoint = arc->getStartpoint();
-            endPoint = arc->getEndpoint();
-            center = arc->getCenter();
-            reversed = arc->isReversed();
-            break;
-        case RS2::EntityCircle:
-            circle=static_cast<RS_Circle*>(e);
-            startPoint = circle->getCenter()
-                    + RS_Vector(circle->getRadius(), 0.0);
-            endPoint = startPoint;
-            center = circle->getCenter();
-            break;
-        case RS2::EntityEllipse:
-            ellipse = static_cast<RS_Ellipse*>(e);
-            startPoint = ellipse->getStartpoint();
-            endPoint = ellipse->getEndpoint();
-            center = ellipse->getCenter();
-            reversed = ellipse->isReversed();
-            break;
-        default:
-            continue;
+        switch(e->rtti()) {
+            case RS2::EntityLine:
+                line=static_cast<RS_Line*>(e);
+                startPoint = line->getStartpoint();
+                endPoint = line->getEndpoint();
+                break;
+            case RS2::EntityArc:
+                arc=static_cast<RS_Arc*>(e);
+                startPoint = arc->getStartpoint();
+                endPoint = arc->getEndpoint();
+                center = arc->getCenter();
+                reversed = arc->isReversed();
+                break;
+            case RS2::EntityCircle:
+                circle=static_cast<RS_Circle*>(e);
+                startPoint = circle->getCenter()
+                        + RS_Vector(circle->getRadius(), 0.0);
+                endPoint = startPoint;
+                center = circle->getCenter();
+                break;
+            case RS2::EntityEllipse:
+                ellipse = static_cast<RS_Ellipse*>(e);
+                startPoint = ellipse->getStartpoint();
+                endPoint = ellipse->getEndpoint();
+                center = ellipse->getCenter();
+                reversed = ellipse->isReversed();
+                break;
+            default:
+                continue;
         }
 
         // getting all intersections of this pattern line with the contour:
@@ -349,28 +367,24 @@ void RS_Hatch::update() {
                     RS_VectorSolutions sol =
                         RS_Information::getIntersection(e, p, true);
 
-					for (const RS_Vector& vp: sol){
+                    for (const RS_Vector& vp: sol) {
 						if (vp.valid) {
 							is.append(vp);
-							RS_DEBUG->print("  pattern line intersection: %f/%f",
-											vp.x, vp.y);
+                            RS_DEBUG->print(RS_Debug::D_DEBUGGING, "  pattern line intersection: %f/%f", vp.x, vp.y);
 						}
 					}
 				}
 			}
 		}
 
-
-		QList<RS_Vector> is2;//to be filled with sorted intersections
+        QList<RS_Vector> is2;       //to be filled with sorted intersections
 		is2.append(startPoint);
 
         // sort the intersection points into is2 (only if there are intersections):
-        if(is.size() == 1)
-        {//only one intersection
+        if(is.size() == 1) {        //only one intersection
             is2.append(is.first());
         }
-        else if(is.size() > 1)
-        {
+        else if(is.size() > 1) {
             RS_Vector sp = startPoint;
             double sa = center.angleTo(sp);
 			if(ellipse ) sa=ellipse->getEllipseAngle(sp);
@@ -380,7 +394,7 @@ void RS_Hatch::update() {
 			RS_Vector av;
 			RS_Vector v;
 			RS_Vector last{};
-            do {
+            do {    // very long while(!done) loop
                 done = true;
                 minDist = RS_MAXDOUBLE;
 				av.valid = false;
@@ -422,11 +436,7 @@ void RS_Hatch::update() {
 						is2.append(av);
 						last = av;
                     }
-#if QT_VERSION < 0x040400
-                    emu_qt44_removeOne(is, av);
-#else
                     is.removeOne(av);
-#endif
 
 					av.valid = false;
                 }
@@ -436,43 +446,40 @@ void RS_Hatch::update() {
 		is2.append(endPoint);
 
         // add small cut lines / arcs to tmp2:
-            for (int i = 1; i < is2.size(); ++i) {
-                auto v1 = is2.at(i-1);
-                auto v2 = is2.at(i);
+        for (int i = 1; i < is2.size(); ++i) {
+            auto v1 = is2.at(i-1);
+            auto v2 = is2.at(i);
 
 
-                if (line) {
-
-					tmp2.addEntity(new RS_Line{&tmp2, v1, v2});
-                } else if (arc || circle) {
-					if(fabs(center.angleTo(v2)-center.angleTo(v1)) > RS_TOLERANCE_ANGLE)
-                    {//don't create an arc with a too small angle
-                        tmp2.addEntity(new RS_Arc(&tmp2,
-                                                  RS_ArcData(center,
-															 center.distanceTo(v1),
-															 center.angleTo(v1),
-															 center.angleTo(v2),
-                                                             reversed)));
-                    }
+            if (line) {
 
+                tmp2.addEntity(new RS_Line{&tmp2, v1, v2});
+            } else if (arc || circle) {
+                if(fabs(center.angleTo(v2)-center.angleTo(v1)) > RS_TOLERANCE_ANGLE)
+                {//don't create an arc with a too small angle
+                    tmp2.addEntity(new RS_Arc(&tmp2,
+                                              RS_ArcData(center,
+                                                         center.distanceTo(v1),
+                                                         center.angleTo(v1),
+                                                         center.angleTo(v2),
+                                                         reversed)));
                 }
             }
-
-    }
+        }
+    } // end for very very long for(auto e: tmp) loop
 
     // updating hatch / adding entities that are inside
-    RS_DEBUG->print("RS_Hatch::update: cutting pattern carpet: OK");
+    RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update: cutting pattern carpet: OK");
 
     //RS_EntityContainer* rubbish = new RS_EntityContainer(getGraphic());
 
-    // the hatch pattern entities:
+    // add the hatch pattern entities
     hatch = new RS_EntityContainer(this);
-    hatch->setPen(RS_Pen(RS2::FlagInvalid));
-	hatch->setLayer(nullptr);
+    hatch->setPen(hatch_pen);
+    hatch->setLayer(hatch_layer);
     hatch->setFlag(RS2::FlagTemp);
 
     //calculateBorders();
-
 	for(auto e: tmp2){
 
         RS_Vector middlePoint;
@@ -501,8 +508,8 @@ void RS_Hatch::update() {
                     RS_Information::isPointInsideContour(middlePoint2, this)) {
 
                 RS_Entity* te = e->clone();
-				te->setPen(RS2::FlagInvalid);
-				te->setLayer(nullptr);
+                te->setPen(hatch_pen);
+                te->setLayer(hatch_layer);
                 te->reparent(hatch);
                 hatch->addEntity(te);
             }
@@ -519,7 +526,7 @@ void RS_Hatch::update() {
 
     updateRunning = false;
 
-    RS_DEBUG->print("RS_Hatch::update: OK");
+    RS_DEBUG->print(RS_Debug::D_DEBUGGING, "RS_Hatch::update: OK");
 }
 
 
@@ -546,7 +553,6 @@ void RS_Hatch::activateContour(bool on) {
         RS_DEBUG->print("RS_Hatch::activateContour: OK");
 }
 
-//#include<QDebug>
 /**
  * Overrides drawing of subentities. This is only ever called for solid fills.
  */
@@ -564,11 +570,9 @@ void RS_Hatch::draw(RS_Painter* painter, RS_GraphicView* view, double& /*pattern
     QPainterPath path;
     QList<QPolygon> paClosed;
     QPolygon pa;
-//    QPolygon jp;   // jump points
 
-    // loops:
     if (needOptimization==true) {
-		for(auto l: entities){
+        foreach (auto l, entities){
 
             if (l->rtti()==RS2::EntityContainer) {
                 RS_EntityContainer* loop = (RS_EntityContainer*)l;
@@ -579,15 +583,14 @@ void RS_Hatch::draw(RS_Painter* painter, RS_GraphicView* view, double& /*pattern
         needOptimization = false;
     }
 
-    // loops:
-	for(auto l: entities){
+    foreach (auto l, entities){
         l->setLayer(getLayer());
 
         if (l->rtti()==RS2::EntityContainer) {
             RS_EntityContainer* loop = (RS_EntityContainer*)l;
 
             // edges:
-			for(auto e: *loop){
+            for(auto e: *loop){
 
                 e->setLayer(getLayer());
                 switch (e->rtti()) {
@@ -597,22 +600,14 @@ void RS_Hatch::draw(RS_Painter* painter, RS_GraphicView* view, double& /*pattern
                     QPoint pt2(RS_Math::round(view->toGuiX(e->getEndpoint().x)),
                                RS_Math::round(view->toGuiY(e->getEndpoint().y)));
 
-//                    if (! (pa.size()>0 && (pa.last() - pt1).manhattanLength()<=2)) {
-//                        jp<<pt1;
-//                    }
-                    if(pa.size() && (pa.last()-pt1).manhattanLength()>=1)
-                        pa<<pt1;
-                    pa<<pt2;
+                    if(!pa.size() || (pa.last() - pt1).manhattanLength() >= 1) {
+                        pa << pt1;
+                    }
+                    pa << pt2;
                 }
                     break;
 
                 case RS2::EntityArc: {
-//                    QPoint pt1(RS_Math::round(view->toGuiX(e->getStartpoint().x)),
-//                               RS_Math::round(view->toGuiY(e->getStartpoint().y)));
-//                    if (! (pa.size()>0 && (pa.last() - pt1).manhattanLength()<=2)) {
-//                        jp<<pt1;
-//                    }
-
                     QPolygon pa2;
                     RS_Arc* arc=static_cast<RS_Arc*>(e);
 
@@ -628,26 +623,9 @@ void RS_Hatch::draw(RS_Painter* painter, RS_GraphicView* view, double& /*pattern
 
                 case RS2::EntityCircle: {
                     RS_Circle* circle = static_cast<RS_Circle*>(e);
-//                    QPoint pt1(RS_Math::round(view->toGuiX(circle->getCenter().x+circle->getRadius())),
-//                               RS_Math::round(view->toGuiY(circle->getCenter().y)));
-//                    if (! (pa.size()>0 && (pa.last() - pt1).manhattanLength()<=2)) {
-//                        jp<<pt1;
-//                    }
-
                     RS_Vector c=view->toGui(circle->getCenter());
                     double r=view->toGuiDX(circle->getRadius());
-#if QT_VERSION >= 0x040400
                     path.addEllipse(QPoint(c.x,c.y),r,r);
-#else
-                    path.addEllipse(c.x - r, c.y + r, 2.*r, 2.*r);
-//                    QPolygon pa2;
-//                    painter->createArc(pa2, view->toGui(circle->getCenter()),
-//                                       view->toGuiDX(circle->getRadius()),
-//                                       0.0,
-//                                       2*M_PI,
-//                                       false);
-//                    pa<<pa2;
-#endif
                 }
                     break;
                 case RS2::EntityEllipse:
@@ -662,9 +640,7 @@ void RS_Hatch::draw(RS_Painter* painter, RS_GraphicView* view, double& /*pattern
                                            ellipse->getAngle()
                                            ,ellipse->getAngle1(),ellipse->getAngle2(),ellipse->isReversed()
                                            );
-//                    qDebug()<<"ellipse: "<<ellipse->getCenter().x<<","<<ellipse->getCenter().y;
-//                    qDebug()<<"ellipse: pa2.size()="<<pa2.size();
-//                    qDebug()<<"ellipse: pa2="<<pa2;
+
                     if(pa.size() && pa2.size()&&(pa.last()-pa2.first()).manhattanLength()<1)
                         pa2.remove(0,1);
                     pa<<pa2;
@@ -685,7 +661,7 @@ void RS_Hatch::draw(RS_Painter* painter, RS_GraphicView* view, double& /*pattern
                 default:
                     break;
                 }
-//                qDebug()<<"pa="<<pa;
+
                 if( pa.size()>2 && pa.first() == pa.last()) {
                     paClosed<<pa;
                     pa.clear();
@@ -712,8 +688,6 @@ void RS_Hatch::draw(RS_Painter* painter, RS_GraphicView* view, double& /*pattern
     painter->drawPath(path);
     painter->setBrush(brush);
     painter->setPen(pen);
-
-
 }
 
 //must be called after update()
