@@ -228,12 +228,14 @@ void RS_Insert::update() {
 
                 ne->setPen(tmpPen);
 
-                                ne->setUpdateEnabled(true);
+                ne->setUpdateEnabled(true);
 
-                                if (data.updateMode!=RS2::PreviewUpdate) {
-//                                        RS_DEBUG->print("RS_Insert::update: updating new entity");
-                                        ne->update();
-                                }
+                // insert must be updated even in preview mode
+                if (data.updateMode != RS2::PreviewUpdate
+                        || ne->rtti() == RS2::EntityInsert) {
+                    //RS_DEBUG->print("RS_Insert::update: updating new entity");
+                    ne->update();
+                }
 
 //                                RS_DEBUG->print("RS_Insert::update: adding new entity");
                 appendEntity(ne);
@@ -291,9 +293,9 @@ RS_Block* RS_Insert::getBlockForInsert() const{
  *
  * @return true Only if the entity and the block and the layer it is on
  * are visible.
- * The Layer might also be nullptr. In that case the layer visiblity
+ * The Layer might also be nullptr. In that case the layer visibility
  * is ignored.
- * The Block might also be nullptr. In that case the block visiblity
+ * The Block might also be nullptr. In that case the block visibility
  * is ignored.
  */
 bool RS_Insert::isVisible() const
