@@ -81,6 +81,10 @@ public:
     /** sets a new end point of the polyline */
 	void setEndpoint(RS_Vector const& v);
 
+    // set layer for polyline and sub-entities
+    void setLayer(const QString& name);
+    void setLayer(RS_Layer* l);
+
     /** @return End point of the entity */
 	RS_Vector getEndpoint() const override;
 
