@@ -121,7 +121,7 @@ bool RS_Spline::isClosed() const {
 }
 
 /**
- * Sets the closed falg of this spline.
+ * Sets the closed flag of this spline.
  */
 void RS_Spline::setClosed(bool c) {
 		data.closed = c;
@@ -136,7 +136,7 @@ RS_VectorSolutions RS_Spline::getRefPoints() const
 RS_Vector RS_Spline::getNearestRef( const RS_Vector& coord,
                                     double* dist /*= nullptr*/) const
 {
-    // override the RS_EntityContainer methode
+    // override the RS_EntityContainer method
     // use RS_Entity instead for spline point dragging
     return RS_Entity::getNearestRef(coord, dist);
 }
@@ -144,7 +144,7 @@ RS_Vector RS_Spline::getNearestRef( const RS_Vector& coord,
 RS_Vector RS_Spline::getNearestSelectedRef( const RS_Vector& coord,
                                             double* dist /*= nullptr*/) const
 {
-    // override the RS_EntityContainer methode
+    // override the RS_EntityContainer method
     // use RS_Entity instead for spline point dragging
     return RS_Entity::getNearestSelectedRef(coord, dist);
 }
@@ -565,8 +565,8 @@ void RS_Spline::rbspline(size_t npts, size_t k, size_t p1,
 	auto const x = knot(npts, k);
 
     // calculate the points on the rational B-spline curve
-	double t = 0;
-	double const step = x[nplusc-1]/(p1-1);
+    double t {x[0]};
+    double const step {(x[nplusc-1] - t) / (p1-1)};
 
 	for (auto& vp: p) {
 		if (x[nplusc-1] - t < 5e-6) t = x[nplusc-1];
