@@ -27,6 +27,7 @@
 #include<iostream>
 #include<cmath>
 #include <QObject>
+#include <QStringList>
 #include "rs_units.h"
 #include "rs_math.h"
 #include "rs_vector.h"
@@ -389,7 +390,7 @@ RS_Vector RS_Units::convert(const RS_Vector& val, RS2::Unit src, RS2::Unit dest)
  *
  * @param length The length in the current unit of the drawing.
  * @param format Format of the string.
- * @param prec Precisision of the value (e.g. 0.001 or 1/128 = 0.0078125)
+ * @param prec Precision of the value (e.g. 0.001 or 1/128 = 0.0078125)
  & @param showUnit Append unit to the value.
  */
 QString RS_Units::formatLinear(double length, RS2::Unit unit,
@@ -425,6 +426,10 @@ QString RS_Units::formatLinear(double length, RS2::Unit unit,
         ret = formatFractional(length, unit, prec, showUnit);
         break;
 
+    case RS2::ArchitecturalMetric:
+        ret = formatArchitecturalMetric(length, unit, prec, showUnit);
+        break;
+
     default:
         RS_DEBUG->print(RS_Debug::D_WARNING,
                         "RS_Units::formatLinear: Unknown format");
@@ -441,7 +446,7 @@ QString RS_Units::formatLinear(double length, RS2::Unit unit,
  * Formats the given length in scientific format (e.g. 2.5E7).
  *
  * @param length The length in the current unit of the drawing.
- * @param prec Precisision of the value (e.g. 0.001 or 1/128 = 0.0078125)
+ * @param prec Precision of the value (e.g. 0.001 or 1/128 = 0.0078125)
  & @param showUnit Append unit to the value.
  */
 QString RS_Units::formatScientific(double length, RS2::Unit unit,
@@ -459,7 +464,7 @@ QString RS_Units::formatScientific(double length, RS2::Unit unit,
  * Formats the given length in decimal (normal) format (e.g. 2.5).
  *
  * @param length The length in the current unit of the drawing.
- * @param prec Precisision of the value (e.g. 0.001)
+ * @param prec Precision of the value (e.g. 0.001)
  & @param showUnit Append unit to the value.
  */
 QString RS_Units::formatDecimal(double length, RS2::Unit unit,
@@ -477,7 +482,7 @@ QString RS_Units::formatDecimal(double length, RS2::Unit unit,
  * Formats the given length in engineering format (e.g. 5' 4.5").
  *
  * @param length The length in the current unit of the drawing.
- * @param prec Precisision of the value (e.g. 0.001 or 1/128 = 0.0078125)
+ * @param prec Precision of the value (e.g. 0.001 or 1/128 = 0.0078125)
  & @param showUnit Append unit to the value.
  */
 QString RS_Units::formatEngineering(double length, RS2::Unit /*unit*/,
@@ -514,7 +519,7 @@ QString RS_Units::formatEngineering(double length, RS2::Unit /*unit*/,
  * Formats the given length in architectural format (e.g. 5' 4 1/2").
  *
  * @param length The length in the current unit of the drawing.
- * @param prec Precisision of the value (e.g. 0.001 or 1/128 = 0.0078125)
+ * @param prec Precision of the value (e.g. 0.001 or 1/128 = 0.0078125)
  & @param showUnit Append unit to the value.
  */
 QString RS_Units::formatArchitectural(double length, RS2::Unit /*unit*/,
@@ -543,12 +548,56 @@ QString RS_Units::formatArchitectural(double length, RS2::Unit /*unit*/,
 
 
 
+/**
+ * Formats the given length in metric architectural format
+ * using DIN 406 (e.g. 1.12⁵).
+ *
+ * @param length The length in the current unit of the drawing.
+ * @param prec Precision of the value (e.g. 0.001)
+ & @param showUnit Append unit to the value.
+ */
+QString RS_Units::formatArchitecturalMetric(double length, RS2::Unit unit,
+                                            int prec, bool showUnit) {
+    QString ret;
+    bool neg = (length<0.0);
+    QString zero = "0";
+
+    if (neg)
+        length = length * -1.0;
+
+    ret = RS_Math::doubleToString(length, prec + 1);
+    int iLast = QString(ret.right(1)).toInt();
+
+    // round on 0.005 and use superscript 5
+    if ((iLast > 2) && (iLast < 8)) {
+        ret = ret.replace(ret.length() - 1, 1, "\u2075");
+    } else {
+        ret = RS_Math::doubleToString(length, prec);
+    }
+
+    // return values < 1.00m in cm (0.42 -> 42)
+    if (ret.startsWith(zero)) {
+        ret = ret.split(".")[1];
+        // eliminate leading zeros (0.07 -> 7)
+        if (ret.startsWith(zero)) {
+            ret = ret.remove(0, 1);
+        }
+    }
+    if (showUnit) {
+        ret = QString("%1 %2").arg(ret).arg(unitToSign(unit));
+    }
+    if (neg) {
+        ret = QString("-%1").arg(ret);
+    }
+    return ret;
+}
+
 /**
  * Formats the given length in fractional (barbarian) format (e.g. 5' 3 1/64").
  *
  * @param length The length in the current unit of the drawing.
  * @param unit Should be inches.
- * @param prec Precisision of the value (e.g. 0.001 or 1/128 = 0.0078125)
+ * @param prec Precision of the value (e.g. 0.001 or 1/128 = 0.0078125)
  & @param showUnit Append unit to the value.
  */
 QString RS_Units::formatFractional(double length, RS2::Unit /*unit*/,
@@ -558,7 +607,7 @@ QString RS_Units::formatFractional(double length, RS2::Unit /*unit*/,
 
 	unsigned num;            // number of complete inches (num' 7/128")
 	unsigned nominator;      // number of fractions (nominator/128)
-	unsigned denominator;    // (4/denominator)
+	unsigned denominator;    // (7/denominator)
 
     // sign:
     QString neg = "";
@@ -608,14 +657,12 @@ QString RS_Units::formatFractional(double length, RS2::Unit /*unit*/,
 
 
 
-
-
 /**
  * Formats the given angle with the given format.
  *
  * @param angle The angle (always in rad).
  * @param format Format of the string.
- * @param prec Precisision of the value (e.g. 0.001 or 1/128 = 0.0078125)
+ * @param prec Precision of the value (e.g. 0.001 or 1/128 = 0.0078125)
  *
  * @ret String with the formatted angle.
  */
@@ -626,6 +673,7 @@ QString RS_Units::formatAngle(double angle, RS2::AngleFormat format,
     double value;
 
     switch (format) {
+    case RS2::Surveyors:
     case RS2::DegreesDecimal:
     case RS2::DegreesMinutesSeconds:
         value = RS_Math::rad2deg(angle);
@@ -699,7 +747,36 @@ QString RS_Units::formatAngle(double angle, RS2::AngleFormat format,
             }
         }
         break;
-
+    case RS2::Surveyors: {
+        QString prefix,suffix;
+        int quadrant;
+        quadrant = ((int)floor(value)/90);
+        switch(quadrant){
+            case 0:
+                prefix="N";
+                suffix="E";
+                break;
+            case 1:
+                prefix="S";
+                suffix="E";
+                value=180. - value;
+                break;
+            case 2:
+                prefix="S";
+                suffix="W";
+                value=value - 180.;
+                break;
+            case 3:
+                prefix="N";
+                suffix="W";
+                value=360. - value;
+                break;
+            }
+            ret = prefix+formatAngle(RS_Math::deg2rad(value),RS2::DegreesMinutesSeconds,prec)+suffix;
+            ret.replace(QChar(0xB0),"d");
+            ret.replace(" ","");
+        }
+        break;
     default:
         break;
     }
@@ -746,166 +823,58 @@ RS2::AngleFormat RS_Units::numberToAngleFormat(int num) {
  * @return Size of the given paper format.
  */
 RS_Vector RS_Units::paperFormatToSize(RS2::PaperFormat p) {
-    RS_Vector ret(false);
 
     switch (p) {
     case RS2::Custom:
-        ret = RS_Vector(0.0, 0.0);
-        break;
-    case RS2::Letter:
-        ret = RS_Vector(215.9, 279.4);
-        break;
-    case RS2::Legal:
-        ret = RS_Vector(215.9, 355.6);
-        break;
-    case RS2::Executive:
-        ret = RS_Vector(190.5, 254.0);
-        break;
-    case RS2::A0:
-        ret = RS_Vector(841.0, 1189.0);
-        break;
-    case RS2::A1:
-        ret = RS_Vector(594.0, 841.0);
-        break;
-    case RS2::A2:
-        ret = RS_Vector(420.0, 594.0);
-        break;
-    case RS2::A3:
-        ret = RS_Vector(297.0, 420.0);
-        break;
-    case RS2::A4:
-        ret = RS_Vector(210.0, 297.0);
-        break;
-    case RS2::A5:
-        ret = RS_Vector(148.0, 210.0);
-        break;
-    case RS2::A6:
-        ret = RS_Vector(105.0, 148.0);
-        break;
-    case RS2::A7:
-        ret = RS_Vector(74.0, 105.0);
-        break;
-    case RS2::A8:
-        ret = RS_Vector(52.0, 74.0);
-        break;
-    case RS2::A9:
-        ret = RS_Vector(37.0, 52.0);
-        break;
-        /*case RS2::A10:
-            ret = RS_Vector(26.0, 37.0);
-            break;*/
-    case RS2::B0:
-        ret = RS_Vector(1000.0, 1414.0);
-        break;
-    case RS2::B1:
-        ret = RS_Vector(707.0, 1000.0);
-        break;
-    case RS2::B2:
-        ret = RS_Vector(500.0, 707.0);
-        break;
-    case RS2::B3:
-        ret = RS_Vector(353.0, 500.0);
-        break;
-    case RS2::B4:
-        ret = RS_Vector(250.0, 353.0);
-        break;
-    case RS2::B5:
-        ret = RS_Vector(176.0, 250.0);
-        break;
-    case RS2::B6:
-        ret = RS_Vector(125.0, 176.0);
-        break;
-    case RS2::B7:
-        ret = RS_Vector(88.0, 125.0);
-        break;
-    case RS2::B8:
-        ret = RS_Vector(62.0, 88.0);
-        break;
-    case RS2::B9:
-        ret = RS_Vector(44.0, 62.0);
-        break;
-    case RS2::B10:
-        ret = RS_Vector(31.0, 44.0);
-        break;
-        /*
-          case RS2::C0:
-              ret = RS_Vector(917.0, 1297.0);
-              break;
-          case RS2::C1:
-              ret = RS_Vector(648.0, 917.0);
-              break;
-          case RS2::C2:
-              ret = RS_Vector(458.0, 648.0);
-              break;
-          case RS2::C3:
-              ret = RS_Vector(324.0, 458.0);
-              break;
-          case RS2::C4:
-              ret = RS_Vector(229.0, 324.0);
-              break;
-          case RS2::C5:
-              ret = RS_Vector(162.0, 229.0);
-              break;
-          case RS2::C6:
-              ret = RS_Vector(114.0, 162.0);
-              break;
-          case RS2::C7:
-              ret = RS_Vector(81.0, 114.0);
-              break;
-          case RS2::C8:
-              ret = RS_Vector(57.0, 81.0);
-              break;
-          case RS2::C9:
-              ret = RS_Vector(40.0, 57.0);
-              break;
-          case RS2::C10:
-              ret = RS_Vector(28.0, 40.0);
-              break;
-        */
-    case RS2::C5E:
-        ret = RS_Vector(163.0, 229.0);
-        break;
-    case RS2::Comm10E:
-        ret = RS_Vector(105.0, 241.0);
-        break;
-    case RS2::DLE:
-        ret = RS_Vector(110.0, 220.0);
-        break;
-    case RS2::Folio:
-        ret = RS_Vector(210.0, 330.0);
-        break;
-    case RS2::Ledger:
-        ret = RS_Vector(432.0, 279.0);
-        break;
-    case RS2::Tabloid:
-        ret = RS_Vector(279.0, 432.0);
-        break;
-
-    case RS2::Arch_A:
-    return RS_Vector(229.,305.);
-    case RS2::Arch_B:
-    return RS_Vector(305.,457.);
-    case RS2::Arch_C:
-    return RS_Vector(457.,610.);
-    case RS2::Arch_D:
-    return RS_Vector(610.,914.);
-    case RS2::Arch_E:
-    return RS_Vector(914.,1219.);
-    case RS2::Arch_E1:
-    return RS_Vector(762.,1067.);
-    case RS2::Arch_E2:
-    return RS_Vector(660.,965.);
-    case RS2::Arch_E3:
-    return RS_Vector(686.,991.);
-
-    case RS2::NPageSize:
         return RS_Vector(0.0, 0.0);
-        break;
+
+    case RS2::A0:
+        return RS_Vector(841.0, 1189.0);
+    case RS2::A1:
+        return RS_Vector(594.0, 841.0);
+    case RS2::A2:
+        return RS_Vector(420.0, 594.0);
+    case RS2::A3:
+        return RS_Vector(297.0, 420.0);
+    case RS2::A4:
+        return RS_Vector(210.0, 297.0);
+
+    /* Removed ISO "B" and "C" series, C5E, Comm10E, DLE, (envelope sizes) */
+
+    case RS2::Letter:  /* 8.5 x 11.0 in.  Sizes shown are used for 'hard' conversion to metric */
+        return RS_Vector(215.9, 279.4);
+    case RS2::Legal:  /* 8.5 x 14.0 in */
+        return RS_Vector(215.9, 355.6);
+    case RS2::Tabloid:  /* 11.0 x 17.0 */
+        return RS_Vector(279.4, 431.8);
+
+    //case RS2::Ansi_A:  /* 8.5 x 11.0 in */
+    //    return RS_Vector(215.9, 279.4);
+    //case RS2::Ansi_B:  /* 11.0 x 17.0 in */
+    //    return RS_Vector(279.4, 431.8);
+    case RS2::Ansi_C:  /* 17.0 x 22.0 in */
+        return RS_Vector(431.8, 558.8);
+    case RS2::Ansi_D:  /* 22.0 x 34.0 in */
+        return RS_Vector(558.8, 863.6);
+    case RS2::Ansi_E:  /* 34.0 x 44.0 in */
+        return RS_Vector(863.6, 1117.6);
+
+    case RS2::Arch_A:  /* 9.0 x 12.0 in */
+        return RS_Vector(228.6, 304.8);
+    case RS2::Arch_B:  /* 12.0 x 18.0 in */
+        return RS_Vector(304.8, 457.2);
+    case RS2::Arch_C:  /* 18.0 x 24.0 in */
+        return RS_Vector(457.2, 609.6);
+    case RS2::Arch_D:  /* 24.0 x 36.0 in */
+        return RS_Vector(609.6, 914.4);
+    case RS2::Arch_E:  /* 36.0 x 48.0 in */
+        return RS_Vector(914.4, 1219.2);
+
     default:
         break;
     }
 
-    return ret;
+    return RS_Vector (false);
 }
 
 
@@ -918,12 +887,12 @@ RS2::PaperFormat RS_Units::paperSizeToFormat(const RS_Vector& s) {
     RS_Vector ts1;
     RS_Vector ts2;
 
-    for (int i=(int)RS2::Custom; i<=(int)RS2::NPageSize; ++i) {
-        ts1 = RS_Units::paperFormatToSize((RS2::PaperFormat)i);
+    for (RS2::PaperFormat i = RS2::FirstPaperFormat; RS2::NPageFormat > i; i = static_cast<RS2::PaperFormat>(i + 1)) {
+        ts1 = RS_Units::paperFormatToSize(i);
         ts2 = RS_Vector(ts1.y, ts1.x);
 
-        if (ts1.distanceTo(s)<1.0e-4 || ts2.distanceTo(s)<1.0e-4) {
-            return (RS2::PaperFormat)i;
+        if (ts1.distanceTo(s) < 1.0e-4 || ts2.distanceTo(s) < 1.0e-4) {
+            return i;
         }
     }
 
@@ -936,162 +905,39 @@ RS2::PaperFormat RS_Units::paperSizeToFormat(const RS_Vector& s) {
  * Converts a paper format to a string (e.g. for a combobox).
  */
 QString RS_Units::paperFormatToString(RS2::PaperFormat p) {
-    QString ret = "";
 
     switch (p) {
-    case RS2::Custom:
-        ret = "Custom";
-        break;
-    case RS2::Letter:
-        ret = "Letter";
-        break;
-    case RS2::Legal:
-        ret = "Legal";
-        break;
-    case RS2::Executive:
-        ret = "Executive";
-        break;
-    case RS2::A0:
-        ret = "A0";
-        break;
-    case RS2::A1:
-        ret = "A1";
-        break;
-    case RS2::A2:
-        ret = "A2";
-        break;
-    case RS2::A3:
-        ret = "A3";
-        break;
-    case RS2::A4:
-        ret = "A4";
-        break;
-    case RS2::A5:
-        ret = "A5";
-        break;
-    case RS2::A6:
-        ret = "A6";
-        break;
-    case RS2::A7:
-        ret = "A7";
-        break;
-    case RS2::A8:
-        ret = "A8";
-        break;
-    case RS2::A9:
-        ret = "A9";
-        break;
-    case RS2::B0:
-        ret = "B0";
-        break;
-    case RS2::B1:
-        ret = "B1";
-        break;
-    case RS2::B2:
-        ret = "B2";
-        break;
-    case RS2::B3:
-        ret = "B3";
-        break;
-    case RS2::B4:
-        ret = "B4";
-        break;
-    case RS2::B5:
-        ret = "B5";
-        break;
-    case RS2::B6:
-        ret = "B6";
-        break;
-    case RS2::B7:
-        ret = "B7";
-        break;
-    case RS2::B8:
-        ret = "B8";
-        break;
-    case RS2::B9:
-        ret = "B9";
-        break;
-    case RS2::B10:
-        ret = "B10";
-        break;
-        /*
-           case RS2::C0:
-               ret = "C0";
-               break;
-           case RS2::C1:
-               ret = "C1";
-               break;
-           case RS2::C2:
-               ret = "C2";
-               break;
-           case RS2::C3:
-               ret = "C3";
-               break;
-           case RS2::C4:
-               ret = "C4";
-               break;
-           case RS2::C5:
-               ret = "C5";
-               break;
-           case RS2::C6:
-               ret = "C6";
-               break;
-           case RS2::C7:
-               ret = "C7";
-               break;
-           case RS2::C8:
-               ret = "C8";
-               break;
-           case RS2::C9:
-               ret = "C9";
-               break;
-           case RS2::C10:
-               ret = "C10";
-               break;
-        */
-    case RS2::C5E:
-        ret = "C5E";
-        break;
-    case RS2::Comm10E:
-        ret = "Comm10E";
-        break;
-    case RS2::DLE:
-        ret = "DLE";
-        break;
-    case RS2::Folio:
-        ret = "Folio";
-        break;
-    case RS2::Ledger:
-        ret = "Ledger";
-        break;
-    case RS2::Tabloid:
-        ret = "Tabloid";
-        break;
-    case RS2::Arch_A:
-    return QString("Arch A");
-    case RS2::Arch_B:
-    return QString("Arch B");
-    case RS2::Arch_C:
-    return QString("Arch C");
-    case RS2::Arch_D:
-    return QString("Arch D");
-    case RS2::Arch_E:
-    return QString("Arch E");
-    case RS2::Arch_E1:
-    return QString("Arch E1");
-    case RS2::Arch_E2:
-    return QString("Arch E2");
-    case RS2::Arch_E3:
-    return QString("Arch E3");
+    case RS2::Custom: return QObject::tr( "Custom", "Paper format");
+
+    case RS2::A0: return QObject::tr( "A0", "Paper format");
+    case RS2::A1: return QObject::tr( "A1", "Paper format");
+    case RS2::A2: return QObject::tr( "A2", "Paper format");
+    case RS2::A3: return QObject::tr( "A3", "Paper format");
+    case RS2::A4: return QObject::tr( "A4", "Paper format");
+
+    /* Removed ISO "B" and "C" series, C5E, Comm10E, DLE, (envelope sizes) */
+
+    case RS2::Letter: return QObject::tr( "Letter / ANSI A", "Paper format");
+    case RS2::Legal:  return QObject::tr( "Legal",  "Paper format");
+    case RS2::Tabloid: return QObject::tr( "Tabloid / ANSI B", "Paper format");
+
+    //case RS2::Ansi_A: return QObject::tr( "Letter / ANSI A", "Paper format");
+    //case RS2::Ansi_B: return QObject::tr( "Tabloid / ANSI B", "Paper format");
+    case RS2::Ansi_C: return QObject::tr( "ANSI C", "Paper format");
+    case RS2::Ansi_D: return QObject::tr( "ANSI D", "Paper format");
+    case RS2::Ansi_E: return QObject::tr( "ANSI E", "Paper format");
+
+    case RS2::Arch_A: return QObject::tr( "Arch A", "Paper format");
+    case RS2::Arch_B: return QObject::tr( "Arch B", "Paper format");
+    case RS2::Arch_C: return QObject::tr( "Arch C", "Paper format");
+    case RS2::Arch_D: return QObject::tr( "Arch D", "Paper format");
+    case RS2::Arch_E: return QObject::tr( "Arch E", "Paper format");
 
-    case RS2::NPageSize:
-        ret = "NPageSize";
-        break;
     default:
         break;
     }
 
-    return ret;
+    return QStringLiteral("");
 }
 
 
@@ -1100,108 +946,55 @@ QString RS_Units::paperFormatToString(RS2::PaperFormat p) {
  * Converts a string to a paper format.
  */
 RS2::PaperFormat RS_Units::stringToPaperFormat(const QString& p) {
-    QString ls = p.toLower();
-    RS2::PaperFormat ret = RS2::Custom;
+    QString ls {p.toLower()};
 
-    if (p=="custom") {
-        ret = RS2::Custom;
-    } else if (p=="letter") {
-        ret = RS2::Letter;
-    } else if (p=="legal") {
-        ret = RS2::Legal;
-    } else if (p=="executive") {
-        ret = RS2::Executive;
-    } else if (p=="a0") {
-        ret = RS2::A0;
-    } else if (p=="a1") {
-        ret = RS2::A1;
-    } else if (p=="a2") {
-        ret = RS2::A2;
-    } else if (p=="a3") {
-        ret = RS2::A3;
-    } else if (p=="a4") {
-        ret = RS2::A4;
-    } else if (p=="a5") {
-        ret = RS2::A5;
-    } else if (p=="a6") {
-        ret = RS2::A6;
-    } else if (p=="a7") {
-        ret = RS2::A7;
-    } else if (p=="a8") {
-        ret = RS2::A8;
-    } else if (p=="a9") {
-        ret = RS2::A9;
-    } else if (p=="b0") {
-        ret = RS2::B0;
-    } else if (p=="b1") {
-        ret = RS2::B1;
-    } else if (p=="b2") {
-        ret = RS2::B2;
-    } else if (p=="b3") {
-        ret = RS2::B3;
-    } else if (p=="b4") {
-        ret = RS2::B4;
-    } else if (p=="b5") {
-        ret = RS2::B5;
-    } else if (p=="b6") {
-        ret = RS2::B6;
-    } else if (p=="b7") {
-        ret = RS2::B7;
-    } else if (p=="b8") {
-        ret = RS2::B8;
-    } else if (p=="b9") {
-        ret = RS2::B9;
-    } else if (p=="b10") {
-        ret = RS2::B10;
-    }
-    /*else if (p=="c0") {
-           ret = RS2::C0;
-       } else if (p=="c1") {
-           ret = RS2::C1;
-       } else if (p=="c2") {
-           ret = RS2::C2;
-       } else if (p=="c3") {
-           ret = RS2::C3;
-       } else if (p=="c4") {
-           ret = RS2::C4;
-       } else if (p=="c5") {
-           ret = RS2::C5;
-       } else if (p=="c6") {
-           ret = RS2::C6;
-       } else if (p=="c7") {
-           ret = RS2::C7;
-       } else if (p=="c8") {
-           ret = RS2::C8;
-       } else if (p=="c9") {
-           ret = RS2::C9;
-       } else if (p=="c10") {
-           ret = RS2::C10;
-       }*/
-    else if (p=="c5e") {
-        ret = RS2::C5E;
-    } else if (p=="comm10e") {
-        ret = RS2::Comm10E;
-    } else if (p=="dle") {
-        ret = RS2::DLE;
-    } else if (p=="folio") {
-        ret = RS2::Folio;
-    } else if (p=="ledger") {
-        ret = RS2::Ledger;
-    } else if (p=="tabloid") {
-        ret = RS2::Tabloid;
-    }
-    if (p==QString("Arch A")) return RS2::Arch_A;
-    if (p==QString("Arch B")) return RS2::Arch_B;
-    if (p==QString("Arch C")) return RS2::Arch_C;
-    if (p==QString("Arch D")) return RS2::Arch_D;
-    if (p==QString("Arch E")) return RS2::Arch_E;
-    if (p==QString("Arch E1")) return RS2::Arch_E1;
-    if (p==QString("Arch E2")) return RS2::Arch_E2;
-    if (p==QString("Arch E3")) return RS2::Arch_E3;
+    // use toLower() on localized paper format strings, don't trust that translators keep lower case
+    if (ls == QStringLiteral("custom") || ls == QObject::tr("custom", "Paper format").toLower())
+        return RS2::Custom;
 
-    if (p=="npagesize") return RS2::NPageSize;
+    if (ls == QStringLiteral("a0") || ls == QObject::tr("a0", "Paper format").toLower())
+        return RS2::A0;
+    if (ls == QStringLiteral("a1") || ls == QObject::tr("a1", "Paper format").toLower())
+        return RS2::A1;
+    if (ls == QStringLiteral("a2") || ls == QObject::tr("a2", "Paper format").toLower())
+        return RS2::A2;
+    if (ls == QStringLiteral("a3") || ls == QObject::tr("a3", "Paper format").toLower())
+        return RS2::A3;
+    if (ls == QStringLiteral("a4") || ls == QObject::tr("a4", "Paper format").toLower())
+        return RS2::A4;
 
-    return ret;
+    /* Removed ISO "B" and "C" series, C5E, Comm10E, DLE, (envelope sizes) */
+
+    if (ls == QStringLiteral("letter") || ls == QObject::tr("letter", "Paper format").toLower())
+        return RS2::Letter;
+    if (ls == QStringLiteral("legal")  || ls == QObject::tr("legal",  "Paper format").toLower())
+        return RS2::Legal;
+    if (ls == QStringLiteral("tabloid") || ls == QObject::tr("tabloid", "Paper format").toLower())
+        return RS2::Tabloid;
+
+    //if (ls == QStringLiteral("ansi a") || ls == QObject::tr("ansi a", "Paper format").toLower())
+    //    return RS2::Ansi_A;
+    //if (ls == QStringLiteral("ansi b") || ls == QObject::tr("ansi b", "Paper format").toLower())
+    //    return RS2::Ansi_B;
+    if (ls == QStringLiteral("ansi c") || ls == QObject::tr("ansi c", "Paper format").toLower())
+        return RS2::Ansi_C;
+    if (ls == QStringLiteral("ansi d") || ls == QObject::tr("ansi d", "Paper format").toLower())
+        return RS2::Ansi_D;
+    if (ls == QStringLiteral("ansi e") || ls == QObject::tr("ansi e", "Paper format").toLower())
+        return RS2::Ansi_E;
+
+    if (ls == QStringLiteral("arch a") || ls == QObject::tr("arch a", "Paper format").toLower())
+        return RS2::Arch_A;
+    if (ls == QStringLiteral("arch b") || ls == QObject::tr("arch b", "Paper format").toLower())
+        return RS2::Arch_B;
+    if (ls == QStringLiteral("arch c") || ls == QObject::tr("arch c", "Paper format").toLower())
+        return RS2::Arch_C;
+    if (ls == QStringLiteral("arch d") || ls == QObject::tr("arch d", "Paper format").toLower())
+        return RS2::Arch_D;
+    if (ls == QStringLiteral("arch e") || ls == QObject::tr("arch e", "Paper format").toLower())
+        return RS2::Arch_E;
+
+    return RS2::Custom;
 }
 
 /**
@@ -1378,4 +1171,3 @@ void RS_Units::test() {
        assert(s=="1∞ 30' 0\"");
     */
 }
-
