@@ -119,6 +119,9 @@ public:
 //    crossP only defined for 3D
     static RS_Vector crossP(const RS_Vector& v1, const RS_Vector& v2);
     static double dotP(const RS_Vector& v1, const RS_Vector& v2);
+    static double posInLine(const RS_Vector& start,
+                            const RS_Vector& end,
+                            const RS_Vector& pos);
 
     /** switch x,y for all vectors */
     RS_Vector flipXY(void) const;
@@ -193,8 +196,6 @@ void set(size_t i, const RS_Vector& v);
     /** switch x,y for all vectors */
     RS_VectorSolutions flipXY(void) const;
 
-    RS_VectorSolutions operator = (const RS_VectorSolutions& s);
-
     friend std::ostream& operator << (std::ostream& os,
                                       const RS_VectorSolutions& s);
 
