@@ -195,7 +195,7 @@ bool RS_FilterDXF1::readFromBuffer() {
                     }
                 }
 
-                // Dimenison Units:
+                // Dimension Units:
                 //
                 else if( dxfLine=="$DIMALT" ) {
 					dxfCode=getBufLine();
@@ -587,7 +587,7 @@ bool RS_FilterDXF1::readFromBuffer() {
                     if (currentLayer) {
                         currentLayer->setPen(pen);
                     }
-                    //graphic->setStyle("CONTINOUS");
+                    //graphic->setStyle("CONTINUOUS");
                     //graphic->setWidth(0);
                     //graphic->setColor(0, false);
                 }
@@ -1636,7 +1636,7 @@ void RS_FilterDXF1::dos2unix() {
 
 
 // Get next line in the buffer:
-//   and overread ALL seperators
+//   and overread ALL separators
 //
 // return:  -Null-string: end of buffer
 //          -String which is the next line in buffer
@@ -1646,7 +1646,7 @@ QString RS_FilterDXF1::getBufLine() {
     QString str;
 
     if (fBufP >= (int)fSize)
-        return QString::null;
+        return QString();
 
     ret = &fBuf[fBufP];
 
@@ -1655,7 +1655,7 @@ QString RS_FilterDXF1::getBufLine() {
         while (++fBufP < (int)fSize && fBuf[fBufP] == '\0')
             ;
         if (fBufP >= (int)fSize)
-            return QString::null;
+            return QString();
         ret = &fBuf[fBufP];
 }*/
 
@@ -1676,7 +1676,7 @@ QString RS_FilterDXF1::getBufLine() {
 
 
 // Get next line in the buffer:
-//   and overread ALL seperators
+//   and overread ALL separators
 //
 // return:  -Null-string: end of buffer
 //          -String which is the next line in buffer
@@ -1791,7 +1791,7 @@ void RS_FilterDXF1::separateBuf(char _c1,
 //   comments get replaced by '\0'
 //
 void RS_FilterDXF1::removeComment(char _fc, char _lc) {
-    bool rem=false;   // Are we removing currrently?
+    bool rem=false;   // Are we removing currently?
     int bc;           // counter
 
     for(bc=0; bc<(int)fSize; ++bc) {
