@@ -50,7 +50,7 @@ struct RS_LineTypePattern;
 
 /**
  * This class is a common GUI interface for the graphic viewer
- * widget which has to be implementet by real GUI classes such
+ * widget which has to be implemented by real GUI classes such
  * as the Qt graphical view.
  *
  * Note that this is just an interface used as a slot to
@@ -318,7 +318,7 @@ public:
 	void lockRelativeZero(bool lock);
 
 	/**
-		 * @return true if the position of the realtive zero point is
+		 * @return true if the position of the relative zero point is
 		 * locked.
 		 */
 	bool isRelativeZeroLocked() const;
@@ -350,7 +350,7 @@ public:
 	void setPrinting(bool p);
 
 	/**
-		 * @retval true This is a a graphic view for printing.
+		 * @retval true This is a graphic view for printing.
 		 * @retval false setSnapOtherwise.
 		 */
 	bool isPrinting() const;
@@ -370,6 +370,18 @@ public:
         return view_rect;
     }
 
+    bool isPanning() const;
+    void setPanning(bool state);
+
+    void setLineWidthScaling(bool state){
+        scaleLineWidth = state;
+    }
+
+    bool getLineWidthScaling(){
+        return scaleLineWidth;
+    }
+
+
 protected:
 
     RS_EntityContainer* container{nullptr}; // Holds a pointer to all the enties
@@ -448,6 +460,10 @@ private:
 	/** if true, graphicView is under cleanup */
 	bool m_bIsCleanUp=false;
 
+    bool panning;
+
+	bool scaleLineWidth;
+
 signals:
     void relative_zero_changed(const RS_Vector&);
     void previous_zoom_state(bool);
