@@ -25,6 +25,8 @@
 **********************************************************************/
 
 #include<cmath>
+#include<memory>
+
 #include "rs_painterqt.h"
 #include "rs_math.h"
 #include "rs_debug.h"
@@ -374,27 +376,12 @@ void RS_PainterQt::drawArcMac(const RS_Vector& cp, double radius,
 
 /**
  * Draws a circle.
- * @param cx center in x
- * @param cy center in y
+ * @param cp Center point
  * @param radius Radius
  */
-void RS_PainterQt::drawCircle(const RS_Vector& cp, double radius) {
-
-// RVT_PORT    if (drawingMode==RS2::ModeXOR && radius<500) {
-                if (radius<500) {
-        // This is _very_ slow for large arcs:
-        QPainter::drawEllipse(toScreenX(cp.x-radius),
-                              toScreenY(cp.y-radius),
-                              RS_Math::round(2.0*radius),
-                              RS_Math::round(2.0*radius));
-    } else {
-        drawArc(cp,
-                radius,
-                0.0, 2*M_PI,
-                cp + RS_Vector(radius, 0.0),
-                cp + RS_Vector(radius, 0.0),
-                false);
-        }
+void RS_PainterQt::drawCircle(const RS_Vector& cp, double radius)
+{
+    QPainter::drawEllipse(QPointF(cp.x, cp.y), radius, radius);
 }
 
 
@@ -413,12 +400,8 @@ void RS_PainterQt::drawEllipse(const RS_Vector& cp,
 }
 
 
-
-/**
- * Draws image.
- */
 void RS_PainterQt::drawImg(QImage& img, const RS_Vector& pos,
-                           double angle, const RS_Vector& factor) {
+                           const RS_Vector& uVector, const RS_Vector& vVector, const RS_Vector& factor) {
     save();
 
     // Render smooth only at close zooms
@@ -429,12 +412,20 @@ void RS_PainterQt::drawImg(QImage& img, const RS_Vector& pos,
       RS_PainterQt::setRenderHint(SmoothPixmapTransform);
     }
 
-    QMatrix wm;
-    wm.translate(pos.x, pos.y);
-    wm.rotate(RS_Math::rad2deg(-angle));
-    wm.scale(factor.x, factor.y);
-    setWorldMatrix(wm);
+    RS_Vector un = uVector/uVector.magnitude();
+    RS_Vector vn = vVector/vVector.magnitude();
 
+    // Image mirroring is switching the handedness of u-v vectors pair which can be detected by
+    // looking at the sign of the z component of their cross product. If z is negative image is mirrored.
+    std::unique_ptr<QMatrix> wm;
+    if(RS_Vector::crossP(uVector, vVector).z < 0) {
+        wm.reset(new QMatrix(un.x, -vn.x, -un.y, vn.y, pos.x, pos.y));
+    } else {
+        wm.reset( new QMatrix(un.x, vn.x, un.y, vn.y, pos.x, pos.y));
+    }
+
+    wm->scale(factor.x, factor.y);
+    setWorldMatrix(*wm);
 
     drawImage(0,-img.height(), img);
 
@@ -442,7 +433,6 @@ void RS_PainterQt::drawImg(QImage& img, const RS_Vector& pos,
 }
 
 
-
 void RS_PainterQt::drawTextH(int x1, int y1,
                              int x2, int y2,
                              const QString& text) {
@@ -530,8 +520,17 @@ RS_Pen RS_PainterQt::getPen() const{
 
 void RS_PainterQt::setPen(const RS_Pen& pen) {
     lpen = pen;
-    if (drawingMode==RS2::ModeBW) {
-        lpen.setColor(RS_Color(0,0,0));
+    switch (drawingMode) {
+    case RS2::ModeBW:
+        lpen.setColor( RS_Color( Qt::black));
+        break;
+
+    case RS2::ModeWB:
+        lpen.setColor( RS_Color( Qt::white));
+        break;
+
+    default:
+        break;
     }
     QPen p(lpen.getColor(), RS_Math::round(lpen.getScreenWidth()),
 		   rsToQtLineType(lpen.getLineType()));
@@ -541,20 +540,37 @@ void RS_PainterQt::setPen(const RS_Pen& pen) {
 }
 
 void RS_PainterQt::setPen(const RS_Color& color) {
-    if (drawingMode==RS2::ModeBW) {
-        lpen.setColor(RS_Color(0,0,0));
-        QPainter::setPen(RS_Color(0,0,0));
-    } else {
-        lpen.setColor(color);
-        QPainter::setPen(color);
+    switch (drawingMode) {
+    case RS2::ModeBW:
+        lpen.setColor( RS_Color( Qt::black));
+        QPainter::setPen( RS_Color( Qt::black));
+        break;
+
+    case RS2::ModeWB:
+        lpen.setColor( RS_Color( Qt::white));
+        QPainter::setPen( RS_Color( Qt::white));
+        break;
+
+    default:
+        lpen.setColor( color);
+        QPainter::setPen( color);
+        break;
     }
 }
 
 void RS_PainterQt::setPen(int r, int g, int b) {
-    if (drawingMode==RS2::ModeBW) {
-        setPen(QColor(0, 0, 0));
-    } else {
-        setPen(QColor(r, g, b));
+    switch (drawingMode) {
+    case RS2::ModeBW:
+        setPen( QColor( Qt::black));
+        break;
+
+    case RS2::ModeWB:
+        setPen( QColor( Qt::white));
+        break;
+
+    default:
+        setPen( QColor( r, g, b));
+        break;
     }
 }
 
@@ -564,10 +580,18 @@ void RS_PainterQt::disablePen() {
 }
 
 void RS_PainterQt::setBrush(const RS_Color& color) {
-    if (drawingMode==RS2::ModeBW) {
-        QPainter::setBrush(QColor(0, 0, 0));
-    } else {
-        QPainter::setBrush(color);
+    switch (drawingMode) {
+    case RS2::ModeBW:
+        QPainter::setBrush( QColor( Qt::black));
+        break;
+
+    case RS2::ModeWB:
+        QPainter::setBrush( QColor( Qt::white));
+        break;
+
+    default:
+        QPainter::setBrush( color);
+        break;
     }
 }
 
