@@ -47,6 +47,7 @@
 #include "rs_ellipse.h"
 #include "rs_polyline.h"
 #include "lc_splinepoints.h"
+#include "lc_undosection.h"
 #include "intern/qc_actiongetpoint.h"
 #include "intern/qc_actiongetselect.h"
 #include "intern/qc_actiongetent.h"
@@ -54,10 +55,6 @@
 #include "rs_debug.h"
 // #include <QDebug>
 
-#if QT_VERSION < 0x040500
-#include "emu_qt45.h"
-#endif
-
 convLTW::convLTW(){
 //    QHash<int, QString> lType;
     lType.insert(RS2::LineByLayer, "BYLAYER");
@@ -767,27 +764,18 @@ doc(d)
 ,docGr(doc->getGraphic())
 ,gView(gv)
 ,main_window(parent)
-,haveUndo(false){
-}
-
-Doc_plugin_interface::~Doc_plugin_interface(){
-    if (haveUndo) {
-        doc->endUndoCycle();
-    }
+{
 }
 
 bool Doc_plugin_interface::addToUndo(RS_Entity* current, RS_Entity* modified){
     if (doc) {
         doc->addEntity(modified);
-        if (!haveUndo) {
-            doc->startUndoCycle();
-            haveUndo = true;
-        }
+        LC_UndoSection undo(doc);
         if (current->isSelected())
             current->setSelected(false);
         current->changeUndoState();
-        doc->addUndoable(current);
-        doc->addUndoable(modified);
+        undo.addUndoable(current);
+        undo.addUndoable(modified);
         return true;
     } else
 		RS_DEBUG->print("Doc_plugin_interface::addToUndo: currentContainer is nullptr");
@@ -796,6 +784,7 @@ bool Doc_plugin_interface::addToUndo(RS_Entity* current, RS_Entity* modified){
 
 void Doc_plugin_interface::updateView(){
     doc->setSelected(false);
+    gView->getContainer()->calculateBorders();
     gView->redraw();
 }
 
@@ -805,11 +794,8 @@ void Doc_plugin_interface::addPoint(QPointF *start){
     if (doc) {
         RS_Point* entity = new RS_Point(doc, RS_PointData(v1));
         doc->addEntity(entity);
-        if (!haveUndo) {
-            doc->startUndoCycle();
-            haveUndo = true;
-        }
-        doc->addUndoable(entity);
+        LC_UndoSection undo(doc);
+        undo.addUndoable(entity);
     } else
 		RS_DEBUG->print("Doc_plugin_interface::addPoint: currentContainer is nullptr");
 }
@@ -821,11 +807,8 @@ void Doc_plugin_interface::addLine(QPointF *start, QPointF *end){
     if (doc) {
 		RS_Line* entity = new RS_Line{doc, v1, v2};
         doc->addEntity(entity);
-        if (!haveUndo) {
-            doc->startUndoCycle();
-            haveUndo = true;
-        }
-        doc->addUndoable(entity);
+        LC_UndoSection undo(doc);
+        undo.addUndoable(entity);
     } else
 		RS_DEBUG->print("Doc_plugin_interface::addLine: currentContainer is nullptr");
 }
@@ -845,11 +828,8 @@ void Doc_plugin_interface::addMText(QString txt, QString sty, QPointF *start,
         RS_MText* entity = new RS_MText(doc, d);
 
         doc->addEntity(entity);
-        if (!haveUndo) {
-            doc->startUndoCycle();
-            haveUndo = true;
-        }
-        doc->addUndoable(entity);
+        LC_UndoSection undo(doc);
+        undo.addUndoable(entity);
     } else
 		RS_DEBUG->print("Doc_plugin_interface::addMtext: currentContainer is nullptr");
 }
@@ -868,11 +848,8 @@ void Doc_plugin_interface::addText(QString txt, QString sty, QPointF *start,
         RS_Text* entity = new RS_Text(doc, d);
 
         doc->addEntity(entity);
-        if (!haveUndo) {
-            doc->startUndoCycle();
-            haveUndo = true;
-        }
-        doc->addUndoable(entity);
+        LC_UndoSection undo(doc);
+        undo.addUndoable(entity);
     } else
 		RS_DEBUG->print("Doc_plugin_interface::addText: currentContainer is nullptr");
 }
@@ -884,11 +861,8 @@ void Doc_plugin_interface::addCircle(QPointF *start, qreal radius){
         RS_Circle* entity = new RS_Circle(doc, d);
 
         doc->addEntity(entity);
-        if (!haveUndo) {
-            doc->startUndoCycle();
-            haveUndo = true;
-        }
-        doc->addUndoable(entity);
+        LC_UndoSection undo(doc);
+        undo.addUndoable(entity);
     } else
 		RS_DEBUG->print("Doc_plugin_interface::addCircle: currentContainer is nullptr");
 }
@@ -902,11 +876,8 @@ void Doc_plugin_interface::addArc(QPointF *start, qreal radius, qreal a1, qreal
                  false);
         RS_Arc* entity = new RS_Arc(doc, d);
         doc->addEntity(entity);
-        if (!haveUndo) {
-            doc->startUndoCycle();
-            haveUndo = true;
-        }
-        doc->addUndoable(entity);
+        LC_UndoSection undo(doc);
+        undo.addUndoable(entity);
     } else
 		RS_DEBUG->print("Doc_plugin_interface::addArc: currentContainer is nullptr");
 }
@@ -920,11 +891,8 @@ void Doc_plugin_interface::addEllipse(QPointF *start, QPointF *end, qreal ratio,
         RS_Ellipse* entity = new RS_Ellipse(doc, ed);
 
         doc->addEntity(entity);
-        if (!haveUndo) {
-            doc->startUndoCycle();
-            haveUndo = true;
-        }
-        doc->addUndoable(entity);
+        LC_UndoSection undo(doc);
+        undo.addUndoable(entity);
     } else
 		RS_DEBUG->print("Doc_plugin_interface::addEllipse: currentContainer is nullptr");
 }
@@ -934,11 +902,7 @@ void Doc_plugin_interface::addLines(std::vector<QPointF> const& points, bool clo
     if (doc) {
         RS_LineData data;
 
-        if (!haveUndo) {
-            doc->startUndoCycle();
-            haveUndo = true;
-        }
-
+        LC_UndoSection undo(doc);
         data.endpoint=RS_Vector(points.front().x(), points.front().y());
 
         for(size_t i=1; i<points.size(); ++i){
@@ -946,14 +910,14 @@ void Doc_plugin_interface::addLines(std::vector<QPointF> const& points, bool clo
             data.endpoint=RS_Vector(points[i].x(), points[i].y());
             RS_Line* line=new RS_Line(doc, data);
             doc->addEntity(line);
-            doc->addUndoable(line);
+            undo.addUndoable(line);
         }
         if(closed){
             data.startpoint=data.endpoint;
             data.endpoint=RS_Vector(points.front().x(), points.front().y());
             RS_Line* line=new RS_Line(doc, data);
             doc->addEntity(line);
-            doc->addUndoable(line);
+            undo.addUndoable(line);
         }
     } else
 		RS_DEBUG->print("%s: currentContainer is nullptr", __func__);
@@ -972,11 +936,8 @@ void Doc_plugin_interface::addPolyline(std::vector<Plug_VertexData> const& point
         }
 
         doc->addEntity(entity);
-        if (!haveUndo) {
-            doc->startUndoCycle();
-            haveUndo = true;
-        }
-        doc->addUndoable(entity);
+        LC_UndoSection undo(doc);
+        undo.addUndoable(entity);
     } else
 		RS_DEBUG->print("%s: currentContainer is nullptr", __func__);
 }
@@ -992,11 +953,8 @@ void Doc_plugin_interface::addSplinePoints(std::vector<QPointF> const& points, b
         LC_SplinePoints* entity = new LC_SplinePoints(doc, data);
 
         doc->addEntity(entity);
-        if (!haveUndo) {
-            doc->startUndoCycle();
-            haveUndo = true;
-        }
-        doc->addUndoable(entity);
+        LC_UndoSection undo(doc);
+        undo.addUndoable(entity);
     } else
 		RS_DEBUG->print("%s: currentContainer is nullptr", __func__);
 }
@@ -1021,11 +979,8 @@ void Doc_plugin_interface::addImage(int handle, QPointF *start, QPointF *uvr, QP
                          fade));
 
         doc->addEntity(image);
-        if (!haveUndo) {
-            doc->startUndoCycle();
-            haveUndo = true;
-        }
-        doc->addUndoable(image);
+        LC_UndoSection undo(doc);
+        undo.addUndoable(image);
     } else
 		RS_DEBUG->print("Doc_plugin_interface::addImage: currentContainer is nullptr");
 }
@@ -1039,11 +994,8 @@ void Doc_plugin_interface::addInsert(QString name, QPointF ins, QPointF scale, q
         RS_Insert* entity = new RS_Insert(doc, id);
 
         doc->addEntity(entity);
-        if (!haveUndo) {
-            doc->startUndoCycle();
-            haveUndo = true;
-        }
-        doc->addUndoable(entity);
+        LC_UndoSection undo(doc);
+        undo.addUndoable(entity);
     } else
 		RS_DEBUG->print("Doc_plugin_interface::addInsert: currentContainer is nullptr");
 }
@@ -1099,11 +1051,8 @@ void Doc_plugin_interface::addEntity(Plug_Entity *handle){
         RS_Entity *ent = (reinterpret_cast<Plugin_Entity*>(handle))->getEnt();
 		if (ent) {
             doc->addEntity(ent);
-            if (!haveUndo) {
-                doc->startUndoCycle();
-                haveUndo = true;
-            }
-            doc->addUndoable(ent);
+            LC_UndoSection undo(doc);
+            undo.addUndoable(ent);
         }
     } else
 		RS_DEBUG->print("Doc_plugin_interface::addEntity: currentContainer is nullptr");
@@ -1123,13 +1072,10 @@ Plug_Entity *Doc_plugin_interface::newEntity( enum DPI::ETYPE type){
 void Doc_plugin_interface::removeEntity(Plug_Entity *ent){
     RS_Entity *e = (reinterpret_cast<Plugin_Entity*>(ent))->getEnt();
     if (doc && e) {
-        if (!haveUndo) {
-            doc->startUndoCycle();
-            haveUndo = true;
-        }
+        LC_UndoSection undo(doc);
         e->setSelected(false);
         e->changeUndoState();
-        doc->addUndoable(e);
+        undo.addUndoable(e);
 
         gView->redraw(RS2::RedrawDrawing);
     }
@@ -1137,14 +1083,11 @@ void Doc_plugin_interface::removeEntity(Plug_Entity *ent){
 
 void Doc_plugin_interface::updateEntity(RS_Entity *org, RS_Entity *newe){
     if (doc) {
-            if (!haveUndo) {
-                doc->startUndoCycle();
-                haveUndo = true;
-            }
-            doc->addEntity(newe);
-            doc->addUndoable(newe);
-            doc->addUndoable(org);
-            org->setUndoState(true);
+        LC_UndoSection undo(doc);
+        doc->addEntity(newe);
+        undo.addUndoable(newe);
+        undo.addUndoable(org);
+        org->setUndoState(true);
     } else
 		RS_DEBUG->print("Doc_plugin_interface::addEntity: currentContainer is nullptr");
 }
@@ -1234,12 +1177,12 @@ void Doc_plugin_interface::setCurrentLayerProperties(int c, QString const& w,
     }
 }
 
-bool Doc_plugin_interface::getPoint(QPointF *point, const QString& mesage,
+bool Doc_plugin_interface::getPoint(QPointF *point, const QString& message,
 									QPointF *base){
     bool status = false;
     QC_ActionGetPoint* a = new QC_ActionGetPoint(*doc, *gView);
     if (a) {
-        if (!(mesage.isEmpty()) ) a->setMesage(mesage);
+        if (!(message.isEmpty()) ) a->setMessage(message);
         gView->killAllActions();
         gView->setCurrentAction(a);
         if (base) a->setBasepoint(base);
@@ -1254,17 +1197,17 @@ bool Doc_plugin_interface::getPoint(QPointF *point, const QString& mesage,
             a->getPoint(point);
             status = true;
         }
-//RLZ: delete QC_ActionGetPoint. Investigate how to kill only this action
+        //RLZ: delete QC_ActionGetPoint. Investigate how to kill only this action
         gView->killAllActions();
     }
     return status;
 }
 
-Plug_Entity *Doc_plugin_interface::getEnt(const QString& mesage){
+Plug_Entity *Doc_plugin_interface::getEnt(const QString& message){
     QC_ActionGetEnt* a = new QC_ActionGetEnt(*doc, *gView);
     if (a) {
-        if (!(mesage.isEmpty()) )
-            a->setMesage(mesage);
+        if (!(message.isEmpty()) )
+            a->setMessage(message);
         gView->killAllActions();
         gView->setCurrentAction(a);
         QEventLoop ev;
@@ -1274,20 +1217,19 @@ Plug_Entity *Doc_plugin_interface::getEnt(const QString& mesage){
             if (!gView->getEventHandler()->hasAction())
                 break;
         }
-        // qDebug() << "getEnt: passed event loop";
     }
     Plug_Entity *e = reinterpret_cast<Plug_Entity*>(a->getSelected(this));
-    // qDebug() << e;
+    a->finish();
     gView->killAllActions();
     return e;
 }
 
-bool Doc_plugin_interface::getSelect(QList<Plug_Entity *> *sel, const QString& mesage){
+bool Doc_plugin_interface::getSelect(QList<Plug_Entity *> *sel, const QString& message){
     bool status = false;
     QC_ActionGetSelect* a = new QC_ActionGetSelect(*doc, *gView);
     if (a) {
-        if (!(mesage.isEmpty()) )
-            a->setMesage(mesage);
+        if (!(message.isEmpty()) )
+            a->setMessage(message);
         gView->killAllActions();
         gView->setCurrentAction(a);
         QEventLoop ev;
@@ -1352,35 +1294,31 @@ bool Doc_plugin_interface::addVariable(const QString& key, double value, int cod
    return true;
 }
 
-bool Doc_plugin_interface::getInt(int *num, const QString& mesage, const QString& title){
+bool Doc_plugin_interface::getInt(int *num, const QString& message, const QString& title){
     bool ok;
     QString msg, tit;
-    if ( mesage.isEmpty() )
+    if ( message.isEmpty() )
         msg = QObject::tr("enter an integer number");
     else
-        msg = mesage;
+        msg = message;
     if ( title.isEmpty() )
         tit = QObject::tr("LibreCAD query");
     else
         tit = title;
 
-#if QT_VERSION < 0x040500
-    int data = emu_qt45_QInputDialog_getInt(main_window, tit, msg, 0, -2147483647, 2147483647, 1, &ok);
-#else
     int data = QInputDialog::getInt(main_window, tit, msg, 0, -2147483647, 2147483647, 1, &ok);
-#endif
 
     if (ok)
         *num = data;
     return ok;
 }
-bool Doc_plugin_interface::getReal(qreal *num, const QString& mesage, const QString& title){
+bool Doc_plugin_interface::getReal(qreal *num, const QString& message, const QString& title){
     bool ok;
     QString msg, tit;
-    if ( mesage.isEmpty() )
+    if ( message.isEmpty() )
         msg = QObject::tr("enter a number");
     else
-        msg = mesage;
+        msg = message;
     if ( title.isEmpty() )
         tit = QObject::tr("LibreCAD query");
     else
@@ -1391,13 +1329,13 @@ bool Doc_plugin_interface::getReal(qreal *num, const QString& mesage, const QStr
         *num = data;
     return ok;
 }
-bool Doc_plugin_interface::getString(QString *txt, const QString& mesage, const QString& title){
+bool Doc_plugin_interface::getString(QString *txt, const QString& message, const QString& title){
     bool ok;
     QString msg, tit;
-    if ( mesage.isEmpty() )
+    if ( message.isEmpty() )
         msg = QObject::tr("enter text");
     else
-        msg = mesage;
+        msg = message;
     if ( title.isEmpty() )
         tit = QObject::tr("LibreCAD query");
     else
@@ -1434,6 +1372,9 @@ QString Doc_plugin_interface::realToStr(const qreal num, const int units, const
     case 5:
         lf = RS2::Fractional;
         break;
+    case 6:
+        lf = RS2::ArchitecturalMetric;
+        break;
     default:
         lf = RS2::Decimal;
     }
@@ -1441,4 +1382,3 @@ QString Doc_plugin_interface::realToStr(const qreal num, const int units, const
     QString msg = RS_Units::formatLinear(num,RS2::None,lf,pr);
     return msg;
 }
-
