@@ -2,7 +2,9 @@
 **
 ** This file is part of the LibreCAD project, a 2D CAD program
 **
-** Copyright (C) 2015-2016 ravas (ravas@outlook.com - github.com/r-a-v-a-s)
+** Copyright (C) 2018 A. Stebich (librecad@mail.lordofbikes.de)
+** Copyright (C) 2018 Simon Wells <simonrwells@gmail.com>
+** Copyright (C) 2015-2016 ravas (github.com/r-a-v-a-s)
 ** Copyright (C) 2010 R. van Twisk (librecad@rvt.dds.nl)
 ** Copyright (C) 2001-2003 RibbonSoft. All rights reserved.
 **
@@ -30,29 +32,57 @@
 #include <QApplication>
 #include <QSplashScreen>
 #include <QSettings>
+#include <QMessageBox>
+#include <QFileInfo>
 
 #include "rs_fontlist.h"
 #include "rs_patternlist.h"
 #include "rs_settings.h"
 #include "rs_system.h"
-#include "rs_fileio.h"
 #include "qg_dlginitial.h"
 
+#include "lc_application.h"
 #include "qc_applicationwindow.h"
 #include "rs_debug.h"
 
+#include "console_dxf2pdf.h"
+
+
 /**
  * Main. Creates Application window.
  */
 int main(int argc, char** argv)
 {
+    QT_REQUIRE_VERSION(argc, argv, "5.2.1");
+
+    /* Check first two arguments in order to decide if we want to run librecad
+     * as console dxf2pdf tool. On Linux we can create a link to librecad
+     * executable and  name it dxf2pdf. So, we can run either:
+     *     librecad dxf2pdf [options] ...
+     * or just:
+     *     dxf2pdf [options] ...
+     */
+    for (int i = 0; i < qMin(argc, 2); i++) {
+        QString arg(argv[i]);
+        if (i == 0) {
+            arg = QFileInfo(QFile::decodeName(argv[i])).baseName();
+        }
+        if (arg.compare("dxf2pdf") == 0) {
+            return console_dxf2pdf(argc, argv);
+        }
+    }
+
     RS_DEBUG->setLevel(RS_Debug::D_WARNING);
 
-    QApplication app(argc, argv);
+    LC_Application app(argc, argv);
     QCoreApplication::setOrganizationName("LibreCAD");
     QCoreApplication::setApplicationName("LibreCAD");
     QCoreApplication::setApplicationVersion(XSTR(LC_VERSION));
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 7, 0))
+    QGuiApplication::setDesktopFileName("librecad.desktop");
+#endif
+
     QSettings settings;
 
     bool first_load = settings.value("Startup/FirstLoad", 1).toBool();
@@ -72,11 +102,17 @@ int main(int argc, char** argv)
         if (allowOptions && (help0.compare(argstr, Qt::CaseInsensitive)==0 ||
                              help1.compare(argstr, Qt::CaseInsensitive)==0 ))
         {
-            qDebug()<<"librecad::usage: <options> <dxf file>";
-            qDebug()<<"-h, --help\tdisplay this message";
+            qDebug()<<"Usage: librecad [command] <options> <dxf file>";
+            qDebug()<<"";
+            qDebug()<<"Commands:";
+            qDebug()<<"";
+            qDebug()<<"  dxf2pdf\tRun librecad as console dxf2pdf tool. Use -h for help.";
+            qDebug()<<"";
+            qDebug()<<"Options:";
+            qDebug()<<"";
+            qDebug()<<"  -h, --help\tdisplay this message";
+            qDebug()<<"  -d, --debug <level>";
             qDebug()<<"";
-            qDebug()<<" --help\tdisplay this message";
-            qDebug()<<"-d, --debug <level>";
             RS_DEBUG->print( RS_Debug::D_NOTHING, "possible debug levels:");
             RS_DEBUG->print( RS_Debug::D_NOTHING, "    %d Nothing", RS_Debug::D_NOTHING);
             RS_DEBUG->print( RS_Debug::D_NOTHING, "    %d Critical", RS_Debug::D_CRITICAL);
@@ -133,37 +169,30 @@ int main(int argc, char** argv)
 
             case '0' + RS_Debug::D_NOTHING :
                 RS_DEBUG->setLevel( RS_Debug::D_NOTHING);
-                ++i;
                 break;
 
             case '0' + RS_Debug::D_CRITICAL :
                 RS_DEBUG->setLevel( RS_Debug::D_CRITICAL);
-                ++i;
                 break;
 
             case '0' + RS_Debug::D_ERROR :
                 RS_DEBUG->setLevel( RS_Debug::D_ERROR);
-                ++i;
                 break;
 
             case '0' + RS_Debug::D_WARNING :
                 RS_DEBUG->setLevel( RS_Debug::D_WARNING);
-                ++i;
                 break;
 
             case '0' + RS_Debug::D_NOTICE :
                 RS_DEBUG->setLevel( RS_Debug::D_NOTICE);
-                ++i;
                 break;
 
             case '0' + RS_Debug::D_INFORMATIONAL :
                 RS_DEBUG->setLevel( RS_Debug::D_INFORMATIONAL);
-                ++i;
                 break;
 
             case '0' + RS_Debug::D_DEBUGGING :
                 RS_DEBUG->setLevel( RS_Debug::D_DEBUGGING);
-                ++i;
                 break;
 
             default :
@@ -174,10 +203,8 @@ int main(int argc, char** argv)
     }
     RS_DEBUG->print("param 0: %s", argv[0]);
 
-    QFileInfo prgInfo( QFile::decodeName(argv[0]) );
-    QString prgDir(prgInfo.absolutePath());
     RS_SETTINGS->init(app.organizationName(), app.applicationName());
-    RS_SYSTEM->init(app.applicationName(), app.applicationVersion(), XSTR(QC_APPDIR), prgDir);
+    RS_SYSTEM->init( app.applicationName(), app.applicationVersion(), XSTR(QC_APPDIR), argv[0]);
 
     // parse command line arguments that might not need a launched program:
     QStringList fileList = handleArgs(argc, argv, argClean);
@@ -236,6 +263,9 @@ int main(int argc, char** argv)
 
     RS_DEBUG->print("main: creating main window..");
     QC_ApplicationWindow appWin;
+#ifdef Q_OS_MAC
+    app.installEventFilter(&appWin);
+#endif
     RS_DEBUG->print("main: setting caption");
     appWin.setWindowTitle(app.applicationName());
 
@@ -248,6 +278,18 @@ int main(int argc, char** argv)
     int windowY = settings.value("WindowY", 32).toInt();
     settings.endGroup();
 
+    settings.beginGroup("Defaults");
+    if( !settings.contains("UseQtFileOpenDialog")) {
+#ifdef Q_OS_LINUX
+        // on Linux don't use native file dialog
+        // because of case insensitive filters (issue #791)
+        settings.setValue("UseQtFileOpenDialog", QVariant(1));
+#else
+        settings.setValue("UseQtFileOpenDialog", QVariant(0));
+#endif
+    }
+    settings.endGroup();
+
     if (!first_load)
         appWin.resize(windowWidth, windowHeight);
 
@@ -275,10 +317,14 @@ int main(int argc, char** argv)
         RS_DEBUG->print("main: updating splash: OK");
     }
 
-    // Set LC_NUMERIC so that entering numeric values uses . as the decimal seperator
+    // Set LC_NUMERIC so that entering numeric values uses . as the decimal separator
     setlocale(LC_NUMERIC, "C");
 
     RS_DEBUG->print("main: loading files..");
+#ifdef Q_OS_MAC
+    // get the file list from LC_Application
+    fileList << app.fileList();
+#endif
     bool files_loaded = false;
     for (QStringList::Iterator it = fileList.begin(); it != fileList.end(); ++it )
     {
@@ -289,7 +335,7 @@ int main(int argc, char** argv)
             Qt::AlignRight|Qt::AlignBottom, Qt::black);
             qApp->processEvents();
         }
-        appWin.slotFileOpen(*it, RS2::FormatUnknown);
+        appWin.slotFileOpen(*it);
         files_loaded = true;
     }
     RS_DEBUG->print("main: loading files: OK");
