@@ -40,14 +40,14 @@ struct QC_ActionGetPoint::Points {
 		RS_MoveData data;
 		RS_Vector referencePoint;
 		RS_Vector targetPoint;
-		QString mesage;
+		QString message;
 };
 
 QC_ActionGetPoint::QC_ActionGetPoint(RS_EntityContainer& container,
         RS_GraphicView& graphicView)
         :RS_PreviewActionInterface("Get Point",
 						   container, graphicView)
-        , canceled{false}
+        , canceled(false)
 		, completed{false}
 		, setTargetPoint{false}
 		, pPoints(new Points{})
@@ -116,7 +116,7 @@ void QC_ActionGetPoint::coordinateEvent(RS_CoordinateEvent* e) {
 
 void QC_ActionGetPoint::updateMouseButtonHints() {
     if (!completed)
-		RS_DIALOGFACTORY->updateMouseWidget(pPoints->mesage, tr("Cancel"));
+		RS_DIALOGFACTORY->updateMouseWidget(pPoints->message, tr("Cancel"));
     else
         RS_DIALOGFACTORY->updateMouseWidget();
 }
@@ -134,15 +134,19 @@ void QC_ActionGetPoint::setBasepoint(QPointF* basepoint){
 }
 
 
-void QC_ActionGetPoint::setMesage(QString msg){
-	pPoints->mesage = msg;
+void QC_ActionGetPoint::setMessage(QString msg){
+	pPoints->message = msg;
 }
 
 
 void QC_ActionGetPoint::getPoint(QPointF *point)
 {
-    point->setX(pPoints->targetPoint.x);
-    point->setY(pPoints->targetPoint.y);
+    if (pPoints)
+    {
+        point->setX(pPoints->targetPoint.x);
+        point->setY(pPoints->targetPoint.y);
+    }
+
 }
 
 // EOF
