@@ -4,7 +4,7 @@
 **
 ** Copyright (C) 2010 R. van Twisk (librecad@rvt.dds.nl)
 ** Copyright (C) 2001-2003 RibbonSoft. All rights reserved.
-**
+** Copyright (C) 2015, 2016 ravas (github.com/r-a-v-a-s)
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software 
@@ -50,7 +50,10 @@ QG_DlgOptionsGeneral::QG_DlgOptionsGeneral(QWidget* parent, bool modal, Qt::Wind
     setupUi(this);
     tabWidget->setCurrentIndex(current_tab);
     init();
-
+    connect(variablefile_button, &QToolButton::clicked,
+            this, &QG_DlgOptionsGeneral::setVariableFile);
+    connect(fonts_button, &QToolButton::clicked,
+            this, &QG_DlgOptionsGeneral::setFontsFolder);
 }
 
 /*
@@ -157,6 +160,7 @@ void QG_DlgOptionsGeneral::init()
     lePathFonts->setText(RS_SETTINGS->readEntry("/Fonts", ""));
     lePathLibrary->setText(RS_SETTINGS->readEntry("/Library", "").trimmed());
     leTemplate->setText(RS_SETTINGS->readEntry("/Template", "").trimmed());
+    variablefile_field->setText(RS_SETTINGS->readEntry("/VariableFile", "").trimmed());
     RS_SETTINGS->endGroup();
 
     // units:
@@ -175,6 +179,10 @@ void QG_DlgOptionsGeneral::init()
     // Auto save timer
     cbAutoSaveTime->setValue(RS_SETTINGS->readNumEntry("/AutoSaveTime", 5));
     cbAutoBackup->setChecked(RS_SETTINGS->readNumEntry("/AutoBackupDocument", 1));
+    cbUseQtFileOpenDialog->setChecked(RS_SETTINGS->readNumEntry("/UseQtFileOpenDialog", 1));
+    cbWheelScrollInvertH->setChecked(RS_SETTINGS->readNumEntry("/WheelScrollInvertH", 0));
+    cbWheelScrollInvertV->setChecked(RS_SETTINGS->readNumEntry("/WheelScrollInvertV", 0));
+    cbInvertZoomDirection->setChecked(RS_SETTINGS->readNumEntry("/InvertZoomDirection", 0));
     RS_SETTINGS->endGroup();
 
 	//update entities to selected entities to the current active layer
@@ -184,15 +192,21 @@ void QG_DlgOptionsGeneral::init()
 	RS_SETTINGS->writeEntry("/ModifyEntitiesToActiveLayer", cbToActiveLayer->isChecked()?1:0);
 	RS_SETTINGS->endGroup();
 
+	RS_SETTINGS->beginGroup("/CADPreferences");
+	cbAutoZoomDrawing->setChecked(RS_SETTINGS->readNumEntry("/AutoZoomDrawing"));
+	RS_SETTINGS->endGroup();
+
     RS_SETTINGS->beginGroup("Startup");
     cbSplash->setChecked(RS_SETTINGS->readNumEntry("/ShowSplash",1)==1);
     tab_mode_check_box->setChecked(RS_SETTINGS->readNumEntry("/TabMode", 0));
     maximize_checkbox->setChecked(RS_SETTINGS->readNumEntry("/Maximize", 0));
     left_sidebar_checkbox->setChecked(RS_SETTINGS->readNumEntry("/EnableLeftSidebar", 1));
     cad_toolbars_checkbox->setChecked(RS_SETTINGS->readNumEntry("/EnableCADToolbars", 1));
-    keycode_checkbox->setChecked(RS_SETTINGS->readNumEntry("/KeycodeMode", 0));
     RS_SETTINGS->endGroup();
 
+	cbEvaluateOnSpace->setChecked(RS_SETTINGS->readNumEntry("/Keyboard/EvaluateCommandOnSpace", false));
+	cbToggleFreeSnapOnSpace->setChecked(RS_SETTINGS->readNumEntry("/Keyboard/ToggleFreeSnapOnSpace", false));
+
     restartNeeded = false;
 }
 
@@ -257,13 +271,18 @@ void QG_DlgOptionsGeneral::ok()
         RS_SETTINGS->writeEntry("/Fonts", lePathFonts->text());
         RS_SETTINGS->writeEntry("/Library", lePathLibrary->text());
         RS_SETTINGS->writeEntry("/Template", leTemplate->text());
+        RS_SETTINGS->writeEntry("/VariableFile", variablefile_field->text());
         RS_SETTINGS->endGroup();
 
         RS_SETTINGS->beginGroup("/Defaults");
         RS_SETTINGS->writeEntry("/Unit",
             RS_Units::unitToString( RS_Units::stringToUnit( cbUnit->currentText() ), false/*untr.*/) );
         RS_SETTINGS->writeEntry("/AutoSaveTime", cbAutoSaveTime->value() );
-        RS_SETTINGS->writeEntry("/AutoBackupDocument", cbAutoBackup->isChecked()?1:0);
+        RS_SETTINGS->writeEntry("/AutoBackupDocument", cbAutoBackup->isChecked() ? 1 : 0);
+        RS_SETTINGS->writeEntry("/UseQtFileOpenDialog", cbUseQtFileOpenDialog->isChecked() ? 1 : 0);
+        RS_SETTINGS->writeEntry("/WheelScrollInvertH", cbWheelScrollInvertH->isChecked() ? 1 : 0);
+        RS_SETTINGS->writeEntry("/WheelScrollInvertV", cbWheelScrollInvertV->isChecked() ? 1 : 0);
+        RS_SETTINGS->writeEntry("/InvertZoomDirection", cbInvertZoomDirection->isChecked() ? 1 : 0);
         RS_SETTINGS->endGroup();
 
         //update entities to selected entities to the current active layer
@@ -271,18 +290,23 @@ void QG_DlgOptionsGeneral::ok()
         RS_SETTINGS->writeEntry("/ModifyEntitiesToActiveLayer", cbToActiveLayer->isChecked()?1:0);
         RS_SETTINGS->endGroup();
 
+		RS_SETTINGS->beginGroup("/CADPreferences");
+		RS_SETTINGS->writeEntry("/AutoZoomDrawing", cbAutoZoomDrawing->isChecked() ? 1 : 0);
+		RS_SETTINGS->endGroup();
+
         RS_SETTINGS->beginGroup("Startup");
         RS_SETTINGS->writeEntry("/ShowSplash", cbSplash->isChecked()?1:0);
         RS_SETTINGS->writeEntry("/TabMode", tab_mode_check_box->isChecked()?1:0);
         RS_SETTINGS->writeEntry("/Maximize", maximize_checkbox->isChecked()?1:0);
         RS_SETTINGS->writeEntry("/EnableLeftSidebar", left_sidebar_checkbox->isChecked()?1:0);
         RS_SETTINGS->writeEntry("/EnableCADToolbars", cad_toolbars_checkbox->isChecked()?1:0);
-        RS_SETTINGS->writeEntry("/KeycodeMode", keycode_checkbox->isChecked()?1:0);
         RS_SETTINGS->endGroup();
+
+		RS_SETTINGS->writeEntry("/Keyboard/EvaluateCommandOnSpace", cbEvaluateOnSpace->isChecked() ? 1 : 0);
+		RS_SETTINGS->writeEntry("/Keyboard/ToggleFreeSnapOnSpace", cbToggleFreeSnapOnSpace->isChecked() ? 1 : 0);
     }
-
-
-    if (restartNeeded==true) {
+	
+	if (restartNeeded==true) {
         QMessageBox::warning( this, tr("Preferences"),
                               tr("Please restart the application to apply all changes."),
                               QMessageBox::Ok,
@@ -375,3 +399,30 @@ void QG_DlgOptionsGeneral::on_pb_clear_geometry_clicked()
     RS_SETTINGS->clear_geometry();
     QMessageBox::information(this, "info", "You must restart LibreCAD to see the changes.");
 }
+
+void QG_DlgOptionsGeneral::setVariableFile()
+{
+    QString path = QFileDialog::getOpenFileName(this);
+    if (!path.isEmpty())
+    {
+        variablefile_field->setText(QDir::toNativeSeparators(path));
+    }
+}
+
+/*!
+ * \brief slot for the font folder selection icon
+ * \author ravas
+ * \date 2016-286
+ */
+void QG_DlgOptionsGeneral::setFontsFolder()
+{
+    QFileDialog dlg(this);
+    dlg.setFileMode(QFileDialog::Directory);
+    dlg.setOption(QFileDialog::ShowDirsOnly);
+
+    if (dlg.exec())
+    {
+        auto dir = dlg.selectedFiles()[0];
+        lePathFonts->setText(QDir::toNativeSeparators(dir));
+    }
+}
