@@ -28,6 +28,7 @@
 #include "rs_actiondrawlineparallel.h"
 #include "rs_settings.h"
 #include "rs_math.h"
+#include "ui_qg_lineparalleloptions.h"
 #include "rs_debug.h"
 
 /*
@@ -36,9 +37,9 @@
  */
 QG_LineParallelOptions::QG_LineParallelOptions(QWidget* parent, Qt::WindowFlags fl)
     : QWidget(parent, fl)
+	, ui(new Ui::Ui_LineParallelOptions{})
 {
-    setupUi(this);
-
+	ui->setupUi(this);
 }
 
 /*
@@ -46,8 +47,7 @@ QG_LineParallelOptions::QG_LineParallelOptions(QWidget* parent, Qt::WindowFlags
  */
 QG_LineParallelOptions::~QG_LineParallelOptions()
 {
-    destroy();
-    // no need to delete child widgets, Qt does it all for us
+	saveSettings();
 }
 
 /*
@@ -56,13 +56,13 @@ QG_LineParallelOptions::~QG_LineParallelOptions()
  */
 void QG_LineParallelOptions::languageChange()
 {
-    retranslateUi(this);
+	ui->retranslateUi(this);
 }
 
-void QG_LineParallelOptions::destroy() {
+void QG_LineParallelOptions::saveSettings() {
     RS_SETTINGS->beginGroup("/Draw");
-    RS_SETTINGS->writeEntry("/LineParallelDistance", leDist->text());
-    RS_SETTINGS->writeEntry("/LineParallelNumber", sbNumber->text());
+	RS_SETTINGS->writeEntry("/LineParallelDistance", ui->leDist->text());
+	RS_SETTINGS->writeEntry("/LineParallelNumber", ui->sbNumber->text());
     RS_SETTINGS->endGroup();
 }
 
@@ -81,12 +81,12 @@ void QG_LineParallelOptions::setAction(RS_ActionInterface* a, bool update) {
             sn = RS_SETTINGS->readEntry("/LineParallelNumber", "1");
             RS_SETTINGS->endGroup();
         }
-        leDist->setText(sd);
-        sbNumber->setValue(sn.toInt());
+		ui->leDist->setText(sd);
+		ui->sbNumber->setValue(sn.toInt());
     } else {
         RS_DEBUG->print(RS_Debug::D_ERROR, 
 			"QG_LineParallelOptions::setAction: wrong action type");
-        action = NULL;
+		action = nullptr;
     }
 
 }
