@@ -3,7 +3,7 @@
 **
 ** This file was created for the LibreCAD project (librecad.org), a 2D CAD program.
 **
-** Copyright (C) 2015 ravas (ravas@outlook.com - github.com/r-a-v-a-s)
+** Copyright (C) 2015 ravas (github.com/r-a-v-a-s)
 **
 ** This program is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License
@@ -30,10 +30,13 @@
 
 #include "lc_actionfactory.h"
 #include "lc_actiongroupmanager.h"
+#include "qc_applicationwindow.h"
+#include "qg_actionhandler.h"
+
 #include <QAction>
 #include <QActionGroup>
 
-LC_ActionFactory::LC_ActionFactory(QObject* parent, QObject* a_handler)
+LC_ActionFactory::LC_ActionFactory(QC_ApplicationWindow* parent, QG_ActionHandler* a_handler)
     : QObject(parent)
     , using_theme(false)
     , main_window(parent)
@@ -228,6 +231,13 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
     action->setObjectName("DrawLinePolygonCenCor");
     a_map["DrawLinePolygonCenCor"] = action;
 
+    action = new QAction(tr("Pol&ygon (Cen,Tan)"), agm->line);  //20161223 added by txmy
+    action->setIcon(QIcon(":/icons/line_polygon_cen_tan.svg"));
+    connect(action, SIGNAL(triggered()),
+    action_handler, SLOT(slotDrawLinePolygon3()));
+    action->setObjectName("DrawLinePolygonCenTan");
+    a_map["DrawLinePolygonCenTan"] = action;
+
     action = new QAction(tr("Polygo&n (Cor,Cor)"), agm->line);
     action->setIcon(QIcon(":/icons/line_polygon_cor_cor.svg"));
     connect(action, SIGNAL(triggered()),
@@ -544,13 +554,15 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
     action->setObjectName("DimDiametric");
     a_map["DimDiametric"] = action;
 
-    action = new QAction(QIcon(":/icons/dim_angular.svg"), tr("&Angular"), agm->dimension);
+    action = new QAction(tr("&Angular"), agm->dimension);
+    action->setIcon(QIcon(":/icons/dim_angular.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotDimAngular()));
     action->setObjectName("DimAngular");
     a_map["DimAngular"] = action;
 
-    action = new QAction(QIcon(":/icons/dim_leader.svg"), tr("&Leader"), agm->dimension);
+    action = new QAction(tr("&Leader"), agm->dimension);
+    action->setIcon(QIcon(":/icons/dim_leader.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotDimLeader()));
     action->setObjectName("DimLeader");
@@ -566,7 +578,8 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
     action->setData("modifyattr, attr, ma");
     a_map["ModifyAttributes"] = action;
 
-    action = new QAction(QIcon(":/icons/delete.svg"), tr("&Delete"), agm->modify);
+    action = new QAction(tr("&Delete"), agm->modify);
+    action->setIcon(QIcon(":/icons/delete.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotModifyDelete()));
     action->setObjectName("ModifyDelete");
@@ -578,7 +591,8 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
     action->setObjectName("ModifyDeleteFree");
     a_map["ModifyDeleteFree"] = action;
 
-    action = new QAction(QIcon(":/icons/move_copy.svg"), tr("&Move / Copy"), agm->modify);
+    action = new QAction(tr("&Move / Copy"), agm->modify);
+    action->setIcon(QIcon(":/icons/move_copy.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotModifyMove()));
     action->setObjectName("ModifyMove");
@@ -593,34 +607,39 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
     action->setData("revert, rev");
     a_map["ModifyRevertDirection"] = action;
 
-    action = new QAction(QIcon(":/icons/rotate.svg"), tr("&Rotate"), agm->modify);
+    action = new QAction(tr("&Rotate"), agm->modify);
+    action->setIcon(QIcon(":/icons/rotate.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotModifyRotate()));
     action->setObjectName("ModifyRotate");
     action->setData("rotate, ro");
     a_map["ModifyRotate"] = action;
 
-    action = new QAction(QIcon(":/icons/scale.svg"), tr("&Scale"), agm->modify);
+    action = new QAction(tr("&Scale"), agm->modify);
+    action->setIcon(QIcon(":/icons/scale.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotModifyScale()));
     action->setObjectName("ModifyScale");
     action->setData("scale, sz");
     a_map["ModifyScale"] = action;
 
-    action = new QAction(QIcon(":/icons/mirror.svg"), tr("&Mirror"), agm->modify);
+    action = new QAction(tr("&Mirror"), agm->modify);
+    action->setIcon(QIcon(":/icons/mirror.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotModifyMirror()));
     action->setObjectName("ModifyMirror");
     action->setData("mirror, mi");
     a_map["ModifyMirror"] = action;
 
-    action = new QAction(QIcon(":/icons/move_rotate.svg"), tr("Mo&ve and Rotate"), agm->modify);
+    action = new QAction(tr("Mo&ve and Rotate"), agm->modify);
+    action->setIcon(QIcon(":/icons/move_rotate.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotModifyMoveRotate()));
     action->setObjectName("ModifyMoveRotate");
     a_map["ModifyMoveRotate"] = action;
 
-    action = new QAction(QIcon(":/icons/rotate2.svg"), tr("Rotate T&wo"), agm->modify);
+    action = new QAction(tr("Rotate T&wo"), agm->modify);
+    action->setIcon(QIcon(":/icons/rotate2.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotModifyRotate2()));
     action->setObjectName("ModifyRotate2");
@@ -658,7 +677,8 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
     action->setData("lengthen, le");
     a_map["ModifyTrimAmount"] = action;
 
-    action = new QAction(QIcon(":/icons/offset.svg"), tr("O&ffset"),agm->modify);
+    action = new QAction(tr("O&ffset"),agm->modify);
+    action->setIcon(QIcon(":/icons/offset.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotModifyOffset()));
     action->setObjectName("ModifyOffset");
@@ -673,7 +693,8 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
     action->setData("divide, cut, div");
     a_map["ModifyCut"] = action;
 
-    action = new QAction(QIcon(":/icons/stretch.svg"), tr("&Stretch"), agm->modify);
+    action = new QAction(tr("&Stretch"), agm->modify);
+    action->setIcon(QIcon(":/icons/stretch.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotModifyStretch()));
     action->setObjectName("ModifyStretch");
@@ -688,7 +709,8 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
     action->setData("bevel, bev, ch");
     a_map["ModifyBevel"] = action;
 
-    action = new QAction(QIcon(":/icons/fillet.svg"), tr("&Fillet"), agm->modify);
+    action = new QAction(tr("&Fillet"), agm->modify);
+    action->setIcon(QIcon(":/icons/fillet.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotModifyRound()));
     action->setObjectName("ModifyRound");
@@ -798,43 +820,57 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
 
     // <[~ Layer ~]>
 
-    action = new QAction(QIcon(":/ui/visibleblock.png"),
-                         tr("&Show all"), agm->layer);
+    action = new QAction(tr("&Show all"), agm->layer);
+    action->setIcon(QIcon(":/ui/visibleblock.png"));
     connect(action, SIGNAL(triggered()),
             action_handler, SLOT(slotLayersDefreezeAll()));
     action->setObjectName("LayersDefreezeAll");
     a_map["LayersDefreezeAll"] = action;
 
-    action = new QAction(QIcon(":/ui/hiddenblock.png"),
-                         tr("&Hide all"), agm->layer);
+    action = new QAction(tr("&Hide all"), agm->layer);
+    action->setIcon(QIcon(":/ui/hiddenblock.png"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotLayersFreezeAll()));
     action->setObjectName("LayersFreezeAll");
     a_map["LayersFreezeAll"] = action;
 
-    action = new QAction(QIcon(":/icons/add.svg"),
-                         tr("&Add Layer"), agm->layer);
+    action = new QAction(tr("&Unlock all"), agm->layer);
+    action->setIcon(QIcon(":/ui/unlockedlayer.png"));
+    connect(action, SIGNAL(triggered()),
+            action_handler, SLOT(slotLayersUnlockAll()));
+    action->setObjectName("LayersUnlockAll");
+    a_map["LayersUnlockAll"] = action;
+
+    action = new QAction(tr("&Lock all"), agm->layer);
+    action->setIcon(QIcon(":/ui/lockedlayer.png"));
+    connect(action, SIGNAL(triggered()),
+    action_handler, SLOT(slotLayersLockAll()));
+    action->setObjectName("LayersLockAll");
+    a_map["LayersLockAll"] = action;
+
+    action = new QAction(tr("&Add Layer"), agm->layer);
+    action->setIcon(QIcon(":/icons/add.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotLayersAdd()));
     action->setObjectName("LayersAdd");
     a_map["LayersAdd"] = action;
 
-    action = new QAction(QIcon(":/icons/remove.svg"),
-                         tr("&Remove Layer"), agm->layer);
+    action = new QAction(tr("&Remove Layer"), agm->layer);
+    action->setIcon(QIcon(":/icons/remove.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotLayersRemove()));
     action->setObjectName("LayersRemove");
     a_map["LayersRemove"] = action;
 
-    action = new QAction(QIcon(":/icons/attributes.svg"),
-                         tr("&Edit Layer"), agm->layer);
+    action = new QAction(tr("&Edit Layer"), agm->layer);
+    action->setIcon(QIcon(":/icons/attributes.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotLayersEdit()));
     action->setObjectName("LayersEdit");
     a_map["LayersEdit"] = action;
 
-    action = new QAction(QIcon(":/icons/locked.svg"),
-                         tr("Toggle Layer Loc&k"), agm->layer);
+    action = new QAction(tr("Toggle Layer Loc&k"), agm->layer);
+    action->setIcon(QIcon(":/icons/locked.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotLayersToggleLock()));
     action->setObjectName("LayersToggleLock");
@@ -877,9 +913,8 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
     action->setObjectName("BlocksFreezeAll");
     a_map["BlocksFreezeAll"] = action;
 
-    action = new QAction(QIcon(":/icons/add.svg"),
-                         tr("&Add Block"), agm->block);
-
+    action = new QAction(tr("&Add Block"), agm->block);
+    action->setIcon(QIcon(":/icons/add.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotBlocksAdd()));
     action->setObjectName("BlocksAdd");
@@ -899,7 +934,7 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
     action->setObjectName("BlocksAttributes");
     a_map["BlocksAttributes"] = action;
 
-    action = new QAction( tr("&Edit Block"), agm->block);
+    action = new QAction(tr("&Edit Block"), agm->block);
     action->setIcon(QIcon(":/icons/properties.svg"));
     connect(action, SIGNAL(triggered()),
     action_handler, SLOT(slotBlocksEdit()));
@@ -951,6 +986,7 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
     action_handler, SLOT(slotOptionsDrawing()));
     action->setObjectName("OptionsDrawing");
     a_map["OptionsDrawing"] = action;
+    connect( main_window, &QC_ApplicationWindow::windowsChanged, action, &QAction::setEnabled);
 
     action = new QAction(tr("Widget Options"), agm->options);
     action->setObjectName("WidgetOptions");
@@ -1002,7 +1038,7 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
 
     // <[~ Misc ~]>
 
-    action = new QAction(tr("Export as &MakerCAM SVG..."), agm->file);
+    action = new QAction(tr("Export as CA&M/plain SVG..."), agm->file);
     connect(action, SIGNAL(triggered()), action_handler, SLOT(slotFileExportMakerCam()));
     action->setObjectName("FileExportMakerCam");
     a_map["FileExportMakerCam"] = action;
@@ -1031,6 +1067,14 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
     action->setObjectName("FileClose");
     a_map["FileClose"] = action;
 
+	action = new QAction(tr("Close All"), agm->file);
+	action->setIcon(QIcon(":/icons/close_all.svg"));
+	QKeySequence shortcut = QKeySequence::Close;
+	action->setShortcut(QKeySequence("Shift+" + shortcut.toString()));
+	connect(action, SIGNAL(triggered()), main_window, SLOT(slotFileCloseAll()));
+	action->setObjectName("FileCloseAll");
+	a_map["FileCloseAll"] = action;
+
     action = new QAction(tr("Export as PDF"), agm->file);
     action->setIcon(QIcon(":/icons/export_pdf.svg"));
     connect(action, SIGNAL(triggered()), main_window, SLOT(slotFilePrintPDF()));
@@ -1046,16 +1090,10 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
     // <[~ View ~]>
 
     action = new QAction(tr("&Fullscreen"), agm->view);
-    #if QT_VERSION >= 0x050000
-    action->setShortcut(QKeySequence::FullScreen);
+    #if defined(Q_OS_LINUX)
+        action->setShortcut(QKeySequence("F11"));
     #else
-        #if defined(Q_OS_MAC)
-        action->setShortcut(tr("Ctrl+Meta+F"));
-        #elif defined(Q_OS_WIN)
-        action->setShortcut(tr("F11"));
-        #else
-        action->setShortcut(tr("Ctrl+F11"));
-        #endif
+        action->setShortcut(QKeySequence::FullScreen);
     #endif
     action->setCheckable(true);
     connect(action, SIGNAL(toggled(bool)), main_window, SLOT(toggleFullscreen(bool)));
@@ -1075,6 +1113,7 @@ void LC_ActionFactory::fillActionContainer(QMap<QString, QAction*>& a_map, LC_Ac
     action = new QAction(tr("&Draft"), agm->view);
     action->setIcon(QIcon(":/icons/draft.svg"));
     action->setCheckable(true);
+    action->setShortcut(QKeySequence(tr("Ctrl+D", "Toggle Draft Mode")));
     connect(action, SIGNAL(toggled(bool)), main_window, SLOT(slotViewDraft(bool)));
     connect(main_window, SIGNAL(draftChanged(bool)), action, SLOT(setChecked(bool)));
     action->setObjectName("ViewDraft");
@@ -1351,6 +1390,16 @@ void LC_ActionFactory::commonActions(QMap<QString, QAction*>& a_map, LC_ActionGr
     action->setObjectName("FileSaveAs");
     a_map["FileSaveAs"] = action;
 
+	action = new QAction(tr("Save A&ll..."), agm->file);
+	action->setIcon(QIcon(":/icons/save_all.svg"));
+	QKeySequence shortcut = QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_S);
+	// only define this shortcut for platforms not already using it for save as
+	if (shortcut != QKeySequence::SaveAs)
+		action->setShortcut(shortcut);
+	connect(action, SIGNAL(triggered()), main_window, SLOT(slotFileSaveAll()));
+	action->setObjectName("FileSaveAll");
+	a_map["FileSaveAll"] = action;
+
     action = new QAction(tr("&Print..."), agm->file);
     if (using_theme)
         action->setIcon(QIcon::fromTheme("document-print", QIcon(":/icons/print.svg")));
