@@ -3,7 +3,7 @@
 **
 ** This file was created for the LibreCAD project (librecad.org), a 2D CAD program.
 **
-** Copyright (C) 2015 ravas (ravas@outlook.com)
+** Copyright (C) 2015 ravas (github.com/r-a-v-a-s)
 **
 ** This program is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License
@@ -43,7 +43,7 @@
 #include <QFile>
 #include <QMenuBar>
 #include <QActionGroup>
-
+#include <QDesktopServices>
 
 LC_WidgetFactory::LC_WidgetFactory(QC_ApplicationWindow* main_win,
                                    QMap<QString, QAction*>& action_map,
@@ -53,12 +53,13 @@ LC_WidgetFactory::LC_WidgetFactory(QC_ApplicationWindow* main_win,
     , a_map(action_map)
     , ag_manager(agm)
 {
-    file_actions
-            << a_map["FileNew"]
-            << a_map["FileNewTemplate"]
-            << a_map["FileOpen"]
-            << a_map["FileSave"]
-            << a_map["FileSaveAs"];
+	file_actions
+		<< a_map["FileNew"]
+		<< a_map["FileNewTemplate"]
+		<< a_map["FileOpen"]
+		<< a_map["FileSave"]
+		<< a_map["FileSaveAs"]
+		<< a_map["FileSaveAll"];
 
     line_actions
             << a_map["DrawLine"]
@@ -75,6 +76,7 @@ LC_WidgetFactory::LC_WidgetFactory(QC_ApplicationWindow* main_win,
             << a_map["DrawLineOrthogonal"]
             << a_map["DrawLineRelAngle"]
             << a_map["DrawLinePolygonCenCor"]
+            << a_map["DrawLinePolygonCenTan"]   //20161226 added by txmy
             << a_map["DrawLinePolygonCorCor"];
 
     circle_actions
@@ -168,6 +170,8 @@ LC_WidgetFactory::LC_WidgetFactory(QC_ApplicationWindow* main_win,
     layer_actions
             << a_map["LayersDefreezeAll"]
             << a_map["LayersFreezeAll"]
+            << a_map["LayersUnlockAll"]
+            << a_map["LayersLockAll"]
             << a_map["LayersAdd"]
             << a_map["LayersRemove"]
             << a_map["LayersEdit"]
@@ -493,54 +497,63 @@ QToolBar* LC_WidgetFactory::createCategoriesToolbar()
     tool_button = new QToolButton;
     tool_button->setPopupMode(QToolButton::InstantPopup);
     tool_button->setIcon(QIcon(":/icons/line.svg"));
+    tool_button->setToolTip(tr("Lines"));
     categories_toolbar->addWidget(tool_button);
     tool_button->addActions(line_actions);
 
     tool_button = new QToolButton;
     tool_button->setPopupMode(QToolButton::InstantPopup);
     tool_button->setIcon(QIcon(":/icons/circle.svg"));
+    tool_button->setToolTip(tr("Circles"));
     categories_toolbar->addWidget(tool_button);
     tool_button->addActions(circle_actions);
 
     tool_button = new QToolButton;
     tool_button->setPopupMode(QToolButton::InstantPopup);
     tool_button->setIcon(QIcon(":/icons/line_freehand.svg"));
+    tool_button->setToolTip(tr("Freehand"));
     categories_toolbar->addWidget(tool_button);
     tool_button->addActions(curve_actions);
 
     tool_button = new QToolButton;
     tool_button->setPopupMode(QToolButton::InstantPopup);
     tool_button->setIcon(QIcon(":/icons/ellipses.svg"));
+    tool_button->setToolTip(tr("Ellipses"));
     categories_toolbar->addWidget(tool_button);
     tool_button->addActions(ellipse_actions);
 
     tool_button = new QToolButton;
     tool_button->setPopupMode(QToolButton::InstantPopup);
     tool_button->setIcon(QIcon(":/icons/polylines.svg"));
+    tool_button->setToolTip(tr("PolyLines"));
     categories_toolbar->addWidget(tool_button);
     tool_button->addActions(polyline_actions);
 
     tool_button = new QToolButton;
     tool_button->setPopupMode(QToolButton::InstantPopup);
     tool_button->setIcon(QIcon(":/icons/select.svg"));
+    tool_button->setToolTip(tr("Select"));
     categories_toolbar->addWidget(tool_button);
     tool_button->addActions(select_actions);
 
     tool_button = new QToolButton;
     tool_button->setPopupMode(QToolButton::InstantPopup);
     tool_button->setIcon(QIcon(":/icons/dim_horizontal.svg"));
+    tool_button->setToolTip(tr("Dimensions"));
     categories_toolbar->addWidget(tool_button);
     tool_button->addActions(dimension_actions);
 
     tool_button = new QToolButton;
     tool_button->setPopupMode(QToolButton::InstantPopup);
     tool_button->setIcon(QIcon(":/icons/move_rotate.svg"));
+    tool_button->setToolTip(tr("Modify"));
     categories_toolbar->addWidget(tool_button);
     tool_button->addActions(modify_actions);
 
     tool_button = new QToolButton;
     tool_button->setPopupMode(QToolButton::InstantPopup);
     tool_button->setIcon(QIcon(":/icons/measure.svg"));
+    tool_button->setToolTip(tr("Measure"));
     categories_toolbar->addWidget(tool_button);
     tool_button->addActions(info_actions);
 
@@ -557,7 +570,14 @@ void LC_WidgetFactory::createMenus(QMenuBar* menu_bar)
     file_menu = new QMenu(QC_ApplicationWindow::tr("&File"), menu_bar);
     file_menu->setObjectName("File");
     file_menu->setTearOffEnabled(true);
-    file_menu->addActions(file_actions);
+	file_menu->addAction(a_map["FileNew"]);
+	file_menu->addAction(a_map["FileNewTemplate"]);
+	file_menu->addAction(a_map["FileOpen"]);
+	file_menu->addSeparator();
+	file_menu->addAction(a_map["FileSave"]);
+	file_menu->addAction(a_map["FileSaveAs"]);
+	file_menu->addAction(a_map["FileSaveAll"]);
+	file_menu->addSeparator();
     sub_menu = file_menu->addMenu(QIcon(":/icons/import.svg"), QC_ApplicationWindow::tr("Import"));
     sub_menu->setObjectName("Import");
     sub_menu->addAction(a_map["DrawImage"]);
@@ -572,6 +592,7 @@ void LC_WidgetFactory::createMenus(QMenuBar* menu_bar)
     file_menu->addAction(a_map["FilePrintPreview"]);
     file_menu->addSeparator();
     file_menu->addAction(a_map["FileClose"]);
+	file_menu->addAction(a_map["FileCloseAll"]);
     file_menu->addAction(a_map["FileQuit"]);
     file_menu->addSeparator();
 
@@ -752,9 +773,50 @@ void LC_WidgetFactory::createMenus(QMenuBar* menu_bar)
     help_menu->setObjectName("Help");
     help_menu->setTearOffEnabled(true);
 
-    QAction* wiki_link = new QAction(QC_ApplicationWindow::tr("Online"), main_window);
-    connect(wiki_link, SIGNAL(triggered()), main_window, SLOT(invokeLinkList()));
-    help_menu->addAction(wiki_link);
+    QAction* online_wiki    = new QAction( QC_ApplicationWindow::tr( "&Wiki"), main_window);
+    QAction* online_manual  = new QAction( QC_ApplicationWindow::tr( "User's &Manual"), main_window);
+    QAction* online_commands= new QAction( QC_ApplicationWindow::tr( "&Commands"), main_window);
+    QAction* online_styles  = new QAction( QC_ApplicationWindow::tr( "&Style Sheets"), main_window);
+    QAction* online_widgets = new QAction( QC_ApplicationWindow::tr( "Wid&gets"), main_window);
+    QAction* online_forum   = new QAction( QC_ApplicationWindow::tr( "&Forum"), main_window);
+    QAction* online_chat    = new QAction( QC_ApplicationWindow::tr( "Zulip &Chat"), main_window);
+    QAction* online_release = new QAction( QC_ApplicationWindow::tr( "&Release Information"), main_window);
+    connect(online_wiki, &QAction::triggered, main_window, [=](){
+        QDesktopServices::openUrl( QUrl( "https://dokuwiki.librecad.org/"));
+    });
+    connect(online_manual, &QAction::triggered, main_window, [=](){
+        QDesktopServices::openUrl( QUrl( "https://librecad.readthedocs.io/"));
+    });
+    connect(online_commands, &QAction::triggered, main_window, [=](){
+        QDesktopServices::openUrl( QUrl( "https://librecad.readthedocs.io/en/latest/ref/tools.html"));
+    });
+    connect(online_styles, &QAction::triggered, main_window, [=](){
+        QDesktopServices::openUrl( QUrl( "https://librecad.readthedocs.io/en/latest/ref/customize.html#style-sheets"));
+    });
+    connect(online_widgets, &QAction::triggered, main_window, [=](){
+        QDesktopServices::openUrl( QUrl( "https://librecad.readthedocs.io/en/latest/ref/menu.html#widgets"));
+    });
+    connect(online_forum, &QAction::triggered, main_window, [=](){
+        QDesktopServices::openUrl( QUrl( "https://forum.librecad.org/"));
+    });
+    connect(online_chat, &QAction::triggered, main_window, [=](){
+        QDesktopServices::openUrl( QUrl( "https://librecad.zulipchat.com/"));
+    });
+    connect(online_release, &QAction::triggered, main_window, [=](){
+        QDesktopServices::openUrl( QUrl( "https://github.com/LibreCAD/LibreCAD/releases"));
+    });
+
+    QMenu* online_menu = help_menu->addMenu( QC_ApplicationWindow::tr( "On&line"));
+    online_menu->setObjectName("online_menu");
+    online_menu->setTearOffEnabled(true);
+    online_menu->addAction( online_wiki);
+    online_menu->addAction( online_manual);
+    online_menu->addAction( online_commands);
+    online_menu->addAction( online_styles);
+    online_menu->addAction( online_widgets);
+    online_menu->addAction( online_forum);
+    online_menu->addAction( online_chat);
+    online_menu->addAction( online_release);
 
     help_menu->addSeparator();
 
@@ -762,6 +824,16 @@ void LC_WidgetFactory::createMenus(QMenuBar* menu_bar)
     connect(help_about, SIGNAL(triggered()), main_window, SLOT(showAboutWindow()));
     help_menu->addAction(help_about);
 
+    QAction* license = new QAction(QObject::tr("License"), main_window);
+    connect(license, SIGNAL(triggered()), main_window, SLOT(invokeLicenseWindow()));
+    help_menu->addAction(license);
+
+    QAction* donate = new QAction( QC_ApplicationWindow::tr( "&Donate"), main_window);
+    connect(donate, &QAction::triggered, main_window, [=](){
+        QDesktopServices::openUrl( QUrl( "https://librecad.org/donate.html"));
+    });
+    help_menu->addAction(donate);
+
     // <[~ Widgets Menu ~]>
 
     QMenu* widgets_menu = new QMenu("Widgets", menu_bar);
