@@ -2,6 +2,8 @@
 **
 ** This file is part of the LibreCAD project, a 2D CAD program
 **
+** Copyright (C) 2018 webmite <ianm.main@gmail.com>
+** Copyright (C) 2018 A. Stebich (librecad@mail.lordofbikes.de)
 ** Copyright (C) 2010 R. van Twisk (librecad@rvt.dds.nl)
 ** Copyright (C) 2001-2003 RibbonSoft. All rights reserved.
 **
@@ -32,6 +34,7 @@
 #include <QString>
 #include <QFileDialog>
 #include <QToolBar>
+#include <QRegularExpression>
 
 #include "rs_patternlist.h"
 #include "rs_settings.h"
@@ -114,10 +117,6 @@
 #include "rs_vector.h"
 #include "rs_debug.h"
 
-#if QT_VERSION < 0x040400
-#include "emu_qt44.h"
-#endif
-
 //QG_DialogFactory* QG_DialogFactory::uniqueInstance = nullptr;
 
 /**
@@ -179,21 +178,36 @@ void QG_DialogFactory::requestWarningDialog(const QString& warning) {
  * @return a pointer to the newly created layer that
  * should be added.
  */
-RS_Layer* QG_DialogFactory::requestNewLayerDialog(RS_LayerList* layerList) {
+RS_Layer* QG_DialogFactory::requestNewLayerDialog(RS_LayerList* layerList)
+{
+    RS_Layer* layer {nullptr};
 
-	RS_Layer* layer = nullptr;
-
-    QString layer_name = "", newLayerName = "";
-
-	if (layerList) {
-        layer_name = QString(layerList->getActive()->getName());
-        if (layer_name.isEmpty() || !layer_name.compare("0", Qt::CaseInsensitive) ) {
-            layer_name = "noname";
+    QString layer_name;
+    QString newLayerName;
+    if (nullptr != layerList) {
+        layer_name = layerList->getActive()->getName();
+        if (layer_name.isEmpty() || !layer_name.compare("0") ) {
+            layer_name = QObject::tr( "noname", "default layer name");
         }
-        newLayerName = QString(layer_name);
-		int i = 2;
-		while(layerList->find(newLayerName)) {
-            newLayerName = QString("%1%2").arg(layer_name).arg(i++);
+        newLayerName = layer_name;
+
+        QString sBaseLayerName( layer_name);
+        QString sNumLayerName;
+        int nlen {1};
+        int i {0};
+        QRegularExpression re("^(.*\\D+|)(\\d*)$");
+        QRegularExpressionMatch match( re.match(layer_name));
+        if (match.hasMatch()) {
+            sBaseLayerName = match.captured(1);
+            if( 1 < match.lastCapturedIndex()) {
+                sNumLayerName = match.captured(2);
+                nlen = sNumLayerName.length();
+                i = sNumLayerName.toInt();
+            }
+        }
+
+        while (layerList->find( newLayerName)) {
+            newLayerName = QString("%1%2").arg( sBaseLayerName).arg( ++i, nlen, 10, QChar('0'));
         }
     }
 
@@ -208,8 +222,9 @@ RS_Layer* QG_DialogFactory::requestNewLayerDialog(RS_LayerList* layerList) {
         dlg.updateLayer();
     } else {
         delete layer;
-		layer = nullptr;
+        layer = nullptr;
     }
+
     return layer;
 }
 
@@ -270,6 +285,103 @@ RS_Layer* QG_DialogFactory::requestLayerRemovalDialog(RS_LayerList* layerList) {
 }
 
 
+/**
+ * Shows a dialog that asks the user if the selected layers
+ * can be removed. Doesn't remove the layers. This is up to the caller.
+ *
+ * @return a list of layers names to be removed.
+ */
+QStringList QG_DialogFactory::requestSelectedLayersRemovalDialog(
+    RS_LayerList* layerList)
+{
+
+    if (!layerList) {
+        RS_DEBUG->print(RS_Debug::D_WARNING,
+                "QG_DialogFactory::requestSelectedLayersRemovalDialog(): "
+                "layerList is nullptr");
+        return QStringList();
+    }
+
+    QStringList names;
+    bool layer_0_selected {false};
+
+    // first, try to add selected layers
+    for (auto layer: *layerList) {
+        if (!layer) continue;
+        if (!layer->isVisibleInLayerList()) continue;
+        if (!layer->isSelectedInLayerList()) continue;
+        if (layer->getName() == "0") {
+            layer_0_selected = true;
+            continue;
+        }
+        names << layer->getName();
+    }
+
+    // then, if there're no selected layers,
+    // try to add active layer instead
+    if (names.isEmpty()) {
+        RS_Layer* layer = layerList->getActive();
+        if (layer && layer->isVisibleInLayerList()) {
+            if (layer->getName() == "0") {
+                layer_0_selected = true;
+            } else {
+                names << layer->getName();
+            }
+        }
+    }
+
+    // still there're no layers, so return
+    if (names.isEmpty()) {
+        if (layer_0_selected) {
+            QMessageBox::information(
+                parent,
+                QMessageBox::tr("Remove Layer"),
+                QMessageBox::tr("Layer \"0\" can never be removed."),
+                QMessageBox::Ok
+            );
+        }
+        return names; // empty, nothing to remove
+    }
+
+    // layers added, show confirmation dialog
+
+    QString title(
+        QMessageBox::tr("Remove %n layer(s)", "", names.size())
+    );
+
+    QStringList text_lines = {
+        QMessageBox::tr("Listed layers and all entities on them will be removed."),
+        "",
+        QMessageBox::tr("Warning: this action can NOT be undone!"),
+    };
+
+    if (layer_0_selected) {
+        text_lines << "" <<
+            QMessageBox::tr("Warning: layer \"0\" can never be removed.");
+    }
+
+    QStringList detail_lines = {
+        QMessageBox::tr("Layers for removal:"),
+        "",
+    };
+    detail_lines << names;
+
+    QMessageBox msgBox(
+        QMessageBox::Warning,
+        title,
+        text_lines.join("\n"),
+        QMessageBox::Ok | QMessageBox::Cancel
+    );
+
+    msgBox.setDetailedText(detail_lines.join("\n"));
+
+    if (msgBox.exec() == QMessageBox::Ok) {
+        return names;
+    }
+
+    return QStringList();
+}
+
 
 /**
  * Shows a dialog for editing a layer. A new layer is created and
@@ -435,6 +547,82 @@ RS_Block* QG_DialogFactory::requestBlockRemovalDialog(RS_BlockList* blockList) {
 }
 
 
+/**
+ * Shows a dialog that asks the user if the selected blocks
+ * can be removed. Doesn't remove the blocks. This is up to the caller.
+ *
+ * @return a list of blocks to be removed.
+ */
+QList<RS_Block*> QG_DialogFactory::requestSelectedBlocksRemovalDialog(
+    RS_BlockList* blockList)
+{
+
+    if (!blockList) {
+        RS_DEBUG->print(RS_Debug::D_WARNING,
+                "QG_DialogFactory::requestSelectedBlocksRemovalDialog(): "
+                "blockList is nullptr");
+        return QList<RS_Block*>();
+    }
+
+    QList<RS_Block*> blocks;
+
+    // first, try to add selected blocks
+    for (auto block: *blockList) {
+        if (!block) continue;
+        if (!block->isVisibleInBlockList()) continue;
+        if (!block->isSelectedInBlockList()) continue;
+        blocks << block;
+    }
+
+    // then, if there're no selected blocks,
+    // try to add active block instead
+    if (blocks.isEmpty()) {
+        RS_Block* block = blockList->getActive();
+        if (block && block->isVisibleInBlockList()) {
+            blocks << block;
+        }
+    }
+
+    // still nothing was added, so return
+    if (blocks.isEmpty()) {
+        return blocks; // empty, nothing to remove
+    }
+
+    // blocks added, show confirmation dialog
+
+    QString title(
+        QMessageBox::tr("Remove %n block(s)", "", blocks.size())
+    );
+
+    QString text(
+        QMessageBox::tr("Listed blocks and all their entities will be removed.")
+    );
+
+    QStringList detail_lines = {
+        QMessageBox::tr("Blocks for removal:"),
+        "",
+    };
+    for (auto block: blocks) {
+        detail_lines << block->getName();
+    }
+
+    QMessageBox msgBox(
+        QMessageBox::Warning,
+        title,
+        text,
+        QMessageBox::Ok | QMessageBox::Cancel
+    );
+
+    msgBox.setDetailedText(detail_lines.join("\n"));
+
+    if (msgBox.exec() == QMessageBox::Ok) {
+        return blocks;
+    }
+
+    return QList<RS_Block*>();
+}
+
+
 /**
  * Shows a dialog for choosing a file name. Opening the file is up to
  * the caller.
@@ -476,14 +664,10 @@ QString QG_DialogFactory::requestImageOpenDialog()
     fileDlg.setFileMode(QFileDialog::ExistingFile);
     fileDlg.setWindowTitle(QObject::tr("Open Image"));
     fileDlg.setDirectory(defDir);
-#if QT_VERSION >= 0x040400
     fileDlg.setNameFilters(filters);
     if (defFilter.isEmpty())
         defFilter = strAllImageFiles;
     fileDlg.selectNameFilter(defFilter);
-#else
-    emu_qt44_QFileDialog_setNameFilters(fileDlg, filters);
-#endif
 
     if (QDialog::Accepted == fileDlg.exec()) {
         QStringList strSelectedFiles = fileDlg.selectedFiles();
@@ -493,11 +677,7 @@ QString QG_DialogFactory::requestImageOpenDialog()
         // store new default settings:
         RS_SETTINGS->beginGroup("/Paths");
         RS_SETTINGS->writeEntry("/OpenImage", QFileInfo(strFileName).absolutePath());
-#if QT_VERSION < 0x040400
-        RS_SETTINGS->writeEntry("/ImageFilter", emu_qt44_QFileDialog_selectedNameFilter(fileDlg));
-#else
         RS_SETTINGS->writeEntry("/ImageFilter", fileDlg.selectedNameFilter());
-#endif
         RS_SETTINGS->endGroup();
     }
 
