@@ -31,6 +31,7 @@
 #include <QWidget>
 #include <QIcon>
 #include <QAbstractTableModel>
+#include <QItemSelection>
 
 #include "rs_layerlistlistener.h"
 #include "rs_layerlist.h"
@@ -52,6 +53,10 @@ public:
 		COLOR_SAMPLE,
         NAME,
         LAST
+    };
+    enum IconSize {
+        ICONWIDTH = 24,
+        ICONHEIGHT = 24,
     };
 	QG_LayerModel(QObject * parent = nullptr);
 	~QG_LayerModel() = default;
@@ -71,6 +76,9 @@ public:
     RS_Layer *getLayer( int row );
     QModelIndex getIndex (RS_Layer * lay);
 
+    RS_Layer* getActiveLayer() { return activeLayer; };
+    void setActiveLayer(RS_Layer* l) { activeLayer = l; };
+
 private:
     QList<RS_Layer*> listLayer;
     QIcon layerVisible;
@@ -78,7 +86,10 @@ private:
     QIcon layerDefreeze;
     QIcon layerFreeze;
     QIcon layerPrint;
+    QIcon layerNoPrint;
     QIcon layerConstruction;
+    QIcon layerNoConstruction;
+    RS_Layer* activeLayer {nullptr};
 };
 
 
@@ -102,10 +113,7 @@ public:
     virtual void layerActivated(RS_Layer* layer) {
         activateLayer(layer);
     }
-    virtual void layerAdded(RS_Layer* layer) {
-        update();
-        activateLayer(layer);
-    }
+    virtual void layerAdded(RS_Layer* layer);
     virtual void layerEdited(RS_Layer*) {
         update();
     }
@@ -140,7 +148,11 @@ signals:
 
 public slots:
     void slotActivated(QModelIndex layerIdx);
+    void slotSelectionChanged(
+        const QItemSelection &selected,
+        const QItemSelection &deselected);
     void slotUpdateLayerList();
+    void activateLayer(int row);
 
 protected:
     void contextMenuEvent(QContextMenuEvent *e);
@@ -154,6 +166,8 @@ private:
     QG_LayerModel *layerModel;
     RS_Layer* lastLayer;   
     QG_ActionHandler* actionHandler;
+
+    void restoreSelections();
 };
 
 #endif
