@@ -18,16 +18,14 @@
 class LC_Align : public QObject, QC_PluginInterface
 {
     Q_OBJECT
-     Q_INTERFACES(QC_PluginInterface)
-#if QT_VERSION >= 0x050000
-     Q_PLUGIN_METADATA(IID "org.librecad.align" FILE  "align.json")
-#endif
+    Q_INTERFACES(QC_PluginInterface)
+    Q_PLUGIN_METADATA(IID LC_DocumentInterface_iid FILE  "align.json")
 
  public:
-    virtual PluginCapabilities getCapabilities() const;
-    virtual QString name() const;
+    virtual PluginCapabilities getCapabilities() const Q_DECL_OVERRIDE;
+    virtual QString name() const Q_DECL_OVERRIDE;
     virtual void execComm(Document_Interface *doc,
-                                       QWidget *parent, QString cmd);
+                          QWidget *parent, QString cmd) Q_DECL_OVERRIDE;
 };
 
 #endif // ALIGN_H
