@@ -4,8 +4,8 @@
 <context>
     <name>AsciiFile</name>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="37"/>
-        <location filename="../asciifile/asciifile.cpp" line="43"/>
+        <location filename="../asciifile/asciifile.cpp" line="35"/>
+        <location filename="../asciifile/asciifile.cpp" line="41"/>
         <source>Read ascii points</source>
         <translation>Punkte aus ASCII-Datei</translation>
     </message>
@@ -51,6 +51,19 @@
         <translation>Zweiter Zielpunkt:</translation>
     </message>
 </context>
+<context>
+    <name>LC_Gear</name>
+    <message>
+        <location filename="../gear/gear.cpp" line="33"/>
+        <source>Gear creation plugin</source>
+        <translation>Zahnrad Plugin</translation>
+    </message>
+    <message>
+        <location filename="../gear/gear.cpp" line="40"/>
+        <source>Gear plugin</source>
+        <translation>Zahnrad Plugin</translation>
+    </message>
+</context>
 <context>
     <name>LC_List</name>
     <message>
@@ -80,188 +93,208 @@
         <translation>Y</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="73"/>
+        <location filename="../list/list.cpp" line="77"/>
         <source>Layer</source>
         <translation>Layer</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="75"/>
+        <location filename="../list/list.cpp" line="79"/>
         <source>Color</source>
         <translation>Farbe</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="76"/>
+        <location filename="../list/list.cpp" line="80"/>
         <source>Line type</source>
         <translation>Linientyp</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="77"/>
+        <location filename="../list/list.cpp" line="81"/>
         <source>Line thickness</source>
         <translation>Linienstärke</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="78"/>
+        <location filename="../list/list.cpp" line="82"/>
         <source>ID</source>
         <translation>ID</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="84"/>
+        <location filename="../list/list.cpp" line="88"/>
         <source>POINT</source>
         <translation>PUNKT</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="85"/>
-        <location filename="../list/list.cpp" line="195"/>
+        <location filename="../list/list.cpp" line="89"/>
+        <location filename="../list/list.cpp" line="218"/>
         <source>in point</source>
         <translation>im Punkt</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="90"/>
+        <location filename="../list/list.cpp" line="94"/>
         <source>LINE</source>
         <translation>LINIE</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="95"/>
+        <location filename="../list/list.cpp" line="99"/>
         <source>from point</source>
         <translation>von Punkt</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="98"/>
+        <location filename="../list/list.cpp" line="102"/>
         <source>to point</source>
         <translation>zu Punkt</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="103"/>
-        <location filename="../list/list.cpp" line="127"/>
+        <location filename="../list/list.cpp" line="107"/>
+        <location filename="../list/list.cpp" line="131"/>
         <source>length</source>
         <translation>Länge</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="108"/>
+        <location filename="../list/list.cpp" line="112"/>
         <source>Angle in XY plane</source>
         <translation>Winkel in XY Ebene</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="109"/>
+        <location filename="../list/list.cpp" line="113"/>
         <source>Inc.</source>
         <translation>Ausdehnung</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="114"/>
+        <location filename="../list/list.cpp" line="118"/>
         <source>ARC</source>
         <translation>KREISBOGEN</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="115"/>
-        <location filename="../list/list.cpp" line="131"/>
-        <location filename="../list/list.cpp" line="141"/>
+        <location filename="../list/list.cpp" line="119"/>
+        <location filename="../list/list.cpp" line="135"/>
+        <location filename="../list/list.cpp" line="145"/>
         <source>center point</source>
         <translation>Mittelpunkt</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="121"/>
-        <location filename="../list/list.cpp" line="135"/>
-        <location filename="../list/list.cpp" line="199"/>
+        <location filename="../list/list.cpp" line="125"/>
+        <location filename="../list/list.cpp" line="139"/>
+        <location filename="../list/list.cpp" line="222"/>
         <source>radius</source>
         <translation>Radius</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="122"/>
+        <location filename="../list/list.cpp" line="126"/>
         <source>initial angle</source>
         <translation>Startwinkel</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="123"/>
+        <location filename="../list/list.cpp" line="127"/>
         <source>final angle</source>
         <translation>Endwinkel</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="130"/>
+        <location filename="../list/list.cpp" line="134"/>
         <source>CIRCLE</source>
         <translation>KREIS</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="136"/>
+        <location filename="../list/list.cpp" line="140"/>
         <source>circumference</source>
         <translation>Umfang</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="137"/>
+        <location filename="../list/list.cpp" line="141"/>
         <source>area</source>
         <translation>Fläche</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="140"/>
+        <location filename="../list/list.cpp" line="144"/>
         <source>ELLIPSE</source>
         <translation>ELLIPSE</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="144"/>
+        <location filename="../list/list.cpp" line="148"/>
         <source>major axis</source>
         <translation>Hauptachse</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="162"/>
+        <location filename="../list/list.cpp" line="166"/>
         <source>CONSTRUCTIONLINE</source>
         <translation>HILFSLINIE</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="165"/>
+        <location filename="../list/list.cpp" line="169"/>
         <source>OVERLAYBOX</source>
         <translation>OVERLAYBOX</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="168"/>
+        <location filename="../list/list.cpp" line="172"/>
         <source>SOLID</source>
         <translation>KÖRPER</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="172"/>
+        <location filename="../list/list.cpp" line="176"/>
         <source>MTEXT</source>
         <translation>MTEXT</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="175"/>
+        <location filename="../list/list.cpp" line="179"/>
         <source>TEXT</source>
         <translation>TEXT</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="178"/>
+        <location filename="../list/list.cpp" line="182"/>
         <source>INSERT</source>
         <translation>BLOCK</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="181"/>
+        <location filename="../list/list.cpp" line="185"/>
         <source>Name</source>
         <translation>Name</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="182"/>
+        <location filename="../list/list.cpp" line="187"/>
         <source>Insertion point</source>
         <translation>Einfügepunkt</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="187"/>
+        <location filename="../list/list.cpp" line="190"/>
+        <source>Scale</source>
+        <translation>Skalierung</translation>
+    </message>
+    <message>
+        <location filename="../list/list.cpp" line="193"/>
+        <source>Rotation</source>
+        <translation>Rotation</translation>
+    </message>
+    <message>
+        <location filename="../list/list.cpp" line="199"/>
+        <source>Columns/Rows</source>
+        <translation>Spalten/Reihen</translation>
+    </message>
+    <message>
+        <location filename="../list/list.cpp" line="203"/>
+        <source>Column/Row Spacing</source>
+        <translation>Spalten/Reihen Abstand</translation>
+    </message>
+    <message>
+        <location filename="../list/list.cpp" line="210"/>
         <source>POLYLINE</source>
         <translation>POLYLINIE</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="188"/>
+        <location filename="../list/list.cpp" line="211"/>
         <source>Closed</source>
         <translation>Geschlossen</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="189"/>
+        <location filename="../list/list.cpp" line="212"/>
         <source>No</source>
         <translation>Nein</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="189"/>
+        <location filename="../list/list.cpp" line="212"/>
         <source>Yes</source>
         <translation>Ja</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="190"/>
+        <location filename="../list/list.cpp" line="213"/>
         <source>Vertices</source>
         <translation>Eckpunkte</translation>
     </message>
@@ -270,57 +303,57 @@
         <translation type="obsolete">Krümmung</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="204"/>
+        <location filename="../list/list.cpp" line="227"/>
         <source>IMAGE</source>
         <translation>BILD</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="207"/>
+        <location filename="../list/list.cpp" line="230"/>
         <source>SPLINE</source>
         <translation>SPLINE</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="210"/>
+        <location filename="../list/list.cpp" line="233"/>
         <source>SPLINEPOINTS</source>
         <translation>SPLINEPUNKTE</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="213"/>
+        <location filename="../list/list.cpp" line="236"/>
         <source>HATCH</source>
         <translation>SCHRAFFUR</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="216"/>
+        <location filename="../list/list.cpp" line="239"/>
         <source>DIMLEADER</source>
         <translation>BEMASSUNGSFÜHRUNG</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="219"/>
+        <location filename="../list/list.cpp" line="242"/>
         <source>DIMALIGNED</source>
         <translation>BEMASSUNGAUSGERICHTET</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="222"/>
+        <location filename="../list/list.cpp" line="245"/>
         <source>DIMLINEAR</source>
         <translation>BEMASSUNGLINEAR</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="225"/>
+        <location filename="../list/list.cpp" line="248"/>
         <source>DIMRADIAL</source>
         <translation>BEMASSUNGRADIAL</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="228"/>
+        <location filename="../list/list.cpp" line="251"/>
         <source>DIMDIAMETRIC</source>
         <translation>BEMASSUNGDURCHMESSER</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="231"/>
+        <location filename="../list/list.cpp" line="254"/>
         <source>DIMANGULAR</source>
         <translation>BEMASSUNGWINKEL</translation>
     </message>
     <message>
-        <location filename="../list/list.cpp" line="234"/>
+        <location filename="../list/list.cpp" line="257"/>
         <source>UNKNOWN</source>
         <translation>UNBEKANNT</translation>
     </message>
@@ -440,12 +473,12 @@
 <context>
     <name>PicFile</name>
     <message>
-        <location filename="../picfile/picfile.cpp" line="38"/>
+        <location filename="../picfile/picfile.cpp" line="36"/>
         <source>Read PIC file</source>
         <translation>PIC Datei einlesen</translation>
     </message>
     <message>
-        <location filename="../picfile/picfile.cpp" line="44"/>
+        <location filename="../picfile/picfile.cpp" line="42"/>
         <source>import PIC file</source>
         <translation>PIC Datei importieren</translation>
     </message>
@@ -453,177 +486,177 @@
 <context>
     <name>dibPunto</name>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="235"/>
+        <location filename="../asciifile/asciifile.cpp" line="229"/>
         <source>Read ascii points</source>
         <translation>Punkte aus ASCII-Datei</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="241"/>
+        <location filename="../asciifile/asciifile.cpp" line="235"/>
         <source>File...</source>
         <translation>Datei...</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="248"/>
+        <location filename="../asciifile/asciifile.cpp" line="242"/>
         <source>Format:</source>
         <translation>Format:</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="250"/>
+        <location filename="../asciifile/asciifile.cpp" line="244"/>
         <source>Space Separator</source>
         <translation>Leerzeichen getrennt</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="250"/>
+        <location filename="../asciifile/asciifile.cpp" line="244"/>
         <source>Tab Separator</source>
         <translation>Tabulator getrennt</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="250"/>
+        <location filename="../asciifile/asciifile.cpp" line="244"/>
         <source>Comma Separator</source>
         <translation>Komma getrennt</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="250"/>
+        <location filename="../asciifile/asciifile.cpp" line="244"/>
         <source>Space in Columns</source>
         <translation>Feste Spaltenbreite</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="250"/>
+        <location filename="../asciifile/asciifile.cpp" line="244"/>
         <source>*.odb for Psion 2</source>
         <translation>*.odb für Psion 2</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="252"/>
+        <location filename="../asciifile/asciifile.cpp" line="246"/>
         <source>Connect points</source>
         <translation>Punkte verbinden</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="260"/>
+        <location filename="../asciifile/asciifile.cpp" line="254"/>
         <source>2D Point</source>
         <translation>2D Punkt</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="260"/>
+        <location filename="../asciifile/asciifile.cpp" line="254"/>
         <source>Draw 2D Point</source>
         <translation>Zeichne 2D Punkt</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="261"/>
+        <location filename="../asciifile/asciifile.cpp" line="255"/>
         <source>3D Point</source>
         <translation>3D Punkt</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="261"/>
+        <location filename="../asciifile/asciifile.cpp" line="255"/>
         <source>Draw 3D Point</source>
         <translation>Zeichne 3D Punkt</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="262"/>
+        <location filename="../asciifile/asciifile.cpp" line="256"/>
         <source>Point Number</source>
         <translation>Punkt Nummer</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="262"/>
+        <location filename="../asciifile/asciifile.cpp" line="256"/>
         <source>Draw point number</source>
         <translation>Zeichne Punkt Nummer</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="263"/>
+        <location filename="../asciifile/asciifile.cpp" line="257"/>
         <source>Point Elevation</source>
         <translation>Höhenpunkt</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="263"/>
+        <location filename="../asciifile/asciifile.cpp" line="257"/>
         <source>Draw point elevation</source>
         <translation>Zeichne Höhenpunkt</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="264"/>
+        <location filename="../asciifile/asciifile.cpp" line="258"/>
         <source>Point Code</source>
         <translation>Punkt Code</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="264"/>
+        <location filename="../asciifile/asciifile.cpp" line="258"/>
         <source>Draw point code</source>
         <translation>Zeichne Punkt Code</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="278"/>
+        <location filename="../asciifile/asciifile.cpp" line="272"/>
         <source>Accept</source>
         <translation>Übernehmen</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="283"/>
+        <location filename="../asciifile/asciifile.cpp" line="277"/>
         <source>Cancel</source>
         <translation>Abbrechen</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="313"/>
+        <location filename="../asciifile/asciifile.cpp" line="307"/>
         <source>Select file</source>
         <translation>Datei auswählen</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="320"/>
+        <location filename="../asciifile/asciifile.cpp" line="314"/>
         <source>Point 2D layer is empty</source>
         <translation>Layer 2D Punkt ist leer</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="323"/>
+        <location filename="../asciifile/asciifile.cpp" line="317"/>
         <source>Point 3D layer is empty</source>
         <translation>Layer 3D Punkt ist leer</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="326"/>
+        <location filename="../asciifile/asciifile.cpp" line="320"/>
         <source>Point elevation layer is empty</source>
         <translation>Layer Höhenpunkt ist leer</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="327"/>
+        <location filename="../asciifile/asciifile.cpp" line="321"/>
         <source>Point elevation height is empty</source>
         <translation>Höhe Höhenpunkt ist leer</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="328"/>
+        <location filename="../asciifile/asciifile.cpp" line="322"/>
         <source>Point elevation separation is empty</source>
         <translation>Abstand Höhenpunkt ist leer</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="331"/>
+        <location filename="../asciifile/asciifile.cpp" line="325"/>
         <source>Point number layer is empty</source>
         <translation>Layer Punkt Nummer ist leer</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="332"/>
+        <location filename="../asciifile/asciifile.cpp" line="326"/>
         <source>Point number height is empty</source>
         <translation>Höhe Punkt Nummer ist leer</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="333"/>
+        <location filename="../asciifile/asciifile.cpp" line="327"/>
         <source>Point number separation is empty</source>
         <translation>Abstand Punkt Nummer ist leer</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="336"/>
+        <location filename="../asciifile/asciifile.cpp" line="330"/>
         <source>Point code layer is empty</source>
         <translation>Layer Punkt Code ist leer</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="337"/>
+        <location filename="../asciifile/asciifile.cpp" line="331"/>
         <source>Point code height is empty</source>
         <translation>Höhe Punkt Code ist leer</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="338"/>
+        <location filename="../asciifile/asciifile.cpp" line="332"/>
         <source>Point code separation is empty</source>
         <translation>Abstand Punkt Code ist leer</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="366"/>
+        <location filename="../asciifile/asciifile.cpp" line="360"/>
         <source>The file %1 not exist</source>
         <translation>Die Datei %1 existiert nicht</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="371"/>
+        <location filename="../asciifile/asciifile.cpp" line="365"/>
         <source>Can&apos;t open the file %1</source>
         <translation>Kann Datei %1 nicht öffnen</translation>
     </message>
@@ -805,10 +838,68 @@
         <translation>Die Datei %1 existiert nicht</translation>
     </message>
 </context>
+<context>
+    <name>lc_Geardlg</name>
+    <message>
+        <location filename="../gear/gear.cpp" line="66"/>
+        <source>Draw a gear</source>
+        <translation>Ein Zahnrad erstellen</translation>
+    </message>
+    <message>
+        <location filename="../gear/gear.cpp" line="71"/>
+        <source>Number of teeth</source>
+        <translation>Anzahl Zähne</translation>
+    </message>
+    <message>
+        <location filename="../gear/gear.cpp" line="79"/>
+        <source>Circular pitch</source>
+        <translation>Teilkreisdurchmesser</translation>
+    </message>
+    <message>
+        <location filename="../gear/gear.cpp" line="87"/>
+        <source>Pressure angle (deg)</source>
+        <translation>Eingriffswinkel (Grad)</translation>
+    </message>
+    <message>
+        <location filename="../gear/gear.cpp" line="95"/>
+        <source>Addendum</source>
+        <translation>Zahnkopfhöhe</translation>
+    </message>
+    <message>
+        <location filename="../gear/gear.cpp" line="103"/>
+        <source>Dedendum</source>
+        <translation>Zahnfusshöhe</translation>
+    </message>
+    <message>
+        <location filename="../gear/gear.cpp" line="111"/>
+        <source>Type</source>
+        <translation>Typ</translation>
+    </message>
+    <message>
+        <location filename="../gear/gear.cpp" line="114"/>
+        <source>Spur</source>
+        <translation>Stirnrad</translation>
+    </message>
+    <message>
+        <location filename="../gear/gear.cpp" line="115"/>
+        <source>Ring</source>
+        <translation>Hohlrad</translation>
+    </message>
+    <message>
+        <location filename="../gear/gear.cpp" line="119"/>
+        <source>Accept</source>
+        <translation>Übernehmen</translation>
+    </message>
+    <message>
+        <location filename="../gear/gear.cpp" line="124"/>
+        <source>Cancel</source>
+        <translation>Abbrechen</translation>
+    </message>
+</context>
 <context>
     <name>lc_Listdlg</name>
     <message>
-        <location filename="../list/list.cpp" line="251"/>
+        <location filename="../list/list.cpp" line="274"/>
         <source>List entities</source>
         <translation>Objekte auflisten</translation>
     </message>
@@ -879,63 +970,63 @@
 <context>
     <name>picPunto</name>
     <message>
-        <location filename="../picfile/picfile.cpp" line="67"/>
+        <location filename="../picfile/picfile.cpp" line="65"/>
         <source>File...</source>
         <translation>Datei...</translation>
     </message>
     <message>
-        <location filename="../picfile/picfile.cpp" line="77"/>
+        <location filename="../picfile/picfile.cpp" line="75"/>
         <source>Scale:</source>
         <translation>Skalierung:</translation>
     </message>
     <message>
-        <location filename="../picfile/picfile.cpp" line="81"/>
+        <location filename="../picfile/picfile.cpp" line="79"/>
         <source>Accept</source>
         <translation>Übernehmen</translation>
     </message>
     <message>
-        <location filename="../picfile/picfile.cpp" line="85"/>
+        <location filename="../picfile/picfile.cpp" line="83"/>
         <source>Cancel</source>
         <translation>Abbrechen</translation>
     </message>
     <message>
-        <location filename="../picfile/picfile.cpp" line="113"/>
+        <location filename="../picfile/picfile.cpp" line="111"/>
         <source>Select file</source>
         <translation>Datei auswählen</translation>
     </message>
     <message>
-        <location filename="../picfile/picfile.cpp" line="121"/>
+        <location filename="../picfile/picfile.cpp" line="119"/>
         <source>Scale Factor is empty or invalid</source>
         <translation>Skalierungsfaktor ist leer oder ungültig</translation>
     </message>
     <message>
-        <location filename="../picfile/picfile.cpp" line="134"/>
+        <location filename="../picfile/picfile.cpp" line="132"/>
         <source>The file %1 not exist</source>
         <translation>Die Datei %1 existiert nicht</translation>
     </message>
     <message>
-        <location filename="../picfile/picfile.cpp" line="139"/>
+        <location filename="../picfile/picfile.cpp" line="137"/>
         <source>Can&apos;t open the file %1</source>
         <translation>Kann Datei %1 nicht öffnen</translation>
     </message>
     <message>
-        <location filename="../picfile/picfile.cpp" line="146"/>
+        <location filename="../picfile/picfile.cpp" line="144"/>
         <source>%1 objects imported</source>
         <translation>%1 Objekte importiert</translation>
     </message>
     <message>
-        <location filename="../picfile/picfile.cpp" line="168"/>
+        <location filename="../picfile/picfile.cpp" line="166"/>
         <source>picPunto drawLine: first point is empty %1</source>
         <translation>PIC Import: Erster Punkt ist leer %1</translation>
     </message>
     <message>
-        <location filename="../picfile/picfile.cpp" line="181"/>
+        <location filename="../picfile/picfile.cpp" line="179"/>
         <source>picPunto drawLine: next point is empty %1</source>
         <translation>PIC Import: Endpunkt ist leer %1</translation>
     </message>
     <message>
-        <location filename="../picfile/picfile.cpp" line="260"/>
-        <location filename="../picfile/picfile.cpp" line="269"/>
+        <location filename="../picfile/picfile.cpp" line="258"/>
+        <location filename="../picfile/picfile.cpp" line="267"/>
         <source>format error in %1</source>
         <translation>Formatfehler in %1</translation>
     </message>
@@ -1034,7 +1125,7 @@ Als Variable/Parameter der Gleichung kann t oder x verwendet werden.
 <context>
     <name>pointBox</name>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="177"/>
+        <location filename="../asciifile/asciifile.cpp" line="175"/>
         <source>Layer:</source>
         <translation>Layer:</translation>
     </message>
@@ -1042,12 +1133,12 @@ Als Variable/Parameter der Gleichung kann t oder x verwendet werden.
 <context>
     <name>textBox</name>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="210"/>
+        <location filename="../asciifile/asciifile.cpp" line="207"/>
         <source>Style:</source>
         <translation>Stil:</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="211"/>
+        <location filename="../asciifile/asciifile.cpp" line="208"/>
         <source>Height:</source>
         <translation>Höhe:</translation>
     </message>
@@ -1056,7 +1147,7 @@ Als Variable/Parameter der Gleichung kann t oder x verwendet werden.
         <translation type="obsolete">Höhe:</translation>
     </message>
     <message>
-        <location filename="../asciifile/asciifile.cpp" line="212"/>
+        <location filename="../asciifile/asciifile.cpp" line="209"/>
         <source>Separation</source>
         <translation>Teilung</translation>
     </message>
